/*!
 * Copyright Adaptavist 2022 (c) All rights reserved
 */
import { IdProperty, NameProperty } from './common';
import { Attachment } from './attachment';
import { Comment } from './comment';
import { Component } from './component';
import { FieldMeta } from './field_meta';
import { HistoryMetadata } from './history_metadata';
import { IssueLink } from './issue_link';
import { IssueRef } from './issue_ref';
import { IssueType } from './issue_type';
import { JsonType } from './json_type';
import { LinkGroup } from './link_group';
import { Priority } from './priority';
import { Project } from './project';
import { Status } from './status';
import { Transition } from './transition';
import { UserFull } from './user';
import { Version } from './version';
import { Worklog } from './worklog';
interface CommonFields {
    components?: IdProperty[];
    reporter?: NameProperty;
    description?: string;
    assignee?: NameProperty;
    fixVersions?: IdProperty[];
    priority?: IdProperty;
    labels?: string[];
    versions?: IdProperty[];
    duedate?: string | null;
    security?: IdProperty;
    timetracking?: {
        remainingEstimate?: string;
        originalEstimate?: string;
    };
    environment?: string;
    parent?: {
        id?: string;
        key?: string;
    };
    [x: string]: any;
}
export interface FieldsCreateIssue extends CommonFields {
    project: IdProperty;
    issuetype: IdProperty;
    summary: string;
}
export interface FieldsEditIssue extends CommonFields {
    project?: IdProperty;
    issuetype?: IdProperty;
    summary?: string;
    resolution?: IdProperty;
}
export interface IssueResponse {
    expand?: string;
    id?: string;
    self?: string;
    key?: string;
    fields?: {
        issuetype?: IssueType;
        components?: Component[];
        timespent?: number | null;
        timeoriginalestimate?: number | null;
        description?: string | null;
        project?: Project;
        fixVersions?: Version[];
        aggregatetimespent?: number | null;
        resolution?: {
            self?: string;
            id?: string;
            description?: string;
            name?: string;
        } | null;
        timetracking?: {
            originalEstimate?: string;
            remainingEstimate?: string;
            timeSpent?: string;
            originalEsimateSeconds?: number;
            remainingEstimateSeconds?: number;
            timeSpentSeconds?: number;
        };
        subtasks?: IssueRef[];
        attachment?: Attachment[];
        aggregatetimeestimate?: number | null;
        resolutiondate?: string | null;
        workratio?: number;
        summary?: string;
        lastViewed?: any;
        watches?: {
            self?: string;
            watchCount?: number;
            isWatching?: boolean;
        };
        creator?: UserFull;
        created?: string;
        reporter?: UserFull;
        aggregateprogress?: {
            progress?: number;
            total?: number;
            percent?: number;
        };
        priority?: Priority;
        labels?: string[];
        environment?: string | null;
        timeestimate?: number | null;
        aggregatetimeoriginalestimate?: number | null;
        versions?: Version[];
        duedate?: string | null;
        progress?: {
            progress?: number;
            total?: number;
            percent?: number;
        };
        comment?: {
            comments?: Comment[];
            maxResults?: number;
            total?: number;
            startAt?: number;
        };
        issuelinks?: IssueLink[];
        votes?: {
            self?: string;
            votes?: number;
            hasVoted?: boolean;
        };
        worklog?: {
            startAt?: number;
            maxResults?: number;
            total?: number;
            worklogs?: Worklog[];
        };
        assignee?: UserFull | null;
        updated?: string;
        status?: Status;
        parent?: IssueRef;
        security?: IdProperty;
        [x: string]: any;
    };
    renderedFields?: Record<string, any>;
    properties?: {
        properties: Record<string, string>;
    };
    names?: Record<string, string>;
    schema?: Record<string, JsonType>;
    transitions?: Transition[];
    operations?: {
        linkGroups?: LinkGroup[];
    };
    editmeta?: {
        fields?: Record<string, FieldMeta>;
    };
    changelog?: {
        startAt?: number;
        maxResults?: number;
        total?: number;
        histories?: {
            id?: string;
            author?: UserFull;
            created?: string;
            items?: {
                field?: string;
                fieldtype?: string;
                from?: string;
                fromString?: string;
                to?: string;
                toString?: string;
            }[];
            historyMetadata?: HistoryMetadata;
        }[];
    };
    versionedRepresentations?: Record<string, Record<string, any>>;
    fieldsToInclude?: Record<string, any>;
}
export {};
//# sourceMappingURL=issue.d.ts.map