/*!
 * Copyright Adaptavist 2022 (c) All rights reserved
 */
import { HeadersOption } from '@managed-api/commons-core';
import { GetConfigurationResponse, GetInfoResponse } from '../definitions/instance';
import { Property } from '../definitions/property';
import { ErrorStrategyOption } from '../errorStrategy';
export interface GetApplicationPropertyRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * a String containing the property key
     */
    key?: string;
    /**
     * when fetching a list specifies the permission level of all items in the list see {@link com.atlassian.jira.bc.admin.ApplicationPropertiesService.EditPermissionLevel}
     */
    permissionLevel?: string;
    /**
      * when fetching a list allows the list to be filtered by the property's start of key e.g. "jira.lf.*" whould fetch only those permissions that are editable and whose keys start with "jira.lf.". This is a regex.
      */
    keyFilter?: string;
}
export declare type GetApplicationPropertyResponseOK = Property | Array<Property>;
export declare type GetApplicationPropertyResponseError = undefined;
export interface SetApplicationPropertyRequest extends HeadersOption, ErrorStrategyOption {
    id: string;
    body: {
        value: string | number | boolean;
    };
}
export interface SetApplicationPropertyResponseOK extends Property {
}
export declare type SetApplicationPropertyResponseError = undefined;
export interface GetAdvancedSettingsRequest extends HeadersOption, ErrorStrategyOption {
}
export interface GetAdvancedSettingsResponseOK extends Array<Property> {
}
export declare type GetAdvancedSettingsResponseError = undefined;
export interface GetInstanceConfigurationRequest extends HeadersOption, ErrorStrategyOption {
}
export interface GetInstanceConfigurationResponseOK extends GetConfigurationResponse {
}
export declare type GetInstanceConfigurationResponseError = undefined;
export interface GetInstanceInfoRequest extends HeadersOption, ErrorStrategyOption {
    doHealthCheck?: boolean;
}
export interface GetInstanceInfoResponseOK extends GetInfoResponse {
}
export declare type GetInstanceInfoResponseError = undefined;
//# sourceMappingURL=instance.d.ts.map