/*!
 * Copyright Adaptavist 2022 (c) All rights reserved
 */
import { CreateResponse } from '../definitions/create_response';
import { HistoryMetadata } from '../definitions/history_metadata';
import { EntityProperty, IdProperty, NameProperty } from '../definitions/common';
import { FieldsCreateIssue, FieldsEditIssue, IssueResponse } from '../definitions/issue';
import { HeadersOption } from '@managed-api/commons-core';
import { ErrorStrategyOption } from '../errorStrategy';
export interface CreateIssueRequest extends HeadersOption, ErrorStrategyOption {
    body: {
        transition?: IdProperty;
        fields?: FieldsCreateIssue;
        update?: Record<string, {
            set?: any;
            edit?: any;
            add?: any;
            remove?: any;
        }>;
        historyMetadata?: HistoryMetadata;
        properties?: EntityProperty[];
        [x: string]: any;
    };
}
export interface CreateIssueResponseOK extends CreateResponse {
}
export declare type CreateIssueResponseError = undefined;
export interface GetIssueRequest extends HeadersOption, ErrorStrategyOption {
    issueIdOrKey: string | number;
    /**
     * The fields param (which can be specified multiple times) gives a comma-separated list of fields to include in the response. This can be used to retrieve a subset of fields. A particular field can be excluded by prefixing it with a minus.
     * By default, all (*all) fields are returned in this get-issue resource. Note: the default is different when doing a jql search -- the default there is just navigable fields (*navigable).
     ** *all - include all fields
    ** *navigable - include just navigable fields
    ** summary,comment - include just the summary and comments
    ** -comment - include everything except comments (the default is *all for get-issue)
    ** *all,-comment - include everything except comments
    */
    fields?: string;
    /**
     * The expand param is used to include, hidden by default, parts of response. This can be used to include:
     ** renderedFields - field values in HTML format
    ** names - display name of each field
    ** schema - schema for each field which describes a type of the field
    ** transitions - all possible transitions for the given issue
    ** operations - all possibles operations which may be applied on issue
    ** editmeta - information about how each field may be edited. It contains field's schema as well.
    ** changelog - history of all changes of the given issue
    ** versionedRepresentations - REST representations of all fields. Some field may contain more recent versions. RESET representations are numbered. The greatest number always represents the most recent version. It is recommended that the most recent version is used. version for these fields which provide a more recent REST representation. After including versionedRepresentations "fields" field become hidden.
    */
    expand?: string[];
    /**
     * The properties param is similar to fields and specifies a comma-separated list of issue properties to include. Unlike fields, properties are not included by default. To include them all send ?properties=*all. You can also include only specified properties or exclude some properties with a minus (-) sign.
     ** *all - include all properties
    ** *all, -prop1 - include all properties except prop1
    ** prop1, prop1 - include prop1 and prop2 properties
    */
    properties?: string;
    updateHistory?: boolean;
}
export interface GetIssueResponseOK extends IssueResponse {
}
export declare type GetIssueResponseError = undefined;
export interface DeleteIssueRequest extends HeadersOption, ErrorStrategyOption {
    issueIdOrKey: string | number;
    /**
     * a String of true or false indicating that any subtasks should also be deleted. If the issue has no subtasks this parameter is ignored. If the issue has subtasks and this parameter is missing or false, then the issue will not be deleted and an error will be returned.
     */
    deleteSubtasks?: string;
}
export declare type DeleteIssueResponseOK = undefined;
export declare type DeleteIssueResponseError = undefined;
export interface EditIssueRequest extends HeadersOption, ErrorStrategyOption {
    issueIdOrKey: string | number;
    /**
     * send the email with notification that the issue was updated to users that watch it. Admin or project admin permissions are required to disable the notification.
     */
    notifyUsers?: boolean;
    body: {
        transition?: IdProperty;
        fields?: FieldsEditIssue;
        update?: Record<string, {
            set?: any;
            edit?: any;
            add?: any;
            remove?: any;
        }[]>;
        historyMetadata?: HistoryMetadata;
        properties?: EntityProperty[];
        [x: string]: any;
    };
}
export declare type EditIssueResponseOK = undefined;
export declare type EditIssueResponseError = undefined;
export interface AssignIssueRequest extends HeadersOption, ErrorStrategyOption {
    issueIdOrKey: string | number;
    body: {
        /**
         * name of the user
         */
        name: string;
    };
}
export declare type AssignIssueResponseOK = undefined;
export declare type AssignIssueResponseError = undefined;
export interface SendNotificationForIssueRequest extends HeadersOption, ErrorStrategyOption {
    issueIdOrKey: string | number;
    body: {
        subject?: string;
        textBody?: string;
        htmlBody?: string;
        to?: {
            reporter: boolean;
            assignee: boolean;
            watchers: boolean;
            voters: boolean;
            users?: NameProperty[];
            groups?: NameProperty[];
        };
        restrict?: {
            groups?: NameProperty[];
            permissions?: {
                id?: string;
                key?: string;
            }[];
        };
    };
}
export declare type SendNotificationForIssueResponseOK = undefined;
export declare type SendNotificationForIssueResponseError = undefined;
//# sourceMappingURL=issue.d.ts.map