/*!
 * Copyright Adaptavist 2022 (c) All rights reserved
 */
import { HeadersOption } from '@managed-api/commons-core';
import { Worklog, Worklogs } from '../../definitions/worklog';
import { WorklogIds } from '../../definitions/worklog_ids';
import { ErrorStrategyOption } from '../../errorStrategy';
export interface GetIssueWorklogsRequest extends HeadersOption, ErrorStrategyOption {
    issueIdOrKey: string | number;
}
export interface GetIssueWorklogsResponseOK extends Worklogs {
}
export declare type GetIssueWorklogsResponseError = undefined;
export interface AddIssueWorklogRequest extends HeadersOption, ErrorStrategyOption {
    issueIdOrKey: string | number;
    /**
     * (optional) allows you to provide specific instructions to update the remaining time estimate of the issue.
     * "new" - sets the estimate to a specific value
     * "leave"- leaves the estimate as is
     * "manual" - specify a specific amount to increase remaining estimate by
     * "auto"- Default option. Will automatically adjust the value based on the new timeSpent specified on the worklog
     */
    adjustEstimate?: 'new' | 'leave' | 'manual' | 'auto';
    /**
     * (required when "new" is selected for adjustEstimate) the new value for the remaining estimate field. e.g. "2d"
     */
    newEstimate?: string;
    /**
     * (required when "manual" is selected for adjustEstimate) the amount to reduce the remaining estimate by e.g. "2d"
     */
    reduceBy?: string;
    body: {
        comment?: string;
        visibility?: {
            type?: 'group' | 'role';
            value?: string;
        };
        started?: string;
        timeSpent?: string;
        timeSpentSeconds?: number;
    };
}
export interface AddIssueWorklogResponseOK extends Worklog {
}
export declare type AddIssueWorklogResponseError = undefined;
export interface GetIssueWorklogRequest extends HeadersOption, ErrorStrategyOption {
    issueIdOrKey: string | number;
    id: string;
}
export interface GetIssueWorklogResponseOK extends Worklog {
}
export declare type GetIssueWorklogResponseError = undefined;
export interface UpdateIssueWorklogRequest extends HeadersOption, ErrorStrategyOption {
    issueIdOrKey: string | number;
    id: string;
    /**
     * (optional) allows you to provide specific instructions to update the remaining time estimate of the issue.
     * "new" - sets the estimate to a specific value
     * "leave"- leaves the estimate as is
     * "auto"- Default option. Will automatically adjust the value based on the new timeSpent specified on the worklog
     */
    adjustEstimate?: 'new' | 'leave' | 'auto';
    /**
     * (required when "new" is selected for adjustEstimate) the new value for the remaining estimate field. e.g. "2d"
     */
    newEstimate?: string;
    body: {
        comment?: string;
        visibility?: {
            type?: 'group' | 'role';
            value?: string;
        };
        started?: string;
        timeSpent?: string;
        timeSpentSeconds?: number;
    };
}
export interface UpdateIssueWorklogResponseOK extends Worklog {
}
export declare type UpdateIssueWorklogResponseError = undefined;
export interface DeleteIssueWorklogRequest extends HeadersOption, ErrorStrategyOption {
    issueIdOrKey: string | number;
    id: string;
    /**
     * (optional) allows you to provide specific instructions to update the remaining time estimate of the issue.
     * "new" - sets the estimate to a specific value
     * "leave"- leaves the estimate as is
     * "manual" - specify a specific amount to increase remaining estimate by
     * "auto"- Default option. Will automatically adjust the value based on the new timeSpent specified on the worklog
     */
    adjustEstimate?: 'new' | 'leave' | 'manual' | 'auto';
    /**
     * (required when "new" is selected for adjustEstimate) the new value for the remaining estimate field. e.g. "2d"
     */
    newEstimate?: string;
    /**
     * (required when "manual" is selected for adjustEstimate) the amount to increase the remaining estimate by e.g. "2d"
     */
    increaseBy?: string;
}
export declare type DeleteIssueWorklogResponseOK = undefined;
export declare type DeleteIssueWorklogResponseError = undefined;
export interface GetDeletedIssueWorklogIdsRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * a date time in unix timestamp format since when deleted worklogs will be returned.
     */
    since?: number;
}
export interface GetDeletedIssueWorklogIdsResponseOK extends WorklogIds {
}
export declare type GetDeletedIssueWorklogIdsResponseError = undefined;
export interface GetIssueWorklogsForIdsRequest extends HeadersOption, ErrorStrategyOption {
    body: {
        ids: number[];
    };
}
export interface GetIssueWorklogsForIdsResponseOK extends Array<Worklog> {
}
export declare type GetIssueWorklogsForIdsResponseError = undefined;
export interface GetUpdatedIssueWorklogIdsRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * a date time in unix timestamp format since when updated worklogs will be returned.
     */
    since?: number;
}
export interface GetUpdatedIssueWorklogIdsResponseOK extends WorklogIds {
}
export declare type GetUpdatedIssueWorklogIdsResponseError = undefined;
//# sourceMappingURL=worklog.d.ts.map