/*!
 * Copyright Adaptavist 2022 (c) All rights reserved
 */
import { HeadersOption } from '@managed-api/commons-core';
import { Component } from '../definitions/component';
import { CreateResponse } from '../definitions/create_response';
import { Project } from '../definitions/project';
import { ProjectStatuses } from '../definitions/project_status';
import { ProjectVersions } from '../definitions/project_version';
import { Version } from '../definitions/version';
import { ErrorStrategyOption } from '../errorStrategy';
export interface GetProjectsRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * the parameters to expand
     */
    expand?: string[];
    /**
     * if this parameter is set then only projects recently accessed by the current user (if not logged in then based on HTTP session) will be returned (maximum count limited to the specified number but no more than 20).
     */
    recent?: number;
    /**
     * whether to include archived projects in response, default: false
     */
    includeArchived?: boolean;
}
export interface GetProjectsResponseOK extends Array<Project> {
}
export declare type GetProjectsResponseError = undefined;
export interface CreateProjectRequest extends HeadersOption, ErrorStrategyOption {
    body: {
        key: string;
        name: string;
        projectTypeKey: string;
        projectTemplateKey?: string;
        lead: string;
        description?: string;
        url?: string;
        assigneeType?: 'PROJECT_LEAD' | 'UNASSIGNED';
        avatarId?: number;
        issueSecurityScheme?: number;
        permissionScheme?: number;
        notificationScheme?: number;
        categoryId?: number;
    };
}
export interface CreateProjectResponseOK extends CreateResponse {
}
export declare type CreateProjectResponseError = undefined;
export interface GetProjectRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * the parameters to expand
     */
    expand?: string[];
    projectIdOrKey: string;
}
export interface GetProjectResponseOK extends Project {
}
export declare type GetProjectResponseError = undefined;
export interface UpdateProjectRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * the parameters to expand in returned project
     */
    expand?: string[];
    projectIdOrKey: string;
    body: {
        key?: string;
        name?: string;
        description?: string;
        lead?: string;
        url?: string;
        assigneeType?: 'PROJECT_LEAD' | 'UNASSIGNED';
        avatarId?: number;
        issueSecurityScheme?: number;
        permissionScheme?: number;
        notificationScheme?: number;
        categoryId?: number;
    };
}
export interface UpdateProjectResponseOK extends Project {
}
export declare type UpdateProjectResponseError = undefined;
export interface DeleteProjectRequest extends HeadersOption, ErrorStrategyOption {
    projectIdOrKey: string;
}
export declare type DeleteProjectResponseOK = undefined;
export declare type DeleteProjectResponseError = undefined;
export interface ArchiveProjectRequest extends HeadersOption, ErrorStrategyOption {
    projectIdOrKey: string;
}
export declare type ArchiveProjectResponseOK = undefined;
export declare type ArchiveProjectResponseError = undefined;
export interface GetProjectComponentsRequest extends HeadersOption, ErrorStrategyOption {
    projectIdOrKey: string;
}
export interface GetProjectComponentsResponseOK extends Array<Component> {
}
export declare type GetProjectComponentsResponseError = undefined;
export interface RestoreProjectRequest extends HeadersOption, ErrorStrategyOption {
    projectIdOrKey: string;
}
export declare type RestoreProjectResponseOK = undefined;
export declare type RestoreProjectResponseError = undefined;
export interface GetProjectStatusesRequest extends HeadersOption, ErrorStrategyOption {
    projectIdOrKey: string;
}
export interface GetProjectStatusesResponseOK extends Array<ProjectStatuses> {
}
export declare type GetProjectStatusesResponseError = undefined;
export interface UpdateProjectTypeRequest extends HeadersOption, ErrorStrategyOption {
    projectIdOrKey: string;
    newProjectTypeKey: string;
}
export interface UpdateProjectTypeResponseOK extends Project {
}
export declare type UpdateProjectTypeResponseError = undefined;
export interface GetProjectVersionsPaginatedRequest extends HeadersOption, ErrorStrategyOption {
    projectIdOrKey: string;
    /**
     * the page offset, if not specified then defaults to 0
     */
    startAt?: number;
    /**
     * how many results on the page should be included. Defaults to 50.
     */
    maxResults?: number;
    /**
     * ordering of the results.
     */
    orderBy?: '-sequence' | 'sequence' | '+sequence' | '-name' | 'name' | '+name' | '-startDate' | 'startDate' | '+startDate' | '-releaseDate' | 'releaseDate' | '+sequence';
    /**
     * the parameters to expand
     */
    expand?: string[];
}
export interface GetProjectVersionsPaginatedResponseOK extends ProjectVersions {
}
export declare type GetProjectVersionsPaginatedResponseError = undefined;
export interface GetProjectVersionsRequest extends HeadersOption, ErrorStrategyOption {
    projectIdOrKey: string;
    /**
     * the parameters to expand
     */
    expand?: string[];
}
export interface GetProjectVersionsResponseOK extends Array<Version> {
}
export declare type GetProjectVersionsResponseError = undefined;
//# sourceMappingURL=project.d.ts.map