/*!
 * Copyright Adaptavist 2022 (c) All rights reserved
 */
import { HeadersOption } from '@managed-api/commons-core';
import { SimpleLink } from '../../definitions/simple_link';
import { Version } from '../../definitions/version';
import { ErrorStrategyOption } from '../../errorStrategy';
export interface CreateProjectVersionRequest extends HeadersOption, ErrorStrategyOption {
    body: {
        name: string;
        description?: string;
        archived?: boolean;
        released?: boolean;
        /**
         * Format: DD/MMM/YYYY
         */
        userStartDate?: string;
        /**
         * Format: DD/MMM/YYYY
         */
        userReleaseDate?: string;
        /**
         * Either this or projectId is required.
         */
        project?: string;
        /**
         * Either this or project is required.
         */
        projectId?: number;
    };
}
export interface CreateProjectVersionResponseOK extends Version {
}
export declare type CreateProjectVersionResponseError = undefined;
export interface MoveProjectVersionRequest extends HeadersOption, ErrorStrategyOption {
    id: string;
    body: {
        /**
         * A version to place this version after. The value should be the self link of another version
         */
        after?: string;
        /**
         * An absolute position, which may have a value of 'First', 'Last', 'Earlier' or 'Later'
         */
        position?: 'Earlier' | 'Later' | 'First' | 'Last';
    };
}
export interface MoveProjectVersionResponseOK extends Version {
}
export declare type MoveProjectVersionResponseError = undefined;
export interface GetProjectVersionRequest extends HeadersOption, ErrorStrategyOption {
    id: string;
    expand?: string[];
}
export interface GetProjectVersionResponseOK extends Version {
}
export declare type GetProjectVersionResponseError = undefined;
export interface UpdateProjectVersionRequest extends HeadersOption, ErrorStrategyOption {
    id: string;
    body: {
        description?: string;
        name?: string;
        archived?: boolean;
        released?: boolean;
        /**
         * Format: DD/MMM/YYYY
         */
        userStartDate?: string;
        /**
         * Format: DD/MMM/YYYY
         */
        userReleaseDate?: string;
        moveUnfixedIssuesTo?: string;
        operations?: SimpleLink[];
        remotelinks?: {
            name?: string;
            link?: any;
        }[];
    };
}
export interface UpdateProjectVersionResponseOK extends Version {
}
export declare type UpdateProjectVersionResponseError = undefined;
export interface DeleteProjectVersionRequest extends HeadersOption, ErrorStrategyOption {
    id: string;
    /**
     * The version to set fixVersion to on issues where the deleted version is the fix version, If null then the fixVersion is removed.
     */
    moveFixIssuesTo?: string;
    /**
     * The version to set affectedVersion to on issues where the deleted version is the affected version, If null then the affectedVersion is removed.
     */
    moveAffectedIssuesTo?: string;
}
export declare type DeleteProjectVersionResponseOK = undefined;
export declare type DeleteProjectVersionResponseError = undefined;
export interface MergeProjectVersionRequest extends HeadersOption, ErrorStrategyOption {
    id: string;
    moveIssuesTo: string;
}
export declare type MergeProjectVersionResponseOK = undefined;
export declare type MergeProjectVersionResponseError = undefined;
export interface RemoveAndReplaceProjectVersionRequest extends HeadersOption, ErrorStrategyOption {
    id: string;
    body: {
        moveFixIssuesTo?: string;
        moveAffectedIssuesTo?: string;
    };
}
export declare type RemoveAndReplaceProjectVersionResponseOK = undefined;
export declare type RemoveAndReplaceProjectVersionResponseError = undefined;
//# sourceMappingURL=version.d.ts.map