/*!
 * Copyright Adaptavist 2022 (c) All rights reserved
 */
import { HeadersOption } from '@managed-api/commons-core';
import { UserFull } from '../../definitions/user';
import { ErrorStrategyOption } from '../../errorStrategy';
export interface FindAssignableUsersRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * the username
     */
    username?: string;
    /**
     * the key of the project we are finding assignable users for
     */
    project?: string;
    /**
     * the issue key for the issue being edited we need to find assignable users for.
     */
    issueKey?: string;
    /**
     * the index of the first user to return (0-based)
     */
    startAt?: number;
    /**
     * the maximum number of users to return (defaults to 50). The maximum allowed value is 1000. If you specify a value that is higher than this number, your search results will be truncated.
     */
    maxResults?: number;
    actionDescriptorId?: number;
}
export interface FindAssignableUsersResponseOK extends Array<UserFull> {
}
export declare type FindAssignableUsersResponseError = undefined;
export interface FindUsersWithAllPermissionsRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * comma separated list of permissions for project or issue returned users must have, see Permissions JavaDoc for the list of all possible permissions.
     */
    permissions: string;
    /**
     * the username filter, list includes all users if unspecified
     */
    username?: string;
    /**
     * the issue key for the issue for which returned users have specified permissions.
     */
    issueKey?: string;
    /**
     * the optional project key to search for users with if no issueKey is supplied.
     */
    projectKey?: string;
    /**
     * the index of the first user to return (0-based)
     */
    startAt?: number;
    /**
     * the maximum number of users to return (defaults to 50). The maximum allowed value is 1000. If you specify a value that is higher than this number, your search results will be truncated.
     */
    maxResults?: number;
}
export interface FindUsersWithAllPermissionsResponseOK extends Array<UserFull> {
}
export declare type FindUsersWithAllPermissionsResponseError = undefined;
export interface FindUsersRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * A query string used to search username, name or e-mail address
     */
    username: string;
    /**
     * the index of the first user to return (0-based)
     */
    startAt?: number;
    /**
     * the maximum number of users to return (defaults to 50). The maximum allowed value is 1000. If you specify a value that is higher than this number, your search results will be truncated.
     */
    maxResults?: number;
    /**
     * If true, then active users are included in the results (default true)
     */
    includeActive?: boolean;
    /**
     * If true, then inactive users are included in the results (default false)
     */
    includeInactive?: boolean;
}
export interface FindUsersResponseOK extends Array<UserFull> {
}
export declare type FindUsersResponseError = undefined;
export interface FindUsersWithBrowsePermissionRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * the username filter, no users returned if left blank
     */
    username: string;
    /**
     * the issue key for the issue being edited we need to find viewable users for.
     */
    issueKey?: string;
    /**
     * the optional project key to search for users with if no issueKey is supplied.
     */
    projectKey?: string;
    /**
     * the index of the first user to return (0-based)
     */
    startAt?: number;
    /**
     * the maximum number of users to return (defaults to 50). The maximum allowed value is 1000. If you specify a value that is higher than this number, your search results will be truncated.
     */
    maxResults?: number;
}
export interface FindUsersWithBrowsePermissionResponseOK extends Array<UserFull> {
}
export declare type FindUsersWithBrowsePermissionResponseError = undefined;
//# sourceMappingURL=search.d.ts.map