/*!
* Copyright Adaptavist 2022 (c) All rights reserved
*/
import { Headers, Response, BaseApiCore, ErrorStrategyOptionType, PlatformImplementation } from '@managed-api/commons-core';
import { AssignIssueRequest, AssignIssueResponseOK, CreateIssueRequest, CreateIssueResponseOK, DeleteIssueRequest, DeleteIssueResponseOK, EditIssueRequest, EditIssueResponseOK, GetIssueRequest, GetIssueResponseOK, SendNotificationForIssueRequest, SendNotificationForIssueResponseOK } from './types/issue';
import { AddIssueCommentRequest, AddIssueCommentResponseOK, DeleteIssueCommentRequest, DeleteIssueCommentResponseOK, GetIssueCommentRequest, GetIssueCommentResponseOK, GetIssueCommentsRequest, GetIssueCommentsResponseOK, UpdateIssueCommentRequest, UpdateIssueCommentResponseOK } from './types/issue/comment';
import { CustomError } from './common';
import { CommonError, ErrorStrategyHandlers, ErrorStrategyOption } from './errorStrategy';
import { ErrorStrategyBuilder } from './builders/errorStrategy';
import { GetApplicationRoleRequest, GetApplicationRoleResponseOK, GetApplicationRolesRequest, GetApplicationRolesResponseOK, UpdateApplicationRoleRequest, UpdateApplicationRoleResponseOK } from './types/application/role';
import { GetWorkflowsRequest, GetWorkflowsResponseOK } from './types/workflow';
import { GetWorkflowStatusCategoriesRequest, GetWorkflowStatusCategoriesResponseOK, GetWorkflowStatusCategoryRequest, GetWorkflowStatusCategoryResponseOK } from './types/workflow/status/category';
import { GetWorkflowStatusesRequest, GetWorkflowStatusesResponseOK, GetWorkflowStatusRequest, GetWorkflowStatusResponseOK } from './types/workflow/status';
import { CreateWorkflowSchemeRequest, CreateWorkflowSchemeResponseOK, DeleteWorkflowSchemeRequest, DeleteWorkflowSchemeResponseOK, GetWorkflowSchemeRequest, GetWorkflowSchemeResponseOK, UpdateWorkflowSchemeRequest, UpdateWorkflowSchemeResponseOK } from './types/workflow/scheme';
import { GetAllDashboardsRequest, GetAllDashboardsResponseOK, GetDashboardByIdRequest, GetDashboardByIdResponseOK } from './types/dashboard';
import { AddFilterSharePermissionRequest, AddFilterSharePermissionResponseOK, DeleteFilterSharePermissionRequest, DeleteFilterSharePermissionResponseOK, GetFilterSharePermissionRequest, GetFilterSharePermissionResponseOK, GetFilterSharePermissionsRequest, GetFilterSharePermissionsResponseOK } from './types/filter/share/permission';
import { GetFilterDefaultColumnsRequest, GetFilterDefaultColumnsResponseOK, ResetFilterColumnsRequest, ResetFilterColumnsResponseOK, SetFilterDefaultColumnsRequest, SetFilterDefaultColumnsResponseOK } from './types/filter/column';
import { GetDefaultShareScopeRequest, GetDefaultShareScopeResponseOK, SetDefaultShareScopeRequest, SetDefaultShareScopeResponseOK } from './types/filter/share';
import { CreateFilterRequest, CreateFilterResponseOK, DeleteFilterRequest, DeleteFilterResponseOK, EditFilterRequest, EditFilterResponseOK, GetFilterRequest, GetFilterResponseOK, GetMyFavouriteFiltersRequest, GetMyFavouriteFiltersResponseOK } from './types/filter';
import { AddUsersToGroupRequest, AddUsersToGroupResponseOK, GetUsersFromGroupRequest, GetUsersFromGroupResponseOK, RemoveUsersFromGroupRequest, RemoveUsersFromGroupResponseOK } from './types/group/user';
import { CreateGroupRequest, CreateGroupResponseOK, RemoveGroupRequest, RemoveGroupResponseOK } from './types/group';
import { GetAdvancedSettingsRequest, GetAdvancedSettingsResponseOK, GetApplicationPropertyRequest, GetApplicationPropertyResponseOK, GetInstanceConfigurationRequest, GetInstanceConfigurationResponseOK, GetInstanceInfoRequest, GetInstanceInfoResponseOK, SetApplicationPropertyRequest, SetApplicationPropertyResponseOK } from './types/instance';
import { DeleteIssueCommentPropertyRequest, DeleteIssueCommentPropertyResponseOK, GetIssueCommentPropertyKeysRequest, GetIssueCommentPropertyKeysResponseOK, GetIssueCommentPropertyRequest, GetIssueCommentPropertyResponseOK, SetIssueCommentPropertyRequest, SetIssueCommentPropertyResponseOK } from './types/issue/comment/property';
import { GetIssueAttachmentMetadataRequest, GetIssueAttachmentMetadataResponseOK } from './types/issue/attachment/metadata';
import { AddIssueAttachmentRequest, AddIssueAttachmentResponseOK, GetIssueAttachmentRequest, GetIssueAttachmentResponseOK, RemoveIssueAttachmentRequest, RemoveIssueAttachmentResponseOK } from './types/issue/attachment';
import { GetIssueCustomFieldOptionRequest, GetIssueCustomFieldOptionResponseOK } from './types/issue/field/custom/option';
import { GetIssueCustomFieldsRequest, GetIssueCustomFieldsResponseOK } from './types/issue/field/custom';
import { GetIssueFieldsRequest, GetIssueFieldsResponseOK } from './types/issue/field';
import { CreateIssueLinkTypeRequest, CreateIssueLinkTypeResponseOK, DeleteIssueLinkTypeRequest, DeleteIssueLinkTypeResponseOK, GetIssueLinkTypeRequest, GetIssueLinkTypeResponseOK, GetIssueLinkTypesRequest, GetIssueLinkTypesResponseOK, UpdateIssueLinkTypeRequest, UpdateIssueLinkTypeResponseOK } from './types/issue/link/type';
import { CreateOrUpdateRemoteIssueLinkRequest, CreateOrUpdateRemoteIssueLinkResponseOK, DeleteRemoteIssueLinkByGlobalIdRequest, DeleteRemoteIssueLinkByGlobalIdResponseOK, DeleteRemoteIssueLinkRequest, DeleteRemoteIssueLinkResponseOK, GetRemoteIssueLinkRequest, GetRemoteIssueLinkResponseOK, GetRemoteIssueLinksRequest, GetRemoteIssueLinksResponseOK, UpdateRemoteIssueLinkRequest, UpdateRemoteIssueLinkResponseOK } from './types/issue/link/remote';
import { CreateIssueLinkRequest, CreateIssueLinkResponseOK, DeleteIssueLinkRequest, DeleteIssueLinkResponseOK, GetIssueLinkRequest, GetIssueLinkResponseOK } from './types/issue/link';
import { GetCreateIssueMetadataRequest, GetCreateIssueMetadataResponseOK, GetEditIssueMetadataRequest, GetEditIssueMetadataResponseOK } from './types/issue/metadata';
import { CreateIssuePrioritySchemeRequest, CreateIssuePrioritySchemeResponseOK, DeleteIssuePrioritySchemeRequest, DeleteIssuePrioritySchemeResponseOK, GetIssuePrioritySchemeRequest, GetIssuePrioritySchemeResponseOK, GetIssuePrioritySchemesRequest, GetIssuePrioritySchemesResponseOK, UpdateIssuePrioritySchemeRequest, UpdateIssuePrioritySchemeResponseOK } from './types/issue/priority/scheme';
import { GetIssuePrioritiesRequest, GetIssuePrioritiesResponseOK, GetIssuePriorityRequest, GetIssuePriorityResponseOK } from './types/issue/priority';
import { DeleteIssuePropertyRequest, DeleteIssuePropertyResponseOK, GetIssuePropertyKeysRequest, GetIssuePropertyKeysResponseOK, GetIssuePropertyRequest, GetIssuePropertyResponseOK, SetIssuePropertyRequest, SetIssuePropertyResponseOK } from './types/issue/property';
import { GetIssueResolutionRequest, GetIssueResolutionResponseOK, GetIssueResolutionsRequest, GetIssueResolutionsResponseOK } from './types/issue/resolution';
import { SearchIssuesByJqlRequest, SearchIssuesByJqlResponseOK } from './types/issue/search';
import { CanMoveIssueSubTaskRequest, CanMoveIssueSubTaskResponseOK, GetIssueSubTasksRequest, GetIssueSubTasksResponseOK, MoveIssueSubTasksRequest, MoveIssueSubTasksResponseOK } from './types/issue/subtask';
import { GetIssueTransitionsRequest, GetIssueTransitionsResponseOK, PerformIssueTransitionRequest, PerformIssueTransitionResponseOK } from './types/issue/transition';
import { AddProjectAssociationsToIssueTypeSchemeRequest, AddProjectAssociationsToIssueTypeSchemeResponseOK, GetProjectAssociationsForIssueTypeSchemeRequest, GetProjectAssociationsForIssueTypeSchemeResponseOK, RemoveProjectAssociationForIssueTypeSchemeRequest, RemoveProjectAssociationForIssueTypeSchemeResponseOK, RemoveProjectAssociationsForIssueTypeSchemeRequest, RemoveProjectAssociationsForIssueTypeSchemeResponseOK, SetProjectAssociationsForIssueTypeSchemeRequest, SetProjectAssociationsForIssueTypeSchemeResponseOK } from './types/issue/type/scheme/project';
import { CreateIssueTypeSchemeRequest, CreateIssueTypeSchemeResponseOK, DeleteIssueTypeSchemeRequest, DeleteIssueTypeSchemeResponseOK, GetIssueTypeSchemeRequest, GetIssueTypeSchemeResponseOK, GetIssueTypeSchemesRequest, GetIssueTypeSchemesResponseOK, UpdateIssueTypeSchemeRequest, UpdateIssueTypeSchemeResponseOK } from './types/issue/type/scheme';
import { CreateIssueTypeRequest, CreateIssueTypeResponseOK, DeleteIssueTypeRequest, DeleteIssueTypeResponseOK, GetAlternativeIssueTypesRequest, GetAlternativeIssueTypesResponseOK, GetIssueTypeRequest, GetIssueTypeResponseOK, GetIssueTypesRequest, GetIssueTypesResponseOK, UpdateIssueTypeRequest, UpdateIssueTypeResponseOK } from './types/issue/type';
import { AddIssueVoteRequest, AddIssueVoteResponseOK, GetIssueVotesRequest, GetIssueVotesResponseOK, RemoveIssueVoteRequest, RemoveIssueVoteResponseOK } from './types/issue/vote';
import { AddIssueWatcherRequest, AddIssueWatcherResponseOK, GetIssueWatchersRequest, GetIssueWatchersResponseOK, RemoveIssueWatcherRequest, RemoveIssueWatcherResponseOK } from './types/issue/watcher';
import { AddIssueWorklogRequest, AddIssueWorklogResponseOK, DeleteIssueWorklogRequest, DeleteIssueWorklogResponseOK, GetDeletedIssueWorklogIdsRequest, GetDeletedIssueWorklogIdsResponseOK, GetIssueWorklogRequest, GetIssueWorklogResponseOK, GetIssueWorklogsForIdsRequest, GetIssueWorklogsForIdsResponseOK, GetIssueWorklogsRequest, GetIssueWorklogsResponseOK, GetUpdatedIssueWorklogIdsRequest, GetUpdatedIssueWorklogIdsResponseOK, UpdateIssueWorklogRequest, UpdateIssueWorklogResponseOK } from './types/issue/worklog';
import { GetIssueSecuritySchemeRequest, GetIssueSecuritySchemeResponseOK, GetIssueSecuritySchemesRequest, GetIssueSecuritySchemesResponseOK } from './types/issue/security/scheme';
import { GetNotificationSchemeRequest, GetNotificationSchemeResponseOK, GetNotificationSchemesRequest, GetNotificationSchemesResponseOK } from './types/issue/notification/scheme';
import { GetCurrentUserRequest, GetCurrentUserResponseOK, GetMyPreferenceRequest, GetMyPreferenceResponseOK, RemoveMyPreferenceRequest, RemoveMyPreferenceResponseOK, SetMyPreferenceRequest, SetMyPreferenceResponseOK } from './types/myself';
import { CreatePermissionSchemeGrantRequest, CreatePermissionSchemeGrantResponseOK, DeletePermissionSchemeGrantRequest, DeletePermissionSchemeGrantResponseOK, GetPermissionSchemeGrantRequest, GetPermissionSchemeGrantResponseOK, GetPermissionSchemeGrantsRequest, GetPermissionSchemeGrantsResponseOK } from './types/permission/scheme/grant';
import { GetPermissionSchemeAttributeRequest, GetPermissionSchemeAttributeResponseOK } from './types/permission/scheme/attribute';
import { CreatePermissionSchemeRequest, CreatePermissionSchemeResponseOK, DeletePermissionSchemeRequest, DeletePermissionSchemeResponseOK, GetPermissionSchemeRequest, GetPermissionSchemeResponseOK, GetPermissionSchemesRequest, GetPermissionSchemesResponseOK, UpdatePermissionSchemeRequest, UpdatePermissionSchemeResponseOK } from './types/permission/scheme';
import { GetMyPermissionsRequest, GetMyPermissionsResponseOK, GetPermissionsRequest, GetPermissionsResponseOK } from './types/permission';
import { CreateProjectComponentRequest, CreateProjectComponentResponseOK, DeleteProjectComponentRequest, DeleteProjectComponentResponseOK, GetProjectComponentRelatedIssueCountRequest, GetProjectComponentRelatedIssueCountResponseOK, GetProjectComponentRequest, GetProjectComponentResponseOK, UpdateProjectComponentRequest, UpdateProjectComponentResponseOK } from './types/project/component';
import { AddProjectRoleActorUsersRequest, AddProjectRoleActorUsersResponseOK, DeleteProjectRoleActorRequest, DeleteProjectRoleActorResponseOK, SetProjectRoleActorsRequest, SetProjectRoleActorsResponseOK } from './types/project/role/actor';
import { GetProjectRoleRequest, GetProjectRoleResponseOK, GetProjectRolesRequest, GetProjectRolesResponseOK } from './types/project/role';
import { GetProjectSecurityLevelsRequest, GetProjectSecurityLevelsResponseOK } from './types/project/security';
import { GetAccessibleProjectTypeRequest, GetAccessibleProjectTypeResponseOK, GetProjectTypeRequest, GetProjectTypeResponseOK, GetProjectTypesRequest, GetProjectTypesResponseOK } from './types/project/type';
import { ValidateProjectKeyRequest, ValidateProjectKeyResponseOK } from './types/project/validation';
import { CreateOrUpdateRemoteVersionLinkByIdRequest, CreateOrUpdateRemoteVersionLinkByIdResponseOK, CreateOrUpdateRemoteVersionLinkRequest, CreateOrUpdateRemoteVersionLinkResponseOK, DeleteRemoteVersionLinkRequest, DeleteRemoteVersionLinkResponseOK, DeleteRemoteVersionLinksByIdRequest, DeleteRemoteVersionLinksByIdResponseOK, GetRemoteVersionLinkRequest, GetRemoteVersionLinkResponseOK, GetRemoteVersionLinksByIdRequest, GetRemoteVersionLinksByIdResponseOK, GetRemoteVersionLinksRequest, GetRemoteVersionLinksResponseOK } from './types/project/version/remote';
import { GetProjectVersionRelatedIssueCountRequest, GetProjectVersionRelatedIssueCountResponseOK, GetProjectVersionUnresolvedIssueCountRequest, GetProjectVersionUnresolvedIssueCountResponseOK } from './types/project/version/count';
import { CreateProjectVersionRequest, CreateProjectVersionResponseOK, DeleteProjectVersionRequest, DeleteProjectVersionResponseOK, GetProjectVersionRequest, GetProjectVersionResponseOK, MergeProjectVersionRequest, MergeProjectVersionResponseOK, MoveProjectVersionRequest, MoveProjectVersionResponseOK, RemoveAndReplaceProjectVersionRequest, RemoveAndReplaceProjectVersionResponseOK, UpdateProjectVersionRequest, UpdateProjectVersionResponseOK } from './types/project/version';
import { GetProjectIssueSecuritySchemeRequest, GetProjectIssueSecuritySchemeResponseOK } from './types/project/issue/security/scheme';
import { GetProjectNotificationSchemeRequest, GetProjectNotificationSchemeResponseOK } from './types/project/notification/scheme';
import { GetProjectPermissionSchemeRequest, GetProjectPermissionSchemeResponseOK } from './types/project/permission/scheme';
import { GetPrioritySchemeRequest, GetPrioritySchemeResponseOK } from './types/project/priority/scheme';
import { AddScreenTabResponseOK, AddScreenTabRequest, GetScreenTabsRequest, GetScreenTabsResponseOK, RenameScreenTabResponseOK, RenameScreenTabRequest, DeleteScreenTabRequest, DeleteScreenTabResponseOK, MoveScreenTabRequest, MoveScreenTabResponseOK } from './types/screen/tab';
import { ArchiveProjectRequest, ArchiveProjectResponseOK, CreateProjectRequest, CreateProjectResponseOK, DeleteProjectRequest, DeleteProjectResponseOK, GetProjectComponentsRequest, GetProjectComponentsResponseOK, GetProjectRequest, GetProjectResponseOK, GetProjectsRequest, GetProjectsResponseOK, GetProjectStatusesRequest, GetProjectStatusesResponseOK, GetProjectVersionsPaginatedRequest, GetProjectVersionsPaginatedResponseOK, GetProjectVersionsRequest, GetProjectVersionsResponseOK, RestoreProjectRequest, RestoreProjectResponseOK, UpdateProjectRequest, UpdateProjectResponseOK, UpdateProjectTypeRequest, UpdateProjectTypeResponseOK } from './types/project';
import { AddFieldToDefaultScreenRequest, AddFieldToDefaultScreenResponseOK, AddScreenFieldRequest, AddScreenFieldResponseOK, GetScreenFieldsRequest, GetScreenFieldsResponseOK, MoveScreenFieldRequest, MoveScreenFieldResponseOK, RemoveScreenFieldRequest, RemoveScreenFieldResponseOK } from './types/screen/field';
import { GetScreenFieldsToAddRequest, GetScreenFieldsToAddResponseOK, GetScreensRequest, GetScreensResponseOK } from './types/screen';
import { FindAssignableUsersRequest, FindAssignableUsersResponseOK, FindUsersRequest, FindUsersResponseOK, FindUsersWithAllPermissionsRequest, FindUsersWithAllPermissionsResponseOK, FindUsersWithBrowsePermissionRequest, FindUsersWithBrowsePermissionResponseOK } from './types/user/search';
import { AddUserToApplicationRequest, AddUserToApplicationResponseOK, ChangeUserPasswordRequest, ChangeUserPasswordResponseOK, CreateUserRequest, CreateUserResponseOK, GetUserRequest, GetUserResponseOK, RemoveUserFromApplicationRequest, RemoveUserFromApplicationResponseOK, RemoveUserRequest, RemoveUserResponseOK, UpdateUserRequest, UpdateUserResponseOK } from './types/user';
import { CreateGlobalProjectRoleRequest, CreateGlobalProjectRoleResponseOK, DeleteGlobalProjectRoleRequest, DeleteGlobalProjectRoleResponseOK, GetGlobalProjectRoleRequest, GetGlobalProjectRoleResponseOK, GetGlobalProjectRolesRequest, GetGlobalProjectRolesResponseOK, UpdateGlobalProjectRoleFullyRequest, UpdateGlobalProjectRoleFullyResponseOK, UpdateGlobalProjectRolePartiallyRequest, UpdateGlobalProjectRolePartiallyResponseOK } from './types/role/project';
import { AddGlobalProjectRoleActorsRequest, AddGlobalProjectRoleActorsResponseOK, DeleteGlobalProjectRoleActorsRequest, DeleteGlobalProjectRoleActorsResponseOK, GetGlobalProjectRoleActorsRequest, GetGlobalProjectRoleActorsResponseOK } from './types/role/project/actor';
export interface JiraOnPremApiCoreOptions extends ErrorStrategyOption {
}
declare type GetGlobalErrorStrategy = () => ErrorStrategyOptionType<CommonError, CustomError, ErrorStrategyHandlers, ErrorStrategyBuilder> | undefined;
export declare abstract class JiraOnPremApiCore extends BaseApiCore {
    private options?;
    Issue: IssueGroup;
    Application: ApplicationGroup;
    Workflow: WorkflowGroup;
    Dashboard: DashboardGroup;
    Filter: FilterGroup;
    Group: GroupGroup;
    Instance: InstanceGroup;
    Myself: MyselfGroup;
    Permission: PermissionGroup;
    Project: ProjectGroup;
    Screen: ScreenGroup;
    User: UserGroup;
    Role: RoleGroup;
    All: AllGroup;
    constructor(options?: JiraOnPremApiCoreOptions);
    setGlobalErrorStrategy(errorStrategy: ErrorStrategyOptionType<CommonError, CustomError, ErrorStrategyHandlers, ErrorStrategyBuilder>): void;
    protected buildResponse(url: string, status: number, statusText: string, headers: Headers, body?: string | ArrayBuffer): Response<any>;
    private getGlobalErrorStrategy;
}
declare class AllGroup {
    private Issue;
    private Application;
    private Workflow;
    private Dashboard;
    private Filter;
    private Group;
    private Instance;
    private Myself;
    private Permission;
    private Project;
    private Screen;
    private User;
    private Role;
    constructor(Issue: IssueGroup, Application: ApplicationGroup, Workflow: WorkflowGroup, Dashboard: DashboardGroup, Filter: FilterGroup, Group: GroupGroup, Instance: InstanceGroup, Myself: MyselfGroup, Permission: PermissionGroup, Project: ProjectGroup, Screen: ScreenGroup, User: UserGroup, Role: RoleGroup);
    /**
    * Get all the ProjectRoles available in JIRA. Currently this list is global.
    * Alternative usage: Role.Project.getRoles
    * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#role-getProjectRoles
    * @param options Request options.
    */
    getGlobalProjectRoles<T = GetGlobalProjectRolesResponseOK>(options?: GetGlobalProjectRolesRequest): Promise<GetGlobalProjectRolesResponseOK | T>;
    /**
     * Creates a new ProjectRole to be available in Jira. The created role does not have any default actors assigned.
     * Alternative usage: Role.Project.createRole
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.2/#role-createProjectRole
     * @param options Request options.
     */
    createGlobalProjectRole<T = CreateGlobalProjectRoleResponseOK>(options: CreateGlobalProjectRoleRequest): Promise<CreateGlobalProjectRoleResponseOK | T>;
    /**
     * Get a specific ProjectRole available in JIRA.
     * Alternative usage: Role.Project.getRole
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#role-getProjectRolesById
     * @param options Request options.
     */
    getGlobalProjectRole<T = GetGlobalProjectRoleResponseOK>(options: GetGlobalProjectRoleRequest): Promise<GetGlobalProjectRoleResponseOK | T>;
    /**
     * Partially updates a roles name or description.
     * Alternative usage: Role.Project.updateRolePartially
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.2/#role-partialUpdateProjectRole
     * @param options Request options.
     */
    updateGlobalProjectRolePartially<T = UpdateGlobalProjectRolePartiallyResponseOK>(options: UpdateGlobalProjectRolePartiallyRequest): Promise<UpdateGlobalProjectRolePartiallyResponseOK | T>;
    /**
     * Fully updates a roles. Both name and description must be given.
     * Alternative usage: Role.Project.updateRoleFully
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#role-getProjectRolesById
     * @param options Request options.
     */
    updateGlobalProjectRoleFully<T = UpdateGlobalProjectRoleFullyResponseOK>(options: UpdateGlobalProjectRoleFullyRequest): Promise<UpdateGlobalProjectRoleFullyResponseOK | T>;
    /**
     * Deletes a role. May return 403 in the future.
     * Alternative usage: Role.Project.deleteRole
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.2/#role-deleteProjectRole
     * @param options Request options.
     */
    deleteGlobalProjectRole<T = DeleteGlobalProjectRoleResponseOK>(options: DeleteGlobalProjectRoleRequest): Promise<DeleteGlobalProjectRoleResponseOK | T>;
    /**
     * Gets default actors for the given role.
     * Alternative usage: Role.Project.Actor.getActors
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.2/#role-getProjectRoleActorsForRole
     * @param options Request options.
     */
    getGlobalProjectRoleActors<T = GetGlobalProjectRoleActorsResponseOK>(options: GetGlobalProjectRoleActorsRequest): Promise<GetGlobalProjectRoleActorsResponseOK | T>;
    /**
     * Adds default actors to the given role. The request data should contain a list of usernames or a list of groups to add.
     * Alternative usage: Role.Project.Actor.addActors
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.2/#role-addProjectRoleActorsToRole
     * @param options Request options.
     */
    addGlobalProjectRoleActors<T = AddGlobalProjectRoleActorsResponseOK>(options: AddGlobalProjectRoleActorsRequest): Promise<AddGlobalProjectRoleActorsResponseOK | T>;
    /**
     * Removes default actor from the given role.
     * Alternative usage: Role.Project.Actor.deleteActors
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.2/#role-deleteProjectRoleActorsFromRole
     * @param options Request options.
     */
    deleteGlobalProjectRoleActors<T = DeleteGlobalProjectRoleActorsResponseOK>(options: DeleteGlobalProjectRoleActorsRequest): Promise<DeleteGlobalProjectRoleActorsResponseOK | T>;
    /**
     * Returns a user.
     * Alternative usage: User.getUser
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#user-getUser
     * @param options Request options.
     */
    getUser<T = GetUserResponseOK>(options?: GetUserRequest): Promise<GetUserResponseOK | T>;
    /**
     * Modify user. The "value" fields present will override the existing value. Fields skipped in request will not be changed.
     * Alternative usage: User.updateUser
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#user-updateUser
     * @param options Request options.
     */
    updateUser<T = UpdateUserResponseOK>(options: UpdateUserRequest): Promise<UpdateUserResponseOK | T>;
    /**
     * Create user. By default created user will not be notified with email. If password field is not set then password will be randomly generated.
     * Alternative usage: User.createUser
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#user-createUser
     * @param options Request options.
     */
    createUser<T = CreateUserResponseOK>(options: CreateUserRequest): Promise<CreateUserResponseOK | T>;
    /**
     * Removes user and its references (like project roles associations, watches, history).
     * Alternative usage: User.removeUser
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#user-removeUser
     * @param options Request options.
     */
    removeUser<T = RemoveUserResponseOK>(options: RemoveUserRequest): Promise<RemoveUserResponseOK | T>;
    /**
     * Add user to given application. Admin permission will be required to perform this operation.
     * Alternative usage: User.addUserToApplication
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#user-addUserToApplication
     * @param options Request options.
     */
    addUserToApplication<T = AddUserToApplicationResponseOK>(options: AddUserToApplicationRequest): Promise<AddUserToApplicationResponseOK | T>;
    /**
     * Remove user from given application. Admin permission will be required to perform this operation.
     * Alternative usage: User.removeUserFromApplication
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#user-removeUserFromApplication
     * @param options Request options.
     */
    removeUserFromApplication<T = RemoveUserFromApplicationResponseOK>(options: RemoveUserFromApplicationRequest): Promise<RemoveUserFromApplicationResponseOK | T>;
    /**
     * Modify user password.
     * Alternative usage: User.changeUserPassword
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#user-changeUserPassword
     * @param options Request options.
     */
    changeUserPassword<T = ChangeUserPasswordResponseOK>(options: ChangeUserPasswordRequest): Promise<ChangeUserPasswordResponseOK | T>;
    /**
     * Returns a list of users that match the search string. This resource cannot be accessed anonymously. Please note that this resource should be called with an issue key when a list of assignable users is retrieved for editing. For create only a project key should be supplied. The list of assignable users may be incorrect if it's called with the project key for editing.
     * Alternative usage: User.Search.findAssignableUsers
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#user-findAssignableUsers
     * @param options Request options.
     */
    findAssignableUsers<T = FindAssignableUsersResponseOK>(options?: FindAssignableUsersRequest): Promise<FindAssignableUsersResponseOK | T>;
    /**
     * Returns a list of active users that match the search string and have all specified permissions for the project or issue.
     * This resource can be accessed by users with ADMINISTER_PROJECT permission for the project or global ADMIN or SYSADMIN rights.
     * Alternative usage: User.Search.findUsersWithAllPermissions
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#user-findUsersWithAllPermissions
     * @param options Request options.
     */
    findUsersWithAllPermissions<T = FindUsersWithAllPermissionsResponseOK>(options: FindUsersWithAllPermissionsRequest): Promise<FindUsersWithAllPermissionsResponseOK | T>;
    /**
     * Returns a list of users that match the search string. This resource cannot be accessed anonymously.
     * Alternative usage: User.Search.findUsers
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#user-findUsers
     * @param options Request options.
     */
    findUsers<T = FindUsersResponseOK>(options: FindUsersRequest): Promise<FindUsersResponseOK | T>;
    /**
     * Returns a list of active users that match the search string. This resource cannot be accessed anonymously and requires the Browse Users global permission. Given an issue key this resource will provide a list of users that match the search string and have the browse issue permission for the issue provided.
     * Alternative usage: User.Search.findUsersWithBrowsePermission
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#user-findUsersWithBrowsePermission
     * @param options Request options.
     */
    findUsersWithBrowsePermission<T = FindUsersWithBrowsePermissionResponseOK>(options: FindUsersWithBrowsePermissionRequest): Promise<FindUsersWithBrowsePermissionResponseOK | T>;
    /**
     * Gets available fields for screen. i.e ones that haven't already been added.
     * Alternative usage: Screen.getFieldsToAdd
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.2/#screens-getFieldsToAdd
     * @param options Request options.
     */
    getScreenFieldsToAdd<T = GetScreenFieldsToAddResponseOK>(options: GetScreenFieldsToAddRequest): Promise<GetScreenFieldsToAddResponseOK | T>;
    /**
     * Gets available field screens.
     * Alternative usage: Screen.getScreens
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.2/#screens-getAllScreens
     * @param options Request options.
     */
    getScreens<T = GetScreensResponseOK>(options: GetScreensRequest): Promise<GetScreensResponseOK | T>;
    /**
     * Creates tab for given screen.
     * Alternative usage: Screen.Tab.addTab
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.2/#screens-addTab
     * @param options Request options.
     */
    addScreenTab<T = AddScreenTabResponseOK>(options: AddScreenTabRequest): Promise<AddScreenTabResponseOK | T>;
    /**
     * Returns a list of all tabs for the given screen.
     * Alternative usage: Screen.Tab.getTabs
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.2/#screens-getAllTabs
     * @param options Request options.
     */
    getScreenTabs<T = GetScreenTabsResponseOK>(options: GetScreenTabsRequest): Promise<GetScreenTabsResponseOK | T>;
    /**
     * Renames tab on given screen.
     * Alternative usage: Screen.Tab.renameTab
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.2/#screens-renameTab
     * @param options Request options.
     */
    renameScreenTab<T = RenameScreenTabResponseOK>(options: RenameScreenTabRequest): Promise<RenameScreenTabResponseOK | T>;
    /**
     * Deletes tab to give screen.
     * Alternative usage: Screen.Tab.deleteTab
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.2/#screens-deleteTab
     * @param options Request options.
     */
    deleteScreenTab<T = DeleteScreenTabResponseOK>(options: DeleteScreenTabRequest): Promise<DeleteScreenTabResponseOK | T>;
    /**
     * Moves tab position.
     * Alternative usage: Screen.Tab.moveTab
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.2/#screens-moveTab
     * @param options Request options.
     */
    moveScreenTab<T = MoveScreenTabResponseOK>(options: MoveScreenTabRequest): Promise<MoveScreenTabResponseOK | T>;
    /**
     * Gets all fields for a given tab.
     * Alternative usage: Screen.Field.getFields
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.2/#screens-getAllFields
     * @param options Request options.
     */
    getScreenFields<T = GetScreenFieldsResponseOK>(options: GetScreenFieldsRequest): Promise<GetScreenFieldsResponseOK | T>;
    /**
     * Adds field to the given tab.
     * Alternative usage: Screen.Field.addField
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.2/#screens-addField
     * @param options Request options.
     */
    addScreenField<T = AddScreenFieldResponseOK>(options: AddScreenFieldRequest): Promise<AddScreenFieldResponseOK | T>;
    /**
     * Removes field from given tab.
     * Alternative usage: Screen.Field.removeField
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.2/#screens-removeField
     * @param options Request options.
     */
    removeScreenField<T = RemoveScreenFieldResponseOK>(options: RemoveScreenFieldRequest): Promise<RemoveScreenFieldResponseOK | T>;
    /**
     * Moves field on the given tab.
     * Alternative usage: Screen.Field.moveField
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.2/#screens-moveField
     * @param options Request options.
     */
    moveScreenField<T = MoveScreenFieldResponseOK>(options: MoveScreenFieldRequest): Promise<MoveScreenFieldResponseOK | T>;
    /**
     * Adds field or custom field to the default tab.
     * Alternative usage: Screen.Field.addToDefaultScreen
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.2/#screens-addFieldToDefaultScreen
     * @param options Request options.
     */
    addFieldToDefaultScreen<T = AddFieldToDefaultScreenResponseOK>(options: AddFieldToDefaultScreenRequest): Promise<AddFieldToDefaultScreenResponseOK | T>;
    /**
     * Returns all projects which are visible for the currently logged in user. If no user is logged in, it returns the list of projects that are visible when using anonymous access.
     * Alternative usage: Project.getProjects
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#project-getAllProjects
     * @param options Request options.
     */
    getProjects<T = GetProjectsResponseOK>(options?: GetProjectsRequest): Promise<GetProjectsResponseOK | T>;
    /**
     * Creates a new project.
     * Alternative usage: Project.createProject
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#project-createProject
     * @param options Request options.
     */
    createProject<T = CreateProjectResponseOK>(options: CreateProjectRequest): Promise<CreateProjectResponseOK | T>;
    /**
     * Contains a full representation of a project in JSON format.
     * Alternative usage: Project.getProject
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#project-getProject
     * @param options Request options.
     */
    getProject<T = GetProjectResponseOK>(options: GetProjectRequest): Promise<GetProjectResponseOK | T>;
    /**
     * Updates a project. Only non null values sent in JSON will be updated in the project.
     * Alternative usage: Project.updateProject
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#project-updateProject
     * @param options Request options.
     */
    updateProject<T = UpdateProjectResponseOK>(options: UpdateProjectRequest): Promise<UpdateProjectResponseOK | T>;
    /**
     * Deletes a project.
     * Alternative usage: Project.deleteProject
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#project-deleteProject
     * @param options Request options.
     */
    deleteProject<T = DeleteProjectResponseOK>(options: DeleteProjectRequest): Promise<DeleteProjectResponseOK | T>;
    /**
     * Archives a project. For DC only.
     * Alternative usage: Project.archiveProject
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#project-archiveProject
     * @param options Request options.
     */
    archiveProject<T = ArchiveProjectResponseOK>(options: ArchiveProjectRequest): Promise<ArchiveProjectResponseOK | T>;
    /**
     * Contains a full representation of a the specified project's components.
     * Alternative usage: Project.getComponents
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#project-getProjectComponents
     * @param options Request options.
     */
    getProjectComponents<T = GetProjectComponentsResponseOK>(options: GetProjectComponentsRequest): Promise<GetProjectComponentsResponseOK | T>;
    /**
     * Restore an archived project. In case of success restored project should be re-indexed. For DC only.
     * Alternative usage: Project.restoreProject
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#project-restoreProject
     * @param options Request options.
     */
    restoreProject<T = RestoreProjectResponseOK>(options: RestoreProjectRequest): Promise<RestoreProjectResponseOK | T>;
    /**
     * Get all issue types with valid status values for a project.
     * Alternative usage: Project.getStatuses
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#project-getAllStatuses
     * @param options Request options.
     */
    getProjectStatuses<T = GetProjectStatusesResponseOK>(options: GetProjectStatusesRequest): Promise<GetProjectStatusesResponseOK | T>;
    /**
     * Updates the type of a project.
     * Alternative usage: Project.updateProjectType
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#project-updateProjectType
     * @param options Request options.
     */
    updateProjectType<T = UpdateProjectTypeResponseOK>(options: UpdateProjectTypeRequest): Promise<UpdateProjectTypeResponseOK | T>;
    /**
     * Returns all versions for the specified project. Results are paginated.
     * Alternative usage: Project.getVersionsPaginated
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#project-getProjectVersionsPaginated
     * @param options Request options.
     */
    getProjectVersionsPaginated<T = GetProjectVersionsPaginatedResponseOK>(options: GetProjectVersionsPaginatedRequest): Promise<GetProjectVersionsPaginatedResponseOK | T>;
    /**
     * Contains a full representation of a the specified project's versions.
     * Alternative usage: Project.getVersions
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#project-getProjectVersions
     * @param options Request options.
     */
    getProjectVersions<T = GetProjectVersionsResponseOK>(options: GetProjectVersionsRequest): Promise<GetProjectVersionsResponseOK | T>;
    /**
     * Gets a full representation of a priority scheme in JSON format used by specified project.
     * Alternative usage: Project.Priority.Scheme.getScheme
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.2/#project/{projectKeyOrId}/priorityscheme-getAssignedPriorityScheme
     * @param options Request options.
     */
    getPriorityScheme<T = GetPrioritySchemeResponseOK>(options: GetPrioritySchemeRequest): Promise<GetPrioritySchemeResponseOK | T>;
    /**
     * Resource for associating permission schemes and projects.
     * Alternative usage: Project.Permission.Scheme.getScheme
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.2/#project/{projectKeyOrId}/permissionscheme-getAssignedPermissionScheme
     * @param options Request options.
     */
    getProjectPermissionScheme<T = GetProjectPermissionSchemeResponseOK>(options: GetProjectPermissionSchemeRequest): Promise<GetProjectPermissionSchemeResponseOK | T>;
    /**
     * Gets a notification scheme associated with the project.
     * Alternative usage: Project.Notification.Scheme.getScheme
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.2/#project/{projectKeyOrId}/notificationscheme-getNotificationScheme
     * @param options Request options.
     */
    getProjectNotificationScheme<T = GetProjectNotificationSchemeResponseOK>(options: GetProjectNotificationSchemeRequest): Promise<GetProjectNotificationSchemeResponseOK | T>;
    /**
     * Returns the issue security scheme for project.
     * Alternative usage: Project.Issue.Security.Scheme.getScheme
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.2/#project/{projectKeyOrId}/issuesecuritylevelscheme-getIssueSecurityScheme
     * @param options Request options.
     */
    getProjectIssueSecurityScheme<T = GetProjectIssueSecuritySchemeResponseOK>(options: GetProjectIssueSecuritySchemeRequest): Promise<GetProjectIssueSecuritySchemeResponseOK | T>;
    /**
     * Create a version via POST.
     * Alternative usage: Project.Version.createVersion
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#version-createVersion
     * @param options Request options.
     */
    createProjectVersion<T = CreateProjectVersionResponseOK>(options: CreateProjectVersionRequest): Promise<CreateProjectVersionResponseOK | T>;
    /**
     * Modify a version's sequence within a project.
     * Alternative usage: Project.Version.moveVersion
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#version-moveVersion
     * @param options Request options.
     */
    moveProjectVersion<T = MoveProjectVersionResponseOK>(options: MoveProjectVersionRequest): Promise<MoveProjectVersionResponseOK | T>;
    /**
     * Returns a project version.
     * Alternative usage: Project.Version.getVersion
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#version-getVersion
     * @param options Request options.
     */
    getProjectVersion<T = GetProjectVersionResponseOK>(options: GetProjectVersionRequest): Promise<GetProjectVersionResponseOK | T>;
    /**
     * Modify a version via PUT. Any fields present in the PUT will override existing values. As a convenience, if a field is not present, it is silently ignored.
     * Alternative usage: Project.Version.updateVersion
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#version-updateVersion
     * @param options Request options.
     */
    updateProjectVersion<T = UpdateProjectVersionResponseOK>(options: UpdateProjectVersionRequest): Promise<UpdateProjectVersionResponseOK | T>;
    /**
     * Delete a project version.
     * Alternative usage: Project.Version.deleteVersion
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#version-delete
     * @param options Request options.
     */
    deleteProjectVersion<T = DeleteProjectVersionResponseOK>(options: DeleteProjectVersionRequest): Promise<DeleteProjectVersionResponseOK | T>;
    /**
     * Merge versions.
     * Alternative usage: Project.Version.mergeVersion
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#version-merge
     * @param options Request options.
     */
    mergeProjectVersion<T = MergeProjectVersionResponseOK>(options: MergeProjectVersionRequest): Promise<MergeProjectVersionResponseOK | T>;
    /**
     * Delete a project version.
     * Alternative usage: Project.Version.removeAndReplaceVersion
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#version-delete
     * @param options Request options.
     */
    removeAndReplaceProjectVersion<T = RemoveAndReplaceProjectVersionResponseOK>(options: RemoveAndReplaceProjectVersionRequest): Promise<RemoveAndReplaceProjectVersionResponseOK | T>;
    /**
     * Returns a bean containing the number of fixed in and affected issues for the given version.
     * Alternative usage: Project.Version.Count.getVersionRelatedIssueCount
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#version-getVersionRelatedIssues
     * @param options Request options.
     */
    getProjectVersionRelatedIssueCount<T = GetProjectVersionRelatedIssueCountResponseOK>(options: GetProjectVersionRelatedIssueCountRequest): Promise<GetProjectVersionRelatedIssueCountResponseOK | T>;
    /**
     * Returns the number of unresolved issues for the given version
     * Alternative usage: Project.Version.Count.getVersionUnresolvedIssueCount
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#version-getVersionUnresolvedIssues
     * @param options Request options.
     */
    getProjectVersionUnresolvedIssueCount<T = GetProjectVersionUnresolvedIssueCountResponseOK>(options: GetProjectVersionUnresolvedIssueCountRequest): Promise<GetProjectVersionUnresolvedIssueCountResponseOK | T>;
    /**
     * Returns the remote version links associated with the given version ID.
     * Alternative usage: Project.Version.Remote.getLinksById
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.2/#version-getRemoteVersionLinksByVersionId
     * @param options Request options.
     */
    getRemoteVersionLinksById<T = GetRemoteVersionLinksByIdResponseOK>(options: GetRemoteVersionLinksByIdRequest): Promise<GetRemoteVersionLinksByIdResponseOK | T>;
    /**
     * Create a remote version link via POST.
     * Alternative usage: Project.Version.Remote.createOrUpdateLinkById
     * The link's global ID will be taken from the JSON payload if provided; otherwise, it will be generated.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.2/#version-createOrUpdateRemoteVersionLink
     * @param options Request options.
     */
    createOrUpdateRemoteVersionLinkById<T = CreateOrUpdateRemoteVersionLinkByIdResponseOK>(options: CreateOrUpdateRemoteVersionLinkByIdRequest): Promise<CreateOrUpdateRemoteVersionLinkByIdResponseOK | T>;
    /**
     * Delete all remote version links for a given version ID.
     * Alternative usage: Project.Version.Remote.deleteLinksById
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.2/#version-deleteRemoteVersionLinksByVersionId
     * @param options Request options.
     */
    deleteRemoteVersionLinksById<T = DeleteRemoteVersionLinksByIdResponseOK>(options: DeleteRemoteVersionLinksByIdRequest): Promise<DeleteRemoteVersionLinksByIdResponseOK | T>;
    /**
     * A REST sub-resource representing a remote version link.
     * Alternative usage: Project.Version.Remote.getLink
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.2/#version-getRemoteVersionLink
     * @param options Request options.
     */
    getRemoteVersionLink<T = GetRemoteVersionLinkResponseOK>(options: GetRemoteVersionLinkRequest): Promise<GetRemoteVersionLinkResponseOK | T>;
    /**
     * Create a remote version link via POST.
     * Alternative usage: Project.Version.Remote.createOrUpdateLink
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.2/#version-createOrUpdateRemoteVersionLink
     * @param options Request options.
     */
    createOrUpdateRemoteVersionLink<T = CreateOrUpdateRemoteVersionLinkResponseOK>(options: CreateOrUpdateRemoteVersionLinkRequest): Promise<CreateOrUpdateRemoteVersionLinkResponseOK | T>;
    /**
     * Delete a specific remote version link with the given version ID and global ID.
     * Alternative usage: Project.Version.Remote.deleteLink
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.2/#version-deleteRemoteVersionLink
     * @param options Request options.
     */
    deleteRemoteVersionLink<T = DeleteRemoteVersionLinkResponseOK>(options: DeleteRemoteVersionLinkRequest): Promise<DeleteRemoteVersionLinkResponseOK | T>;
    /**
     * Delete a specific remote version link with the given version ID and global ID.
     * Alternative usage: Project.Version.Remote.deleteLink
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.2/#version-deleteRemoteVersionLink
     * @param options Request options.
     */
    getRemoteVersionLinks<T = GetRemoteVersionLinksResponseOK>(options: GetRemoteVersionLinksRequest): Promise<GetRemoteVersionLinksResponseOK | T>;
    /**
     * Validates a project key.
     * Alternative usage: Project.Validation.validateProjectKey
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#projectvalidate-getProject
     * @param options Request options.
     */
    validateProjectKey<T = ValidateProjectKeyResponseOK>(options: ValidateProjectKeyRequest): Promise<ValidateProjectKeyResponseOK | T>;
    /**
     * Returns all the project types defined on the JIRA instance, not taking into account whether the license to use those project types is valid or not.
     * Alternative usage: Project.Type.getTypes
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#project/type-getAllProjectTypes
     * @param options Request options.
     */
    getProjectTypes<T = GetProjectTypesResponseOK>(options?: GetProjectTypesRequest): Promise<GetProjectTypesResponseOK | T>;
    /**
    * Returns the project type with the given key.
    * Alternative usage: Project.Type.getType
    * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#project/type-getProjectTypeByKey
    * @param options Request options.
    */
    getProjectType<T = GetProjectTypeResponseOK>(options: GetProjectTypeRequest): Promise<GetProjectTypeResponseOK | T>;
    /**
     * Returns the project type with the given key, if it is accessible to the logged in user. This takes into account whether the user is licensed on the Application that defines the project type.
     * Alternative usage: Project.Type.getAccessibleType
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#project/type-getAccessibleProjectTypeByKey
     * @param options Request options.
     */
    getAccessibleProjectType<T = GetAccessibleProjectTypeResponseOK>(options: GetAccessibleProjectTypeRequest): Promise<GetAccessibleProjectTypeResponseOK | T>;
    /**
     * Returns all security levels for the project that the current logged in user has access to.
     * Alternative usage: Project.Security.getLevels
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.2/#project/{projectKeyOrId}/securitylevel-getSecurityLevelsForProject
     * @param options Request options.
     */
    getProjectSecurityLevels<T = GetProjectSecurityLevelsResponseOK>(options: GetProjectSecurityLevelsRequest): Promise<GetProjectSecurityLevelsResponseOK | T>;
    /**
     * Returns all roles in the given project Id or key, with links to full details on each role.
     * Alternative usage: Project.Role.getRoles
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#project/{projectIdOrKey}/role-getProjectRoles
     * @param options Request options.
     */
    getProjectRoles<T = GetProjectRolesResponseOK>(options: GetProjectRolesRequest): Promise<GetProjectRolesResponseOK | T>;
    /**
     * Returns the details for a given project role in a project.
     * Alternative usage: Project.Role.getRole
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#project/{projectIdOrKey}/role-getProjectRole
     * @param options Request options.
     */
    getProjectRole<T = GetProjectRoleResponseOK>(options: GetProjectRoleRequest): Promise<GetProjectRoleResponseOK | T>;
    /**
     * Updates a project role to include the specified actors (users or groups).
     * Alternative usage: Project.Role.Actor.setActors
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#project/{projectIdOrKey}/role-setActors
     * @param options Request options.
     */
    setProjectRoleActors<T = SetProjectRoleActorsResponseOK>(options: SetProjectRoleActorsRequest): Promise<SetProjectRoleActorsResponseOK | T>;
    /**
     * Adds an actor (user or group) to a project role.
     * Alternative usage: Project.Role.Actor.addUsers
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#project/{projectIdOrKey}/role-addActorUsers
     * @param options Request options.
     */
    addProjectRoleActorUsers<T = AddProjectRoleActorUsersResponseOK>(options: AddProjectRoleActorUsersRequest): Promise<AddProjectRoleActorUsersResponseOK | T>;
    /**
     * Deletes actors (users or groups) from a project role.
     * Delete a user from the role: /rest/api/2/project/{projectIdOrKey}/role/{roleId}?user={username}
     * Delete a group from the role: /rest/api/2/project/{projectIdOrKey}/role/{roleId}?group={groupname}
     * Alternative usage: Project.Role.Actor.deleteActor
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#project/{projectIdOrKey}/role-deleteActor
     * @param options Request options.
     */
    deleteProjectRoleActor<T = DeleteProjectRoleActorResponseOK>(options: DeleteProjectRoleActorRequest): Promise<DeleteProjectRoleActorResponseOK | T>;
    /**
     * Create a component via POST.
     * Alternative usage: Project.Component.createComponent
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#component-createComponent
     * @param options Request options.
     */
    createProjectComponent<T = CreateProjectComponentResponseOK>(options: CreateProjectComponentRequest): Promise<CreateProjectComponentResponseOK | T>;
    /**
     * Returns a project component.
     * Alternative usage: Project.Component.getComponent
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#component-getComponent
     * @param options Request options.
     */
    getProjectComponent<T = GetProjectComponentResponseOK>(options: GetProjectComponentRequest): Promise<GetProjectComponentResponseOK | T>;
    /**
     * Modify a component via PUT. If leadUserName is an empty string ("") the component lead will be removed.
     * Alternative usage: Project.Component.updateComponent
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#component-updateComponent
     * @param options Request options.
     */
    updateProjectComponent<T = UpdateProjectComponentResponseOK>(options: UpdateProjectComponentRequest): Promise<UpdateProjectComponentResponseOK | T>;
    /**
     * Delete a project component.
     * Alternative usage: Project.Component.deleteComponent
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#component-delete
     * @param options Request options.
     */
    deleteProjectComponent<T = DeleteProjectComponentResponseOK>(options: DeleteProjectComponentRequest): Promise<DeleteProjectComponentResponseOK | T>;
    /**
     * Returns counts of issues related to this component.
     * Alternative usage: Project.Component.getRelatedIssueCount
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#component-getComponentRelatedIssues
     * @param options Request options.
     */
    getProjectComponentRelatedIssueCount<T = GetProjectComponentRelatedIssueCountResponseOK>(options: GetProjectComponentRelatedIssueCountRequest): Promise<GetProjectComponentRelatedIssueCountResponseOK | T>;
    /**
     * Returns all permissions in the system and whether the currently logged in user has them.
     * You can optionally provide a specific context to get permissions for (projectKey OR projectId OR issueKey OR issueId).
     * Alternative usage: Permission.getMyPermissions
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#-getPermissions
     * @param options Request options.
     */
    getMyPermissions<T = GetMyPermissionsResponseOK>(options?: GetMyPermissionsRequest): Promise<GetMyPermissionsResponseOK | T>;
    /**
     * Returns all permissions that are present in the JIRA instance - Global, Project and the global ones added by plugins
     * Alternative usage: Permission.getPermissions
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#-getAllPermissions
     * @param options Request options.
     */
    getPermissions<T = GetPermissionsResponseOK>(options?: GetPermissionsRequest): Promise<GetPermissionsResponseOK | T>;
    /**
     * Returns a permission scheme identified by the given id.
     * Alternative usage: Permission.Scheme.getScheme
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.2/#permissionscheme-getPermissionScheme
     * @param options Request options.
     */
    getPermissionSchemes<T = GetPermissionSchemesResponseOK>(options?: GetPermissionSchemesRequest): Promise<GetPermissionSchemesResponseOK | T>;
    /**
     * Create a new permission scheme. This method can create schemes with a defined permission set, or without.
     * Alternative usage: Permission.Scheme.createScheme
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.2/#permissionscheme-createPermissionScheme
     * @param options Request options.
     */
    createPermissionScheme<T = CreatePermissionSchemeResponseOK>(options: CreatePermissionSchemeRequest): Promise<CreatePermissionSchemeResponseOK | T>;
    /**
     * Returns a permission scheme identified by the given id.
     * Alternative usage: Permission.Scheme.getScheme
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.2/#permissionscheme-getPermissionScheme
     * @param options Request options.
     */
    getPermissionScheme<T = GetPermissionSchemeResponseOK>(options: GetPermissionSchemeRequest): Promise<GetPermissionSchemeResponseOK | T>;
    /**
     * Deletes a permission scheme identified by the given id.
     * Alternative usage: Permission.Scheme.deleteScheme
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.2/#permissionscheme-deletePermissionScheme
     * @param options Request options.
     */
    deletePermissionScheme<T = DeletePermissionSchemeResponseOK>(options: DeletePermissionSchemeRequest): Promise<DeletePermissionSchemeResponseOK | T>;
    /**
     * Updates a permission scheme.
     * If the permissions list is present then it will be set in the permission scheme, which basically means it will overwrite any permission grants that existed in the permission scheme.
     * Sending an empty list will remove all permission grants from the permission scheme.
     * To update just the name and description, do not send permissions list at all.
     * Alternative usage: Permission.Scheme.updateScheme
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.2/#permissionscheme-updatePermissionScheme
     * @param options Request options.
     */
    updatePermissionScheme<T = UpdatePermissionSchemeResponseOK>(options: UpdatePermissionSchemeRequest): Promise<UpdatePermissionSchemeResponseOK | T>;
    /**
     * Returns scheme attribute.
     * Alternative usage: Permission.Scheme.Attribute.getAttribute
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.2/#permissionscheme-getSchemeAttribute
     * @param options Request options.
     */
    getPermissionSchemeAttribute<T = GetPermissionSchemeAttributeResponseOK>(options: GetPermissionSchemeAttributeRequest): Promise<GetPermissionSchemeAttributeResponseOK | T>;
    /**
     * Returns all permission grants of the given permission scheme.
     * Alternative usage: Permission.Scheme.Grant.getGrants
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.2/#permissionscheme-getPermissionSchemeGrants
     * @param options Request options.
     */
    getPermissionSchemeGrants<T = GetPermissionSchemeGrantsResponseOK>(options: GetPermissionSchemeGrantsRequest): Promise<GetPermissionSchemeGrantsResponseOK | T>;
    /**
     * Creates a permission grant in a permission scheme.
     * Alternative usage: Permission.Scheme.Grant.createGrant
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.2/#permissionscheme-createPermissionGrant
     * @param options Request options.
     */
    createPermissionSchemeGrant<T = CreatePermissionSchemeGrantResponseOK>(options: CreatePermissionSchemeGrantRequest): Promise<CreatePermissionSchemeGrantResponseOK | T>;
    /**
     * Deletes a permission grant from a permission scheme.
     * Alternative usage: Permission.Scheme.Grant.deleteGrant
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.2/#permissionscheme-deletePermissionSchemeEntity
     * @param options Request options.
     */
    deletePermissionSchemeGrant<T = DeletePermissionSchemeGrantResponseOK>(options: DeletePermissionSchemeGrantRequest): Promise<DeletePermissionSchemeGrantResponseOK | T>;
    /**
     * Returns a permission grant identified by the given id.
     * Alternative usage: Permission.Scheme.Grant.getGrant
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.2/#permissionscheme-getPermissionSchemeGrant
     * @param options Request options.
     */
    getPermissionSchemeGrant<T = GetPermissionSchemeGrantResponseOK>(options: GetPermissionSchemeGrantRequest): Promise<GetPermissionSchemeGrantResponseOK | T>;
    /**
     * Sets preference of the currently logged in user.
     * Preference key must be provided as input parameters (key).
     * Value must be provided as post body. If key or value parameter is not provided - status code 404.
     * If preference is set - status code 204.
     * Alternative usage: Issue.Myself.setPreference
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.2/#mypreferences-setPreference
     * @param options Request options.
     */
    setMyPreference<T = SetMyPreferenceResponseOK>(options: SetMyPreferenceRequest): Promise<SetMyPreferenceResponseOK | T>;
    /**
     * Removes preference of the currently logged in user. Preference key must be provided as input parameters (key).
     * If key parameter is not provided or wrong - status code 404.
     * If preference is unset - status code 204.
     * Alternative usage: Issue.Myself.removePreference
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.2/#mypreferences-removePreference
     * @param options Request options.
     */
    removeMyPreference<T = RemoveMyPreferenceResponseOK>(options: RemoveMyPreferenceRequest): Promise<RemoveMyPreferenceResponseOK | T>;
    /**
     * Returns preference of the currently logged in user.
     * Preference key must be provided as input parameter (key).
     * The value is returned exactly as it is. If key parameter is not provided or wrong - status code 404.
     * If value is found - status code 200.
     * Alternative usage: Issue.Myself.getPreference
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.2/#mypreferences-getPreference
     * @param options Request options.
     */
    getMyPreference<T = GetMyPreferenceResponseOK>(options: GetMyPreferenceRequest): Promise<GetMyPreferenceResponseOK | T>;
    /**
     * Returns currently logged in user.
     * Alternative usage: Myself.getCurrentUser
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#myself-getUser
     * @param options Request options.
     */
    getCurrentUser<T = GetCurrentUserResponseOK>(options?: GetCurrentUserRequest): Promise<GetCurrentUserResponseOK | T>;
    /**
     * Returns a paginated list of notification schemes.
     * Alternative usage: Issue.Notification.Scheme.getSchemes
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#notificationscheme-getNotificationSchemes
     * @param options Request options.
     */
    getNotificationSchemes<T = GetNotificationSchemesResponseOK>(options?: GetNotificationSchemesRequest): Promise<GetNotificationSchemesResponseOK | T>;
    /**
     * Returns a full representation of the notification scheme for the given id.
     * Alternative usage: Issue.Notification.Scheme.getScheme
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.2/#notificationscheme-getNotificationScheme
     * @param options Request options.
     */
    getNotificationScheme<T = GetNotificationSchemeResponseOK>(options: GetNotificationSchemeRequest): Promise<GetNotificationSchemeResponseOK | T>;
    /**
     * Returns all issue security schemes that are defined.
     * Alternative usage: Issue.Security.Scheme.getSchemes
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.2/#issuesecurityschemes-getIssueSecuritySchemes
     * @param options Request options.
     */
    getIssueSecuritySchemes<T = GetIssueSecuritySchemesResponseOK>(options?: GetIssueSecuritySchemesRequest): Promise<GetIssueSecuritySchemesResponseOK | T>;
    /**
     * Returns the issue security scheme along with that are defined.
     * Alternative usage: Issue.Security.Scheme.getScheme
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.2/#issuesecurityschemes-getIssueSecurityScheme
     * @param options Request options.
     */
    getIssueSecurityScheme<T = GetIssueSecuritySchemeResponseOK>(options: GetIssueSecuritySchemeRequest): Promise<GetIssueSecuritySchemeResponseOK | T>;
    /**
     * Returns all work logs for an issue. Work logs won't be returned if the Log work field is hidden for the project.
     * Alternative usage: Issue.Worklog.getWorklogs
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#issue-getIssueWorklog
     * @param options Request options.
     */
    getIssueWorklogs<T = GetIssueWorklogsResponseOK>(options: GetIssueWorklogsRequest): Promise<GetIssueWorklogsResponseOK | T>;
    /**
     * Adds a new worklog entry to an issue.
     * Alternative usage: Issue.Worklog.addWorklog
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#issue-addWorklog
     * @param options Request options.
     */
    addIssueWorklog<T = AddIssueWorklogResponseOK>(options: AddIssueWorklogRequest): Promise<AddIssueWorklogResponseOK | T>;
    /**
     * Returns a specific worklog. The work log won't be returned if the Log work field is hidden for the project.
     * Alternative usage: Issue.Worklog.getWorklog
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#issue-getWorklog
     * @param options Request options.
     */
    getIssueWorklog<T = GetIssueWorklogResponseOK>(options: GetIssueWorklogRequest): Promise<GetIssueWorklogResponseOK | T>;
    /**
     * Updates an existing worklog entry. Fields possible for editing are: comment, visibility, started, timeSpent and timeSpentSeconds. Either timeSpent or timeSpentSeconds can be set. Fields which are not set will not be updated. For a request to be valid, it has to have at least one field change.
     * Alternative usage: Issue.Worklog.updateWorklog
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#issue-updateWorklog
     * @param options Request options.
     */
    updateIssueWorklog<T = UpdateIssueWorklogResponseOK>(options: UpdateIssueWorklogRequest): Promise<UpdateIssueWorklogResponseOK | T>;
    /**
     * Deletes an existing worklog entry.
     * Alternative usage: Issue.Worklog.deleteWorklog
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#issue-deleteWorklog
     * @param options Request options.
     */
    deleteIssueWorklog<T = DeleteIssueWorklogResponseOK>(options: DeleteIssueWorklogRequest): Promise<DeleteIssueWorklogResponseOK | T>;
    /**
     * Returns worklogs id and delete time of worklogs that was deleted since given time. The returns set of worklogs is limited to 1000 elements. This API will not return worklogs deleted during last minute.
     * Alternative usage: Issue.Worklog.getDeletedWorklogIds
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#worklog-getIdsOfWorklogsDeletedSince
     * @param options Request options.
     */
    getDeletedIssueWorklogIds<T = GetDeletedIssueWorklogIdsResponseOK>(options?: GetDeletedIssueWorklogIdsRequest): Promise<GetDeletedIssueWorklogIdsResponseOK | T>;
    /**
     * Returns worklogs for given worklog ids. Only worklogs to which the calling user has permissions, will be included in the result. The returns set of worklogs is limited to 1000 elements.
     * Alternative usage: Issue.Worklog.getWorklogsForIds
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#worklog-getWorklogsForIds
     * @param options Request options.
     */
    getIssueWorklogsForIds<T = GetIssueWorklogsForIdsResponseOK>(options: GetIssueWorklogsForIdsRequest): Promise<GetIssueWorklogsForIdsResponseOK | T>;
    /**
     * Returns worklogs id and update time of worklogs that was updated since given time. The returns set of worklogs is limited to 1000 elements. This API will not return worklogs updated during last minute.
     * Alternative usage: Issue.Worklog.getUpdatedWorklogIds
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#worklog-getIdsOfWorklogsModifiedSince
     * @param options Request options.
     */
    getUpdatedIssueWorklogIds<T = GetUpdatedIssueWorklogIdsResponseOK>(options?: GetUpdatedIssueWorklogIdsRequest): Promise<GetUpdatedIssueWorklogIdsResponseOK | T>;
    /**
     * Returns the list of watchers for the issue with the given key.
     * Alternative usage: Issue.Watcher.getWatchers
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#issue-getIssueWatchers
     * @param options Request options.
     */
    getIssueWatchers<T = GetIssueWatchersResponseOK>(options: GetIssueWatchersRequest): Promise<GetIssueWatchersResponseOK | T>;
    /**
     * Adds a user to an issue's watcher list.
     * Alternative usage: Issue.Watcher.addWatcher
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#issue-addWatcher
     * @param options Request options.
     */
    addIssueWatcher<T = AddIssueWatcherResponseOK>(options: AddIssueWatcherRequest): Promise<AddIssueWatcherResponseOK | T>;
    /**
     * Removes a user from an issue's watcher list.
     * Alternative usage: Issue.Watcher.removeWatcher
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#issue-removeWatcher
     * @param options Request options.
     */
    removeIssueWatcher<T = RemoveIssueWatcherResponseOK>(options: RemoveIssueWatcherRequest): Promise<RemoveIssueWatcherResponseOK | T>;
    /**
     * Remove your vote from an issue. (i.e. "unvote").
     * Alternative usage: Issue.Vote.removeVote
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#issue-removeVote
     * @param options Request options.
     */
    removeIssueVote<T = RemoveIssueVoteResponseOK>(options: RemoveIssueVoteRequest): Promise<RemoveIssueVoteResponseOK | T>;
    /**
     * Cast your vote in favour of an issue.
     * Alternative usage: Issue.Vote.addVote
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#issue-addVote
     * @param options Request options.
     */
    addIssueVote<T = AddIssueVoteResponseOK>(options: AddIssueVoteRequest): Promise<AddIssueVoteResponseOK | T>;
    /**
     * A REST sub-resource representing the voters on the issue.
     * Alternative usage: Issue.Vote.getVotes
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#issue-getVotes
     * @param options Request options.
     */
    getIssueVotes<T = GetIssueVotesResponseOK>(options: GetIssueVotesRequest): Promise<GetIssueVotesResponseOK | T>;
    /**
     * Returns a list of all issue types visible to the user.
     * Alternative usage: Issue.Type.getTypes
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#issuetype-getIssueAllTypes
     * @param options Request options.
     */
    getIssueTypes<T = GetIssueTypesResponseOK>(options?: GetIssueTypesRequest): Promise<GetIssueTypesResponseOK | T>;
    /**
     * Creates an issue type from a JSON representation and adds the issue newly created issue type to the default issue type scheme.
     * Alternative usage: Issue.Type.createType
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#issuetype-createIssueType
     * @param options Request options.
     */
    createIssueType<T = CreateIssueTypeResponseOK>(options: CreateIssueTypeRequest): Promise<CreateIssueTypeResponseOK | T>;
    /**
     * Returns a full representation of the issue type that has the given id.
     * Alternative usage: Issue.Type.getType
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#issuetype-getIssueType
     * @param options Request options.
     */
    getIssueType<T = GetIssueTypeResponseOK>(options: GetIssueTypeRequest): Promise<GetIssueTypeResponseOK | T>;
    /**
    * Deletes the specified issue type. If the issue type has any associated issues, these issues will be migrated to the alternative issue type specified in the parameter.
    * You can determine the alternative issue types by calling the /rest/api/2/issuetype/{id}/alternatives resource.
    * Alternative usage: Issue.Type.deleteType
    * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#issuetype-deleteIssueType
    * @param options Request options.
    */
    deleteIssueType<T = DeleteIssueTypeResponseOK>(options: DeleteIssueTypeRequest): Promise<DeleteIssueTypeResponseOK | T>;
    /**
     * Updates the specified issue type from a JSON representation.
     * Alternative usage: Issue.Type.updateType
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#issuetype-updateIssueType
     * @param options Request options.
     */
    updateIssueType<T = UpdateIssueTypeResponseOK>(options: UpdateIssueTypeRequest): Promise<UpdateIssueTypeResponseOK | T>;
    /**
     * Returns a list of all alternative issue types for the given issue type id. The list will contain these issues types, to which issues assigned to the given issue type can be migrated.
     * The suitable alternatives are issue types which are assigned to the same workflow, the same field configuration and the same screen scheme.
     * Alternative usage: Issue.Type.getAlternativeTypes
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#issuetype-getAlternativeIssueTypes
     * @param options Request options.
     */
    getAlternativeIssueTypes<T = GetAlternativeIssueTypesResponseOK>(options: GetAlternativeIssueTypesRequest): Promise<GetAlternativeIssueTypesResponseOK | T>;
    /**
     * Creates an issue type scheme from a JSON representation. (Admin required)
     * Alternative usage: Issue.Type.Scheme.createScheme
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.2/#issuetypescheme-createIssueTypeScheme
     * @param options Request options.
     */
    createIssueTypeScheme<T = CreateIssueTypeSchemeResponseOK>(options: CreateIssueTypeSchemeRequest): Promise<CreateIssueTypeSchemeResponseOK | T>;
    /**
     * Returns a list of all issue type schemes visible to the user (must be admin).
     * All issue types associated with the scheme will only be returned if an additional query parameter is provided: expand=schemes.issueTypes.
     * Similarly, the default issue type associated with the scheme (if one exists) will only be returned if additional an query parameter is provided: expand=schemes.defaultIssueType.
     * Note that both query parameters can be used together: expand=schemes.issueTypes,schemes.defaultIssueType.
     * Alternative usage: Issue.Type.Scheme.getSchemes
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.2/#issuetypescheme-getAllIssueTypeSchemes
     * @param options Request options.
     */
    getIssueTypeSchemes<T = GetIssueTypeSchemesResponseOK>(options?: GetIssueTypeSchemesRequest): Promise<GetIssueTypeSchemesResponseOK | T>;
    /**
     * Returns a full representation of the issue type scheme that has the given id (must be admin).
     * Alternative usage: Issue.Type.Scheme.getScheme
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.2/#issuetypescheme-getIssueTypeScheme
     * @param options Request options.
     */
    getIssueTypeScheme<T = GetIssueTypeSchemeResponseOK>(options: GetIssueTypeSchemeRequest): Promise<GetIssueTypeSchemeResponseOK | T>;
    /**
     * Updates the specified issue type scheme from a JSON representation. (Admin required)
     * Alternative usage: Issue.Type.Scheme.updateScheme
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.2/#issuetypescheme-updateIssueTypeScheme
     * @param options Request options.
     */
    updateIssueTypeScheme<T = UpdateIssueTypeSchemeResponseOK>(options: UpdateIssueTypeSchemeRequest): Promise<UpdateIssueTypeSchemeResponseOK | T>;
    /**
     * Deletes the specified issue type scheme.
     * Any projects associated with this IssueTypeScheme will be automatically associated with the global default IssueTypeScheme. (Admin required)
     * Alternative usage: Issue.Type.Scheme.deleteScheme
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.2/#issuetypescheme-deleteIssueTypeScheme
     * @param options Request options.
     */
    deleteIssueTypeScheme<T = DeleteIssueTypeSchemeResponseOK>(options: DeleteIssueTypeSchemeRequest): Promise<DeleteIssueTypeSchemeResponseOK | T>;
    /**
     * Adds additional projects to those already associated with the specified issue type scheme. (Admin required)
     * Alternative usage: Issue.Type.Scheme.Project.addAssociations
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.2/#issuetypescheme-addProjectAssociationsToScheme
     * @param options Request options.
     */
    addProjectAssociationsToIssueTypeScheme<T = AddProjectAssociationsToIssueTypeSchemeResponseOK>(options: AddProjectAssociationsToIssueTypeSchemeRequest): Promise<AddProjectAssociationsToIssueTypeSchemeResponseOK | T>;
    /**
     * For the specified issue type scheme, returns all of the associated projects. (Admin required)
     * Alternative usage: Issue.Type.Scheme.Project.getAssociations
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.2/#issuetypescheme-getAssociatedProjects
     * @param options Request options.
     */
    getProjectAssociationsForIssueTypeScheme<T = GetProjectAssociationsForIssueTypeSchemeResponseOK>(options: GetProjectAssociationsForIssueTypeSchemeRequest): Promise<GetProjectAssociationsForIssueTypeSchemeResponseOK | T>;
    /**
     * Associates the given projects with the specified issue type scheme.
     * Any existing project-associations the issue type scheme has will be overwritten. (Admin required)
     * Alternative usage: Issue.Type.Scheme.Project.setAssociations
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.2/#issuetypescheme-setProjectAssociationsForScheme
     * @param options Request options.
     */
    setProjectAssociationsForIssueTypeScheme<T = SetProjectAssociationsForIssueTypeSchemeResponseOK>(options: SetProjectAssociationsForIssueTypeSchemeRequest): Promise<SetProjectAssociationsForIssueTypeSchemeResponseOK | T>;
    /**
     * Removes all project associations for the specified issue type scheme.
     * These projects revert to an association with the default/global issue type scheme.(Admin required)
     * Alternative usage: Issue.Type.Scheme.Project.removeAssociations
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.2/#issuetypescheme-removeAllProjectAssociations
     * @param options Request options.
     */
    removeProjectAssociationsForIssueTypeScheme<T = RemoveProjectAssociationsForIssueTypeSchemeResponseOK>(options: RemoveProjectAssociationsForIssueTypeSchemeRequest): Promise<RemoveProjectAssociationsForIssueTypeSchemeResponseOK | T>;
    /**
     * For the specified issue type scheme, removes the given project association.
     * This project reverts to an association with the default/global issue type scheme.(Admin required)
     * Alternative usage: Issue.Type.Scheme.Project.removeAssociation
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.2/#issuetypescheme-removeProjectAssociation
     * @param options Request options.
     */
    removeProjectAssociationForIssueTypeScheme<T = RemoveProjectAssociationForIssueTypeSchemeResponseOK>(options: RemoveProjectAssociationForIssueTypeSchemeRequest): Promise<RemoveProjectAssociationForIssueTypeSchemeResponseOK | T>;
    /**
     * Get a list of the transitions possible for this issue by the current user, along with fields that are required and their types.
     * Fields will only be returned if expand=transitions.fields.
     * The fields in the metadata correspond to the fields in the transition screen for that transition. Fields not in the screen will not be in the metadata.
     * Alternative usage: Issue.Transition.getTransitions
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#issue-getTransitions
     * @param options Request options.
     */
    getIssueTransitions<T = GetIssueTransitionsResponseOK>(options: GetIssueTransitionsRequest): Promise<GetIssueTransitionsResponseOK | T>;
    /**
     * Perform a transition on an issue. When performing the transition you can update or set other issue fields.
     * The fields that can be set on transtion, in either the fields parameter or the update parameter can be determined using the /rest/api/2/issue/{issueIdOrKey}/transitions?expand=transitions.fields resource. If a field is not configured to appear on the transition screen, then it will not be in the transition metadata, and a field validation error will occur if it is submitted. The updateHistory param adds the issues retrieved by this method to the current user's issue history, if set to true (by default, the issue history does not include issues retrieved via the REST API). You can view the issue history in the JIRA application, via the Issues dropdown or by using the lastViewed JQL field in an issue search.
     * Alternative usage: Issue.Transition.performTransition
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#issue-doTransition
     * @param options Request options.
     */
    performIssueTransition<T = PerformIssueTransitionResponseOK>(options: PerformIssueTransitionRequest): Promise<PerformIssueTransitionResponseOK | T>;
    /**
     * Returns an issue's subtask list.
     * Alternative usage: Issue.SubTask.getSubTasks
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#issue/{issueIdOrKey}/subtask-getSubTasks
     * @param options Request options.
     */
    getIssueSubTasks<T = GetIssueSubTasksResponseOK>(options: GetIssueSubTasksRequest): Promise<GetIssueSubTasksResponseOK | T>;
    /**
     * Alternative usage: Issue.SubTask.canMoveSubTask
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#issue/{issueIdOrKey}/subtask-canMoveSubTask
     * @param options Request options.
     */
    canMoveIssueSubTask<T = CanMoveIssueSubTaskResponseOK>(options: CanMoveIssueSubTaskRequest): Promise<CanMoveIssueSubTaskResponseOK | T>;
    /**
     * Alternative usage: Issue.SubTask.canMoveSubTask
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#issue/{issueIdOrKey}/subtask-canMoveSubTask
     * @param options Request options.
     */
    moveIssueSubTasks<T = MoveIssueSubTasksResponseOK>(options: MoveIssueSubTasksRequest): Promise<MoveIssueSubTasksResponseOK | T>;
    /**
     * Performs a search using JQL.
     * Alternative usage: Issue.Search.searchByJql
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#search-searchUsingSearchRequest
     * @param options Request options.
     */
    searchIssuesByJql<T = SearchIssuesByJqlResponseOK>(options: SearchIssuesByJqlRequest): Promise<SearchIssuesByJqlResponseOK | T>;
    /**
     * Returns a list of all resolutions.
     * Alternative usage: Issue.Resolution.getResolutions
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#resolution-getResolutions
     * @param options Request options.
     */
    getIssueResolutions<T = GetIssueResolutionsResponseOK>(options?: GetIssueResolutionsRequest): Promise<GetIssueResolutionsResponseOK | T>;
    /**
     * Returns a resolution.
     * Alternative usage: Issue.Resolution.getResolution
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#resolution-getResolution
     * @param options Request options.
     */
    getIssueResolution<T = GetIssueResolutionResponseOK>(options: GetIssueResolutionRequest): Promise<GetIssueResolutionResponseOK | T>;
    /**
     * Returns the keys of all properties for the issue identified by the key or by the id.
     * Alternative usage: Issue.Property.getPropertyKeys
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.2/#issue/{issueIdOrKey}/properties-getPropertiesKeys
     * @param options Request options.
     */
    getIssuePropertyKeys<T = GetIssuePropertyKeysResponseOK>(options: GetIssuePropertyKeysRequest): Promise<GetIssuePropertyKeysResponseOK | T>;
    /**
     * Removes the property from the issue identified by the key or by the id.
     * Ths user removing the property is required to have permissions to edit the issue.
     * Alternative usage: Issue.Property.deleteProperty
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.2/#issue/{issueIdOrKey}/properties-deleteProperty
     * @param options Request options.
     */
    deleteIssueProperty<T = DeleteIssuePropertyResponseOK>(options: DeleteIssuePropertyRequest): Promise<DeleteIssuePropertyResponseOK | T>;
    /**
     * Sets the value of the specified issue's property.
     * You can use this resource to store a custom data against the issue identified by the key or by the id.
     * The user who stores the data is required to have permissions to edit the issue.
     * Alternative usage: Issue.Property.setProperty
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.2/#issue/{issueIdOrKey}/properties-setProperty
     * @param options Request options.
     */
    setIssueProperty<T = SetIssuePropertyResponseOK>(options: SetIssuePropertyRequest): Promise<SetIssuePropertyResponseOK | T>;
    /**
     * Returns the value of the property with a given key from the issue identified by the key or by the id.
     * The user who retrieves the property is required to have permissions to read the issue.
     * Alternative usage: Issue.Property.getProperty
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.2/#issue/{issueIdOrKey}/properties-getProperty
     * @param options Request options.
     */
    getIssueProperty<T = GetIssuePropertyResponseOK>(options: GetIssuePropertyRequest): Promise<GetIssuePropertyResponseOK | T>;
    /**
     * Returns a list of all issue priorities.
     * Alternative usage: Issue.Priority.getPriorities
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#priority-getPriorities
     * @param options Request options.
     */
    getIssuePriorities<T = GetIssuePrioritiesResponseOK>(options?: GetIssuePrioritiesRequest): Promise<GetIssuePrioritiesResponseOK | T>;
    /**
     * Returns an issue priority.
     * Alternative usage: Issue.Priority.getPriority
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#priority-getPriority
     * @param options Request options.
     */
    getIssuePriority<T = GetIssuePriorityResponseOK>(options: GetIssuePriorityRequest): Promise<GetIssuePriorityResponseOK | T>;
    /**
     * Creates new priority scheme.
     * Alternative usage: Issue.Priority.Scheme.createScheme
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.2/#priorityschemes-createPriorityScheme
     * @param options Request options.
     */
    createIssuePriorityScheme<T = CreateIssuePrioritySchemeResponseOK>(options: CreateIssuePrioritySchemeRequest): Promise<CreateIssuePrioritySchemeResponseOK | T>;
    /**
     * Returns all priority schemes.
     * All project keys associated with the priority scheme will only be returned if additional query parameter is provided expand=schemes.projectKeys.
     * Alternative usage: Issue.Priority.Scheme.getSchemes
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.2/#priorityschemes-getPrioritySchemes
     * @param options Request options.
     */
    getIssuePrioritySchemes<T = GetIssuePrioritySchemesResponseOK>(options?: GetIssuePrioritySchemesRequest): Promise<GetIssuePrioritySchemesResponseOK | T>;
    /**
     * Deletes a priority scheme.
     * All projects using deleted scheme will use default priority scheme afterwards. Default priority scheme can't be deleted.
     * Alternative usage: Issue.Priority.Scheme.deleteScheme
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.2/#priorityschemes-deletePriorityScheme
     * @param options Request options.
     */
    deleteIssuePriorityScheme<T = DeleteIssuePrioritySchemeResponseOK>(options: DeleteIssuePrioritySchemeRequest): Promise<DeleteIssuePrioritySchemeResponseOK | T>;
    /**
     * Updates a priority scheme.
     * Update will be rejected if issue migration would be needed as a result of scheme update.
     * Priority scheme update with migration is possible from the UI.
     * All project keys associated with the priority scheme will only be returned if additional query parameter is provided expand=projectKeys.
     * Alternative usage: Issue.Priority.Scheme.updateScheme
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.2/#priorityschemes-updatePriorityScheme
     * @param options Request options.
     */
    updateIssuePriorityScheme<T = UpdateIssuePrioritySchemeResponseOK>(options: UpdateIssuePrioritySchemeRequest): Promise<UpdateIssuePrioritySchemeResponseOK | T>;
    /**
     * Gets a full representation of a priority scheme in JSON format.
     * All project keys associated with the priority scheme will only be returned if additional query parameter is provided expand=projectKeys.
     * Alternative usage: Issue.Priority.Scheme.getScheme
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.2/#priorityschemes-getPriorityScheme
     * @param options Request options.
     */
    getIssuePriorityScheme<T = GetIssuePrioritySchemeResponseOK>(options: GetIssuePrioritySchemeRequest): Promise<GetIssuePrioritySchemeResponseOK | T>;
    /**
     * Returns the meta data for editing an issue. The fields in the editmeta correspond to the fields in the edit screen for the issue. Fields not in the screen will not be in the editmeta.
     * Alternative usage: Issue.Metadata.getEditMetadata
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#issue-getEditIssueMeta
     * @param options Request options.
     */
    getEditIssueMetadata<T = GetEditIssueMetadataResponseOK>(options: GetEditIssueMetadataRequest): Promise<GetEditIssueMetadataResponseOK | T>;
    /**
     * Returns the meta data for creating issues. This includes the available projects, issue types and fields, including field types and whether or not those fields are required. Projects will not be returned if the user does not have permission to create issues in that project.
     * The fields in the createmeta correspond to the fields in the create screen for the project/issuetype. Fields not in the screen will not be in the createmeta.
     * Fields will only be returned if expand=projects.issuetypes.fields.
     * The results can be filtered by project and/or issue type, given by the query params.
     * Alternative usage: Issue.Metadata.getCreateMetadata
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#issue-getCreateIssueMeta
     * @param options Request options.
     * @deprecated
     */
    getCreateIssueMetadata<T = GetCreateIssueMetadataResponseOK>(options?: GetCreateIssueMetadataRequest): Promise<GetCreateIssueMetadataResponseOK | T>;
    /**
     * Creates an issue link between two issues. The user requires the link issue permission for the issue which will be linked to another issue. The specified link type in the request is used to create the link and will create a link from the first issue to the second issue using the outward description. It also create a link from the second issue to the first issue using the inward description of the issue link type. It will add the supplied comment to the first issue. The comment can have a restriction who can view it. If group is specified, only users of this group can view this comment, if roleLevel is specified only users who have the specified role can view this comment. The user who creates the issue link needs to belong to the specified group or have the specified role.
     * Alternative usage: Issue.Link.createLink
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#issueLink-linkIssues
     * @param options Request options.
     */
    createIssueLink<T = CreateIssueLinkResponseOK>(options: CreateIssueLinkRequest): Promise<CreateIssueLinkResponseOK | T>;
    /**
     * Returns an issue link with the specified id.
     * Alternative usage: Issue.Link.getLink
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#issueLink-getIssueLink
     * @param options Request options.
     */
    getIssueLink<T = GetIssueLinkResponseOK>(options: GetIssueLinkRequest): Promise<GetIssueLinkResponseOK | T>;
    /**
     * Deletes an issue link with the specified id. To be able to delete an issue link you must be able to view both issues and must have the link issue permission for at least one of the issues.
     * Alternative usage: Issue.Link.deleteLink
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#issueLink-deleteIssueLink
     * @param options Request options.
     */
    deleteIssueLink<T = DeleteIssueLinkResponseOK>(options: DeleteIssueLinkRequest): Promise<DeleteIssueLinkResponseOK | T>;
    /**
     * A REST sub-resource representing the remote issue links on the issue.
     * Alternative usage: Issue.Link.Remote.getLinks
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#issue-getRemoteIssueLinks
     * @param options Request options.
     */
    getRemoteIssueLinks<T = GetRemoteIssueLinksResponseOK>(options: GetRemoteIssueLinksRequest): Promise<GetRemoteIssueLinksResponseOK | T>;
    /**
     * Creates or updates a remote issue link from a JSON representation. If a globalId is provided and a remote issue link exists with that globalId, the remote issue link is updated. Otherwise, the remote issue link is created.
     * Alternative usage: Issue.Link.Remote.createOrUpdateLink
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#issue-createOrUpdateRemoteIssueLink
     * @param options Request options.
     */
    createOrUpdateRemoteIssueLink<T = CreateOrUpdateRemoteIssueLinkResponseOK>(options: CreateOrUpdateRemoteIssueLinkRequest): Promise<CreateOrUpdateRemoteIssueLinkResponseOK | T>;
    /**
     * Delete the remote issue link with the given global id on the issue.
     * Alternative usage: Issue.Link.Remote.deleteLinkByGlobalId
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#issue-deleteRemoteIssueLinkByGlobalId
     * @param options Request options.
     */
    deleteRemoteIssueLinkByGlobalId<T = DeleteRemoteIssueLinkByGlobalIdResponseOK>(options: DeleteRemoteIssueLinkByGlobalIdRequest): Promise<DeleteRemoteIssueLinkByGlobalIdResponseOK | T>;
    /**
     * Get the remote issue link with the given id on the issue.
     * Alternative usage: Issue.Link.Remote.getLink
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#issue-getRemoteIssueLinkById
     * @param options Request options.
     */
    getRemoteIssueLink<T = GetRemoteIssueLinkResponseOK>(options: GetRemoteIssueLinkRequest): Promise<GetRemoteIssueLinkResponseOK | T>;
    /**
     * Updates a remote issue link from a JSON representation. Any fields not provided are set to null.
     * Alternative usage: Issue.Link.Remote.updateLink
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#issue-updateRemoteIssueLink
     * @param options Request options.
     */
    updateRemoteIssueLink<T = UpdateRemoteIssueLinkResponseOK>(options: UpdateRemoteIssueLinkRequest): Promise<UpdateRemoteIssueLinkResponseOK | T>;
    /**
     * Delete the remote issue link with the given id on the issue.
     * Alternative usage: Issue.Link.Remote.deleteLink
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#issue-deleteRemoteIssueLinkById
     * @param options Request options.
     */
    deleteRemoteIssueLink<T = DeleteRemoteIssueLinkResponseOK>(options: DeleteRemoteIssueLinkRequest): Promise<DeleteRemoteIssueLinkResponseOK | T>;
    /**
     * Returns a list of available issue link types, if issue linking is enabled. Each issue link type has an id, a name and a label for the outward and inward link relationship.
     * Alternative usage: Issue.Link.Type.getTypes
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#issueLinkType-getIssueLinkTypes
     * @param options Request options.
     */
    getIssueLinkTypes<T = GetIssueLinkTypesResponseOK>(options?: GetIssueLinkTypesRequest): Promise<GetIssueLinkTypesResponseOK | T>;
    /**
     * Returns for a given issue link type id all information about this issue link type.
     * Alternative usage: Issue.Link.Type.getType
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#issueLinkType-getIssueLinkType
     * @param options Request options.
     */
    getIssueLinkType<T = GetIssueLinkTypeResponseOK>(options: GetIssueLinkTypeRequest): Promise<GetIssueLinkTypeResponseOK | T>;
    /**
     * Create a new issue link type.
     * Alternative usage: Issue.Link.Type.createType
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#issueLinkType-createIssueLinkType
     * @param options Request options.
     */
    createIssueLinkType<T = CreateIssueLinkTypeResponseOK>(options: CreateIssueLinkTypeRequest): Promise<CreateIssueLinkTypeResponseOK | T>;
    /**
     * Delete the specified issue link type.
     * Alternative usage: Issue.Link.Type.deleteType
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#issueLinkType-deleteIssueLinkType
     * @param options Request options.
     */
    deleteIssueLinkType<T = DeleteIssueLinkTypeResponseOK>(options: DeleteIssueLinkTypeRequest): Promise<DeleteIssueLinkTypeResponseOK | T>;
    /**
     * Update the specified issue link type.
     * Alternative usage: Issue.Link.Type.updateType
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#issueLinkType-updateIssueLinkType
     * @param options Request options.
     */
    updateIssueLinkType<T = UpdateIssueLinkTypeResponseOK>(options: UpdateIssueLinkTypeRequest): Promise<UpdateIssueLinkTypeResponseOK | T>;
    /**
     * Returns a list of all fields, both System and Custom.
     * Alternative usage: Issue.Field.getFields
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#field-getFields
     * @param options Request options.
     */
    getIssueFields<T = GetIssueFieldsResponseOK>(options: GetIssueFieldsRequest): Promise<GetIssueFieldsResponseOK | T>;
    /**
     * Alternative: Issue.Field.Custom.getFields
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#customFields-getCustomFields
     * @param options Request options.
     */
    getIssueCustomFields<T = GetIssueCustomFieldsResponseOK>(options?: GetIssueCustomFieldsRequest): Promise<GetIssueCustomFieldsResponseOK | T>;
    /**
     * Returns a full representation of the Custom Field Option that has the given id.
     * Alternative: Issue.Field.Custom.Option.getOption
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#customFieldOption-getCustomFieldOption
     * @param options Request options.
     */
    getIssueCustomFieldOption<T = GetIssueCustomFieldOptionResponseOK>(options: GetIssueCustomFieldOptionRequest): Promise<GetIssueCustomFieldOptionResponseOK | T>;
    /**
     * Returns the meta-data for an attachment, including the URI of the actual attached file.
     * Alternative usage: Issue.Attachment.getAttachment
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#attachment-getAttachment
     * @param options Request options.
     */
    getIssueAttachment<T = GetIssueAttachmentResponseOK>(options: GetIssueAttachmentRequest): Promise<GetIssueAttachmentResponseOK | T>;
    /**
     * Remove an attachment from an issue.
     * Alternative usage: Issue.Attachment.removeAttachment
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#attachment-removeAttachment
     * @param options Request options.
     */
    removeIssueAttachment<T = RemoveIssueAttachmentResponseOK>(options: RemoveIssueAttachmentRequest): Promise<RemoveIssueAttachmentResponseOK | T>;
    /**
     * Add one or more attachments to an issue.
     * Alternative usage: Issue.Attachment.addAttachment
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#issue/{issueIdOrKey}/attachments-addAttachment
     * @param options Request options.
     */
    addIssueAttachment<T = AddIssueAttachmentResponseOK>(options: AddIssueAttachmentRequest): Promise<AddIssueAttachmentResponseOK | T>;
    /**
     * Returns the meta information for an attachments, specifically if they are enabled and the maximum upload size allowed.
     * Alternative usage: Issue.Attachment.Metadata.getMetadata
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#attachment-getAttachmentMeta
     * @param options Request options.
     */
    getIssueAttachmentMetadata<T = GetIssueAttachmentMetadataResponseOK>(options?: GetIssueAttachmentMetadataRequest): Promise<GetIssueAttachmentMetadataResponseOK | T>;
    /**
     * Returns the keys of all properties for the comment identified by the key or by the id.
     * Alternative usage: Issue.Comment.Property.getPropertyKeys
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.2/#comment/{commentId}/properties-getPropertiesKeys
     * @param options Request options.
     */
    getIssueCommentPropertyKeys<T = GetIssueCommentPropertyKeysResponseOK>(options: GetIssueCommentPropertyKeysRequest): Promise<GetIssueCommentPropertyKeysResponseOK | T>;
    /**
     * Removes the property from the comment identified by the key or by the id.
     * Ths user removing the property is required to have permissions to administer the comment.
     * Alternative usage: Issue.Comment.Property.deleteProperty
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.2/#comment/{commentId}/properties-deleteProperty
     * @param options Request options.
     */
    deleteIssueCommentProperty<T = DeleteIssueCommentPropertyResponseOK>(options: DeleteIssueCommentPropertyRequest): Promise<DeleteIssueCommentPropertyResponseOK | T>;
    /**
     * Sets the value of the specified comment's property.
     * You can use this resource to store a custom data against the comment identified by the key or by the id.
     * The user who stores the data is required to have permissions to administer the comment.
     * Alternative usage: Issue.Comment.Property.setProperty
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.2/#comment/{commentId}/properties-setProperty
     * @param options Request options.
     */
    setIssueCommentProperty<T = SetIssueCommentPropertyResponseOK>(options: SetIssueCommentPropertyRequest): Promise<SetIssueCommentPropertyResponseOK | T>;
    /**
     * Sets the value of the specified comment's property.
     * You can use this resource to store a custom data against the comment identified by the key or by the id.
     * The user who stores the data is required to have permissions to administer the comment.
     * Alternative usage: Issue.Comment.Property.setProperty
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.2/#comment/{commentId}/properties-setProperty
     * @param options Request options.
     */
    getIssueCommentProperty<T = GetIssueCommentPropertyResponseOK>(options: GetIssueCommentPropertyRequest): Promise<GetIssueCommentPropertyResponseOK | T>;
    /**
     * Returns an application property.
     * Alternative usage: Instance.getApplicationProperty
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#application-properties-getProperty
     * @param options Request options.
     */
    getApplicationProperty<T = GetApplicationPropertyResponseOK>(options?: GetApplicationPropertyRequest): Promise<GetApplicationPropertyResponseOK | T>;
    /**
     * Modify an application property via PUT. The "value" field present in the PUT will override the existing value.
     * Alternative usage: Instance.setApplicationProperty
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#application-properties-setPropertyViaRestfulTable
     * @param options Request options.
     */
    setApplicationProperty<T = SetApplicationPropertyResponseOK>(options: SetApplicationPropertyRequest): Promise<SetApplicationPropertyResponseOK | T>;
    /**
     * Returns the properties that are displayed on the "General Configuration > Advanced Settings" page.
     * Alternative usage: Instance.getAdvancedSettings
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#application-properties-getAdvancedSettings
     * @param options Request options.
     */
    getAdvancedSettings<T = GetAdvancedSettingsResponseOK>(options?: GetAdvancedSettingsRequest): Promise<GetAdvancedSettingsResponseOK | T>;
    /**
     * Returns the properties that are displayed on the "General Configuration > Advanced Settings" page.
     * Alternative usage: Instance.getAdvancedSettings
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#application-properties-getAdvancedSettings
     * @param options Request options.
     */
    getInstanceConfiguration<T = GetInstanceConfigurationResponseOK>(options?: GetInstanceConfigurationRequest): Promise<GetInstanceConfigurationResponseOK | T>;
    /**
     * Returns the properties that are displayed on the "General Configuration > Advanced Settings" page.
     * Alternative usage: Instance.getAdvancedSettings
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#application-properties-getAdvancedSettings
     * @param options Request options.
     */
    getInstanceInfo<T = GetInstanceInfoResponseOK>(options?: GetInstanceInfoRequest): Promise<GetInstanceInfoResponseOK | T>;
    /**
     * Creates a group by given group parameter.
     * Alternative usage: Group.createGroup
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#group-createGroup
     * @param options Request options.
     */
    createGroup<T = CreateGroupResponseOK>(options: CreateGroupRequest): Promise<CreateGroupResponseOK | T>;
    /**
     * Deletes a group by given group parameter.
     * Alternative usage: Group.removeGroup
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#group-removeGroup
     * @param options Request options.
     */
    removeGroup<T = RemoveGroupResponseOK>(options?: RemoveGroupRequest): Promise<RemoveGroupResponseOK | T>;
    /**
     * This resource returns a paginated list of users who are members of the specified group and its subgroups. Users in the page are ordered by user names. User of this resource is required to have sysadmin or admin permissions.
     * Alternative usage: Group.User.getUsers
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#group-getUsersFromGroup
     * @param options Request options.
     */
    getUsersFromGroup<T = GetUsersFromGroupResponseOK>(options: GetUsersFromGroupRequest): Promise<GetUsersFromGroupResponseOK | T>;
    /**
     * Adds given user to a group.
     * Alternative usage: Group.User.addUsers
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#group-addUserToGroup
     * @param options Request options.
     */
    addUsersToGroup<T = AddUsersToGroupResponseOK>(options: AddUsersToGroupRequest): Promise<AddUsersToGroupResponseOK | T>;
    /**
     * Removes given user from a group.
     * Alternative usage: Group.User.removeUsers
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#group-removeUserFromGroup
     * @param options Request options.
     */
    removeUsersFromGroup<T = RemoveUsersFromGroupResponseOK>(options?: RemoveUsersFromGroupRequest): Promise<RemoveUsersFromGroupResponseOK | T>;
    /**
     * Creates a new filter, and returns newly created filter. Currently sets permissions just using the users default sharing permissions.
     * Alternative usage: Filter.createFilter
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#filter-createFilter
     * @param options Request options.
     */
    createFilter<T = CreateFilterResponseOK>(options: CreateFilterRequest): Promise<CreateFilterResponseOK | T>;
    /**
     * Returns a filter given an id.
     * Alternative usage: Filter.getFilter
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#filter-getFilter
     * @param options Request options.
     */
    getFilter<T = GetFilterResponseOK>(options: GetFilterRequest): Promise<GetFilterResponseOK | T>;
    /**
     * Updates an existing filter, and returns its new value.
     * Alternative usage: Filter.editFilter
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#filter-editFilter
     * @param options Request options.
     */
    editFilter<T = EditFilterResponseOK>(options: EditFilterRequest): Promise<EditFilterResponseOK | T>;
    /**
     * Delete a filter.
     * Alternative usage: Filter.deleteFilter
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#filter-deleteFilter
     * @param options Request options.
     */
    deleteFilter<T = DeleteFilterResponseOK>(options: DeleteFilterRequest): Promise<DeleteFilterResponseOK | T>;
    /**
     * Returns the favourite filters of the logged-in user.
     * Alternative usage: Filter.getMyFavouriteFilters
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#filter-getFavouriteFilters
     * @param options Request options.
     */
    getMyFavouriteFilters<T = GetMyFavouriteFiltersResponseOK>(options?: GetMyFavouriteFiltersRequest): Promise<GetMyFavouriteFiltersResponseOK | T>;
    /**
     * Returns the default share scope of the logged-in user.
     * Alternative usage: Filter.Share.getShareScope
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#filter-getDefaultShareScope
     * @param options Request options.
     */
    getDefaultShareScope<T = GetDefaultShareScopeResponseOK>(options?: GetDefaultShareScopeRequest): Promise<GetDefaultShareScopeResponseOK | T>;
    /**
     * Sets the default share scope of the logged-in user. Available values are GLOBAL and PRIVATE.
     * Alternative usage: Filter.Share.setShareScope
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#filter-setDefaultShareScope
     * @param options Request options.
     */
    setDefaultShareScope<T = SetDefaultShareScopeResponseOK>(options: SetDefaultShareScopeRequest): Promise<SetDefaultShareScopeResponseOK | T>;
    /**
     * Returns the default columns for the given filter. Currently logged in user will be used as the user making such request.
     * Alternative usage: Filter.Column.getDefaultColumns
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#filter-defaultColumns
     * @param options Request options.
     */
    getFilterDefaultColumns<T = GetFilterDefaultColumnsResponseOK>(options: GetFilterDefaultColumnsRequest): Promise<GetFilterDefaultColumnsResponseOK | T>;
    /**
     * Sets the default columns for the given filter.
     * Alternative usage: Filter.Column.setDefaultColumns
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#filter-setColumns
     * @param options Request options.
     */
    setFilterDefaultColumns<T = SetFilterDefaultColumnsResponseOK>(options: SetFilterDefaultColumnsRequest): Promise<SetFilterDefaultColumnsResponseOK | T>;
    /**
     * Resets the columns for the given filter such that the filter no longer has its own column config.
     * Alternative usage: Filter.Column.resetColumns
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#filter-resetColumns
     * @param options Request options.
     */
    resetFilterColumns<T = ResetFilterColumnsResponseOK>(options: ResetFilterColumnsRequest): Promise<ResetFilterColumnsResponseOK | T>;
    /**
     * Returns all share permissions of the given filter.
     * Alternative usage: Filter.Share.Permission.getSharePermissions
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#filter-getSharePermissions
     * @param options Request options.
     */
    getFilterSharePermissions<T = GetFilterSharePermissionsResponseOK>(options: GetFilterSharePermissionsRequest): Promise<GetFilterSharePermissionsResponseOK | T>;
    /**
     * Adds a share permissions to the given filter. Adding a global permission removes all previous permissions from the filter.
     * Alternative usage: Filter.Share.Permission.addSharePermission
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#filter-addSharePermission
     * @param options Request options.
     */
    addFilterSharePermission<T = AddFilterSharePermissionResponseOK>(options: AddFilterSharePermissionRequest): Promise<AddFilterSharePermissionResponseOK | T>;
    /**
     * Returns a single share permission of the given filter.
     * Alternative usage: Filter.Share.Permission.getSharePermissions
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#filter-getSharePermission
     * @param options Request options.
     */
    getFilterSharePermission<T = GetFilterSharePermissionResponseOK>(options: GetFilterSharePermissionRequest): Promise<GetFilterSharePermissionResponseOK | T>;
    /**
     * Removes a share permissions from the given filter.
     * Alternative usage: Filter.Share.Permission.deleteSharePermission
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#filter-getSharePermission
     * @param options Request options.
     */
    deleteFilterSharePermission<T = DeleteFilterSharePermissionResponseOK>(options: DeleteFilterSharePermissionRequest): Promise<DeleteFilterSharePermissionResponseOK | T>;
    /**
     * Returns a list of all dashboards, optionally filtering them.
     * Alternative usage: Dashboard.getDashboards
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#dashboard-list
     * @param options Request options.
     */
    getAllDashboards<T = GetAllDashboardsResponseOK>(options?: GetAllDashboardsRequest): Promise<GetAllDashboardsResponseOK | T>;
    /**
     * Returns a single dashboard.
     * Alternative usage: Dashboard.getDashboard
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#dashboard-getDashboard
     * @param options Request options.
     */
    getDashboardById<T = GetDashboardByIdResponseOK>(options: GetDashboardByIdRequest): Promise<GetDashboardByIdResponseOK | T>;
    /**
     * Create a new workflow scheme.
     * The body contains a representation of the new scheme. Values not passed are assumed to be set to their defaults.
     * Alternative usage: Workflow.Scheme.createScheme
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.2/#workflowscheme-createScheme
     * @param options Request options.
     */
    createWorkflowScheme<T = CreateWorkflowSchemeResponseOK>(options: CreateWorkflowSchemeRequest): Promise<CreateWorkflowSchemeResponseOK | T>;
    /**
     * Returns the requested workflow scheme to the caller.
     * Alternative usage: Workflow.Scheme.getScheme
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.2/#workflowscheme-getById
     * @param options Request options.
     */
    getWorkflowScheme<T = GetWorkflowSchemeResponseOK>(options: GetWorkflowSchemeRequest): Promise<GetWorkflowSchemeResponseOK | T>;
    /**
     * Delete the passed workflow scheme.
     * Alternative usage: Workflow.Scheme.deleteScheme
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.2/#workflowscheme-deleteScheme
     * @param options Request options.
     */
    deleteWorkflowScheme<T = DeleteWorkflowSchemeResponseOK>(options: DeleteWorkflowSchemeRequest): Promise<DeleteWorkflowSchemeResponseOK | T>;
    /**
     * Update the passed workflow scheme.
     * The body of the request is a representation of the workflow scheme.
     * Values not passed are assumed to indicate no change for that field.
     * Alternative usage: Workflow.Scheme.updateScheme
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.2/#workflowscheme-update
     * @param options Request options.
     */
    updateWorkflowScheme<T = UpdateWorkflowSchemeResponseOK>(options: UpdateWorkflowSchemeRequest): Promise<UpdateWorkflowSchemeResponseOK | T>;
    /**
     * Returns a list of all statuses.
     * Alternative usage: Workflow.Status.getStatuses
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#status-getStatuses
     * @param options Request options.
     */
    getWorkflowStatuses<T = GetWorkflowStatusesResponseOK>(options?: GetWorkflowStatusesRequest): Promise<GetWorkflowStatusesResponseOK | T>;
    /**
     * Returns a full representation of the Status having the given id or name.
     * Alternative usage: Workflow.Status.getStatus
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#status-getStatus
     * @param options Request options.
     */
    getWorkflowStatus<T = GetWorkflowStatusResponseOK>(options: GetWorkflowStatusRequest): Promise<GetWorkflowStatusResponseOK | T>;
    /**
     * Returns a list of all status categories.
     * Alternative usage: Workflow.Status.Category.getCategories
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#statuscategory-getStatusCategories
     * @param options Request options.
     */
    getWorkflowStatusCategories<T = GetWorkflowStatusCategoriesResponseOK>(options?: GetWorkflowStatusCategoriesRequest): Promise<GetWorkflowStatusCategoriesResponseOK | T>;
    /**
     * Returns a full representation of the StatusCategory having the given id or key.
     * Alternative usage: Workflow.Status.Category.getCategory
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#statuscategory-getStatusCategory
     * @param options Request options.
     */
    getWorkflowStatusCategory<T = GetWorkflowStatusCategoryResponseOK>(options: GetWorkflowStatusCategoryRequest): Promise<GetWorkflowStatusCategoryResponseOK | T>;
    /**
     * Returns all workflows.
     * Alternative usage: Workflow.getWorkflows
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#workflow-getAllWorkflows
     * @param options Request options.
     */
    getWorkflows<T = GetWorkflowsResponseOK>(options?: GetWorkflowsRequest): Promise<GetWorkflowsResponseOK | T>;
    /**
     * Returns all ApplicationRoles in the system.
     * Will also return an ETag header containing a version hash of the collection of ApplicationRoles.
     * Alternative usage: Application.Role.getRoles
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.2/#applicationrole-getAll
     * @param options Request options.
     */
    getApplicationRoles<T = GetApplicationRolesResponseOK>(options?: GetApplicationRolesRequest): Promise<GetApplicationRolesResponseOK | T>;
    /**
     * Returns the ApplicationRole with passed key if it exists.
     * Alternative usage: Application.Role.getRole
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.2/#applicationrole-get
     * @param options Request options.
     */
    getApplicationRole<T = GetApplicationRoleResponseOK>(options: GetApplicationRoleRequest): Promise<GetApplicationRoleResponseOK | T>;
    /**
     * Updates the ApplicationRole with the passed data.
     * Only the groups and default groups setting of the role may be updated.
     * Requests to change the key or the name of the role will be silently ignored.
     * Alternative usage: Application.Role.updateRole
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.2/#applicationrole-put
     * @param options Request options.
     */
    updateApplicationRole<T = UpdateApplicationRoleResponseOK>(options: UpdateApplicationRoleRequest): Promise<UpdateApplicationRoleResponseOK | T>;
    /**
     * Creates an issue or a sub-task from a JSON representation.
     * The fields that can be set on create, in either the fields parameter or the update parameter can be determined using the /rest/api/2/issue/createmeta resource. If a field is not configured to appear on the create screen, then it will not be in the createmeta, and a field validation error will occur if it is submitted.
     * Creating a sub-task is similar to creating a regular issue, with two important differences:
     * the issueType field must correspond to a sub-task issue type (you can use /issue/createmeta to discover sub-task issue types), and you must provide a parent field in the issue create request containing the id or key of the parent issue.
     * Alternative usage: Issue.createIssue
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#issue-createIssue
     * @param options Request options.
     */
    createIssue<T = CreateIssueResponseOK>(options: CreateIssueRequest): Promise<CreateIssueResponseOK | T>;
    /**
     * Returns a full representation of the issue for the given issue key.
     * JIRA will attempt to identify the issue by the issueIdOrKey path parameter. This can be an issue id, or an issue key. If the issue cannot be found via an exact match, JIRA will also look for the issue in a case-insensitive way, or by looking to see if the issue was moved. In either of these cases, the request will proceed as normal (a 302 or other redirect will not be returned). The issue key contained in the response will indicate the current value of issue's key.
     * Alternative usage: Issue.getIssue
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#issue-getIssue
     * @param options Request options.
     */
    getIssue<T = GetIssueResponseOK>(options: GetIssueRequest): Promise<GetIssueResponseOK | T>;
    /**
     * Edits an issue from a JSON representation.
     * The issue can either be updated by setting explicit the field value(s) or by using an operation to change the field value.
     * The fields that can be updated, in either the fields parameter or the update parameter, can be determined using the /rest/api/2/issue/{issueIdOrKey}/editmeta resource.
     * If a field is not configured to appear on the edit screen, then it will not be in the editmeta, and a field validation error will occur if it is submitted.
     * Specifying a "field_id": field_value in the "fields" is a shorthand for a "set" operation in the "update" section.
     * Field should appear either in "fields" or "update", not in both.
     * Alternative usage: Issue.editIssue
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#issue-editIssue
     * @param options Request options.
     */
    editIssue<T = EditIssueResponseOK>(options: EditIssueRequest): Promise<EditIssueResponseOK | T>;
    /**
     * Delete an issue. If the issue has subtasks you must set the parameter deleteSubtasks=true to delete the issue. You cannot delete an issue without its subtasks also being deleted.
     * Alternative usage: Issue.deleteIssue
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#issue-deleteIssue
     * @param options Request options.
     */
    deleteIssue<T = DeleteIssueResponseOK>(options: DeleteIssueRequest): Promise<DeleteIssueResponseOK | T>;
    /**
     * Assigns an issue to a user. You can use this resource to assign issues when the user submitting the request has the assign permission but not the edit issue permission. If the name is "-1" automatic assignee is used. A null name will remove the assignee.
     * Alternative usage: Issue.assignIssue
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#issue-assign
     * @param options Request options.
     */
    assignIssue<T = AssignIssueResponseOK>(options: AssignIssueRequest): Promise<AssignIssueResponseOK | T>;
    /**
     * Sends a notification (email) to the list or recipients defined in the request.
     * Alternative usage: Issue.sendNotification
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#issue-notify
     * @param options Request options.
     */
    sendNotificationForIssue<T = SendNotificationForIssueResponseOK>(options: SendNotificationForIssueRequest): Promise<SendNotificationForIssueResponseOK | T>;
    /**
     * Returns all comments for an issue.
     * Alternative usage: Issue.Comment.getComments
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#issue-getComments
     * @param options Request options.
     */
    getIssueComments<T = GetIssueCommentsResponseOK>(options: GetIssueCommentsRequest): Promise<GetIssueCommentsResponseOK | T>;
    /**
     * Adds a new comment to an issue.
     * Alternative usage: Issue.Comment.addComment
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#issue-addComment
     * @param options Request options.
     */
    addIssueComment<T = AddIssueCommentResponseOK>(options: AddIssueCommentRequest): Promise<AddIssueCommentResponseOK | T>;
    /**
     * Returns a single comment.
     * Alternative usage: Issue.Comment.getComment
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#issue-getComment
     * @param options Request options.
     */
    getIssueComment<T = GetIssueCommentResponseOK>(options: GetIssueCommentRequest): Promise<GetIssueCommentResponseOK | T>;
    /**
     * Updates an existing comment using its JSON representation.
     * Alternative usage: Issue.Comment.updateComment
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#issue-updateComment
     * @param options Request options.
     */
    updateIssueComment<T = UpdateIssueCommentResponseOK>(options: UpdateIssueCommentRequest): Promise<UpdateIssueCommentResponseOK | T>;
    /**
     * Deletes an existing comment.
     * Alternative usage: Issue.Comment.deleteComment
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#issue-deleteComment
     * @param options Request options.
     */
    deleteIssueComment<T = DeleteIssueCommentResponseOK>(options: DeleteIssueCommentRequest): Promise<DeleteIssueCommentResponseOK | T>;
}
declare class IssueGroup {
    private implementation;
    private getGlobalErrorStrategy;
    Comment: CommentGroup;
    Metadata: MetadataGroup;
    Link: LinkGroup;
    Vote: VoteGroup;
    Watcher: WatcherGroup;
    Worklog: WorklogGroup;
    Transition: TransitionGroup;
    SubTask: SubTaskGroup;
    Field: FieldGroup;
    Attachment: AttachmentGroup;
    Type: TypeGroup;
    Priority: PriorityGroup;
    Resolution: ResolutionGroup;
    Search: SearchGroup;
    Security: IssueSecurityGroup;
    Notification: IssueNotificationGroup;
    Property: IssuePropertyGroup;
    constructor(implementation: PlatformImplementation, getGlobalErrorStrategy: GetGlobalErrorStrategy);
    /**
     * Creates an issue or a sub-task from a JSON representation.
     * The fields that can be set on create, in either the fields parameter or the update parameter can be determined using the /rest/api/2/issue/createmeta resource. If a field is not configured to appear on the create screen, then it will not be in the createmeta, and a field validation error will occur if it is submitted.
     * Creating a sub-task is similar to creating a regular issue, with two important differences:
     * the issueType field must correspond to a sub-task issue type (you can use /issue/createmeta to discover sub-task issue types), and you must provide a parent field in the issue create request containing the id or key of the parent issue.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#issue-createIssue
     * @param options Request options.
     */
    createIssue<T = CreateIssueResponseOK>(options: CreateIssueRequest): Promise<CreateIssueResponseOK | T>;
    /**
     * Returns a full representation of the issue for the given issue key.
     * JIRA will attempt to identify the issue by the issueIdOrKey path parameter. This can be an issue id, or an issue key. If the issue cannot be found via an exact match, JIRA will also look for the issue in a case-insensitive way, or by looking to see if the issue was moved. In either of these cases, the request will proceed as normal (a 302 or other redirect will not be returned). The issue key contained in the response will indicate the current value of issue's key.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#issue-getIssue
     * @param options Request options.
     */
    getIssue<T = GetIssueResponseOK>(options: GetIssueRequest): Promise<GetIssueResponseOK | T>;
    /**
     * Delete an issue. If the issue has subtasks you must set the parameter deleteSubtasks=true to delete the issue. You cannot delete an issue without its subtasks also being deleted.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#issue-deleteIssue
     * @param options Request options.
     */
    deleteIssue<T = DeleteIssueResponseOK>(options: DeleteIssueRequest): Promise<DeleteIssueResponseOK | T>;
    /**
     * Edits an issue from a JSON representation.
     * The issue can either be updated by setting explicit the field value(s) or by using an operation to change the field value.
     * The fields that can be updated, in either the fields parameter or the update parameter, can be determined using the /rest/api/2/issue/{issueIdOrKey}/editmeta resource.
     * If a field is not configured to appear on the edit screen, then it will not be in the editmeta, and a field validation error will occur if it is submitted.
     * Specifying a "field_id": field_value in the "fields" is a shorthand for a "set" operation in the "update" section.
     * Field should appear either in "fields" or "update", not in both.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#issue-editIssue
     * @param options Request options.
     */
    editIssue<T = EditIssueResponseOK>(options: EditIssueRequest): Promise<EditIssueResponseOK | T>;
    /**
     * Assigns an issue to a user. You can use this resource to assign issues when the user submitting the request has the assign permission but not the edit issue permission. If the name is "-1" automatic assignee is used. A null name will remove the assignee.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#issue-assign
     * @param options Request options.
     */
    assignIssue<T = AssignIssueResponseOK>(options: AssignIssueRequest): Promise<AssignIssueResponseOK | T>;
    /**
     * Sends a notification (email) to the list or recipients defined in the request.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#issue-notify
     * @param options Request options.
     */
    sendNotification<T = SendNotificationForIssueResponseOK>(options: SendNotificationForIssueRequest): Promise<SendNotificationForIssueResponseOK | T>;
}
declare class CommentGroup {
    private implementation;
    private getGlobalErrorStrategy;
    Property: IssueCommentPropertyGroup;
    constructor(implementation: PlatformImplementation, getGlobalErrorStrategy: GetGlobalErrorStrategy);
    /**
     * Returns all comments for an issue.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#issue-getComments
     * @param options Request options.
     */
    getComments<T = GetIssueCommentsResponseOK>(options: GetIssueCommentsRequest): Promise<GetIssueCommentsResponseOK | T>;
    /**
     * Adds a new comment to an issue.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#issue-addComment
     * @param options Request options.
     */
    addComment<T = AddIssueCommentResponseOK>(options: AddIssueCommentRequest): Promise<AddIssueCommentResponseOK | T>;
    /**
     * Returns a single comment.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#issue-getComment
     * @param options Request options.
     */
    getComment<T = GetIssueCommentResponseOK>(options: GetIssueCommentRequest): Promise<GetIssueCommentResponseOK | T>;
    /**
     * Updates an existing comment using its JSON representation.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#issue-updateComment
     * @param options Request options.
     */
    updateComment<T = UpdateIssueCommentResponseOK>(options: UpdateIssueCommentRequest): Promise<UpdateIssueCommentResponseOK | T>;
    /**
     * Deletes an existing comment.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#issue-deleteComment
     * @param options Request options.
     */
    deleteComment<T = DeleteIssueCommentResponseOK>(options: DeleteIssueCommentRequest): Promise<DeleteIssueCommentResponseOK | T>;
}
declare class IssueCommentPropertyGroup {
    private implementation;
    private getGlobalErrorStrategy;
    constructor(implementation: PlatformImplementation, getGlobalErrorStrategy: GetGlobalErrorStrategy);
    /**
     * Returns the keys of all properties for the comment identified by the key or by the id.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.2/#comment/{commentId}/properties-getPropertiesKeys
     * @param options Request options.
     */
    getPropertyKeys<T = GetIssueCommentPropertyKeysResponseOK>(options: GetIssueCommentPropertyKeysRequest): Promise<GetIssueCommentPropertyKeysResponseOK | T>;
    /**
     * Removes the property from the comment identified by the key or by the id.
     * Ths user removing the property is required to have permissions to administer the comment.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.2/#comment/{commentId}/properties-deleteProperty
     * @param options Request options.
     */
    deleteProperty<T = DeleteIssueCommentPropertyResponseOK>(options: DeleteIssueCommentPropertyRequest): Promise<DeleteIssueCommentPropertyResponseOK | T>;
    /**
     * Sets the value of the specified comment's property.
     * You can use this resource to store a custom data against the comment identified by the key or by the id.
     * The user who stores the data is required to have permissions to administer the comment.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.2/#comment/{commentId}/properties-setProperty
     * @param options Request options.
     */
    setProperty<T = SetIssueCommentPropertyResponseOK>(options: SetIssueCommentPropertyRequest): Promise<SetIssueCommentPropertyResponseOK | T>;
    /**
     * Sets the value of the specified comment's property.
     * You can use this resource to store a custom data against the comment identified by the key or by the id.
     * The user who stores the data is required to have permissions to administer the comment.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.2/#comment/{commentId}/properties-setProperty
     * @param options Request options.
     */
    getProperty<T = GetIssueCommentPropertyResponseOK>(options: GetIssueCommentPropertyRequest): Promise<GetIssueCommentPropertyResponseOK | T>;
}
declare class AttachmentGroup {
    private implementation;
    private getGlobalErrorStrategy;
    Metadata: AttachmentMetadataGroup;
    constructor(implementation: PlatformImplementation, getGlobalErrorStrategy: GetGlobalErrorStrategy);
    /**
     * Returns the meta-data for an attachment, including the URI of the actual attached file.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#attachment-getAttachment
     * @param options Request options.
     */
    getAttachment<T = GetIssueAttachmentResponseOK>(options: GetIssueAttachmentRequest): Promise<GetIssueAttachmentResponseOK | T>;
    /**
     * Remove an attachment from an issue.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#attachment-removeAttachment
     * @param options Request options.
     */
    removeAttachment<T = RemoveIssueAttachmentResponseOK>(options: RemoveIssueAttachmentRequest): Promise<RemoveIssueAttachmentResponseOK | T>;
    /**
     * Add one or more attachments to an issue.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#issue/{issueIdOrKey}/attachments-addAttachment
     * @param options Request options.
     */
    addAttachment<T = AddIssueAttachmentResponseOK>(options: AddIssueAttachmentRequest): Promise<AddIssueAttachmentResponseOK | T>;
}
declare class AttachmentMetadataGroup {
    private implementation;
    private getGlobalErrorStrategy;
    constructor(implementation: PlatformImplementation, getGlobalErrorStrategy: GetGlobalErrorStrategy);
    /**
     * Returns the meta information for an attachments, specifically if they are enabled and the maximum upload size allowed.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#attachment-getAttachmentMeta
     * @param options Request options.
     */
    getMetadata<T = GetIssueAttachmentMetadataResponseOK>(options?: GetIssueAttachmentMetadataRequest): Promise<GetIssueAttachmentMetadataResponseOK | T>;
}
declare class FieldGroup {
    private implementation;
    private getGlobalErrorStrategy;
    Custom: CustomGroup;
    constructor(implementation: PlatformImplementation, getGlobalErrorStrategy: GetGlobalErrorStrategy);
    /**
     * Returns a list of all fields, both System and Custom.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#field-getFields
     * @param options Request options.
     */
    getFields<T = GetIssueFieldsResponseOK>(options?: GetIssueFieldsRequest): Promise<GetIssueFieldsResponseOK | T>;
}
declare class CustomGroup {
    private implementation;
    private getGlobalErrorStrategy;
    Option: OptionGroup;
    constructor(implementation: PlatformImplementation, getGlobalErrorStrategy: GetGlobalErrorStrategy);
    /**
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#customFields-getCustomFields
     * @param options Request options.
     */
    getFields<T = GetIssueCustomFieldsResponseOK>(options?: GetIssueCustomFieldsRequest): Promise<GetIssueCustomFieldsResponseOK | T>;
}
declare class OptionGroup {
    private implementation;
    private getGlobalErrorStrategy;
    constructor(implementation: PlatformImplementation, getGlobalErrorStrategy: GetGlobalErrorStrategy);
    /**
     * Returns a full representation of the Custom Field Option that has the given id.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#customFieldOption-getCustomFieldOption
     * @param options Request options.
     */
    getOption<T = GetIssueCustomFieldOptionResponseOK>(options: GetIssueCustomFieldOptionRequest): Promise<GetIssueCustomFieldOptionResponseOK | T>;
}
declare class LinkGroup {
    private implementation;
    private getGlobalErrorStrategy;
    Type: LinkTypeGroup;
    Remote: RemoteGroup;
    constructor(implementation: PlatformImplementation, getGlobalErrorStrategy: GetGlobalErrorStrategy);
    /**
     * Creates an issue link between two issues. The user requires the link issue permission for the issue which will be linked to another issue. The specified link type in the request is used to create the link and will create a link from the first issue to the second issue using the outward description. It also create a link from the second issue to the first issue using the inward description of the issue link type. It will add the supplied comment to the first issue. The comment can have a restriction who can view it. If group is specified, only users of this group can view this comment, if roleLevel is specified only users who have the specified role can view this comment. The user who creates the issue link needs to belong to the specified group or have the specified role.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#issueLink-linkIssues
     * @param options Request options.
     */
    createLink<T = CreateIssueLinkResponseOK>(options: CreateIssueLinkRequest): Promise<CreateIssueLinkResponseOK | T>;
    /**
     * Returns an issue link with the specified id.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#issueLink-getIssueLink
     * @param options Request options.
     */
    getLink<T = GetIssueLinkResponseOK>(options: GetIssueLinkRequest): Promise<GetIssueLinkResponseOK | T>;
    /**
     * Deletes an issue link with the specified id. To be able to delete an issue link you must be able to view both issues and must have the link issue permission for at least one of the issues.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#issueLink-deleteIssueLink
     * @param options Request options.
     */
    deleteLink<T = DeleteIssueLinkResponseOK>(options: DeleteIssueLinkRequest): Promise<DeleteIssueLinkResponseOK | T>;
}
declare class LinkTypeGroup {
    private implementation;
    private getGlobalErrorStrategy;
    constructor(implementation: PlatformImplementation, getGlobalErrorStrategy: GetGlobalErrorStrategy);
    /**
     * Returns a list of available issue link types, if issue linking is enabled. Each issue link type has an id, a name and a label for the outward and inward link relationship.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#issueLinkType-getIssueLinkTypes
     * @param options Request options.
     */
    getTypes<T = GetIssueLinkTypesResponseOK>(options?: GetIssueLinkTypesRequest): Promise<GetIssueLinkTypesResponseOK | T>;
    /**
     * Returns for a given issue link type id all information about this issue link type.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#issueLinkType-getIssueLinkType
     * @param options Request options.
     */
    getType<T = GetIssueLinkTypeResponseOK>(options: GetIssueLinkTypeRequest): Promise<GetIssueLinkTypeResponseOK | T>;
    /**
     * Create a new issue link type.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#issueLinkType-createIssueLinkType
     * @param options Request options.
     */
    createType<T = CreateIssueLinkTypeResponseOK>(options: CreateIssueLinkTypeRequest): Promise<CreateIssueLinkTypeResponseOK | T>;
    /**
     * Delete the specified issue link type.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#issueLinkType-deleteIssueLinkType
     * @param options Request options.
     */
    deleteType<T = DeleteIssueLinkTypeResponseOK>(options: DeleteIssueLinkTypeRequest): Promise<DeleteIssueLinkTypeResponseOK | T>;
    /**
     * Update the specified issue link type.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#issueLinkType-updateIssueLinkType
     * @param options Request options.
     */
    updateType<T = UpdateIssueLinkTypeResponseOK>(options: UpdateIssueLinkTypeRequest): Promise<UpdateIssueLinkTypeResponseOK | T>;
}
declare class RemoteGroup {
    private implementation;
    private getGlobalErrorStrategy;
    constructor(implementation: PlatformImplementation, getGlobalErrorStrategy: GetGlobalErrorStrategy);
    /**
     * A REST sub-resource representing the remote issue links on the issue.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#issue-getRemoteIssueLinks
     * @param options Request options.
     */
    getLinks<T = GetRemoteIssueLinksResponseOK>(options: GetRemoteIssueLinksRequest): Promise<GetRemoteIssueLinksResponseOK | T>;
    /**
     * Creates or updates a remote issue link from a JSON representation. If a globalId is provided and a remote issue link exists with that globalId, the remote issue link is updated. Otherwise, the remote issue link is created.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#issue-createOrUpdateRemoteIssueLink
     * @param options Request options.
     */
    createOrUpdateLink<T = CreateOrUpdateRemoteIssueLinkResponseOK>(options: CreateOrUpdateRemoteIssueLinkRequest): Promise<CreateOrUpdateRemoteIssueLinkResponseOK | T>;
    /**
     * Delete the remote issue link with the given global id on the issue.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#issue-deleteRemoteIssueLinkByGlobalId
     * @param options Request options.
     */
    deleteLinkByGlobalId<T = DeleteRemoteIssueLinkByGlobalIdResponseOK>(options: DeleteRemoteIssueLinkByGlobalIdRequest): Promise<DeleteRemoteIssueLinkByGlobalIdResponseOK | T>;
    /**
     * Get the remote issue link with the given id on the issue.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#issue-getRemoteIssueLinkById
     * @param options Request options.
     */
    getLink<T = GetRemoteIssueLinkResponseOK>(options: GetRemoteIssueLinkRequest): Promise<GetRemoteIssueLinkResponseOK | T>;
    /**
     * Updates a remote issue link from a JSON representation. Any fields not provided are set to null.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#issue-updateRemoteIssueLink
     * @param options Request options.
     */
    updateLink<T = UpdateRemoteIssueLinkResponseOK>(options: UpdateRemoteIssueLinkRequest): Promise<UpdateRemoteIssueLinkResponseOK | T>;
    /**
     * Delete the remote issue link with the given id on the issue.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#issue-deleteRemoteIssueLinkById
     * @param options Request options.
     */
    deleteLink<T = DeleteRemoteIssueLinkResponseOK>(options: DeleteRemoteIssueLinkRequest): Promise<DeleteRemoteIssueLinkResponseOK | T>;
}
declare class MetadataGroup {
    private implementation;
    private getGlobalErrorStrategy;
    constructor(implementation: PlatformImplementation, getGlobalErrorStrategy: GetGlobalErrorStrategy);
    /**
     * Returns the meta data for editing an issue. The fields in the editmeta correspond to the fields in the edit screen for the issue. Fields not in the screen will not be in the editmeta.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#issue-getEditIssueMeta
     * @param options Request options.
     */
    getEditMetadata<T = GetEditIssueMetadataResponseOK>(options: GetEditIssueMetadataRequest): Promise<GetEditIssueMetadataResponseOK | T>;
    /**
     * Returns the meta data for creating issues. This includes the available projects, issue types and fields, including field types and whether or not those fields are required. Projects will not be returned if the user does not have permission to create issues in that project.
     * The fields in the createmeta correspond to the fields in the create screen for the project/issuetype. Fields not in the screen will not be in the createmeta.
     * Fields will only be returned if expand=projects.issuetypes.fields.
     * The results can be filtered by project and/or issue type, given by the query params.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#issue-getCreateIssueMeta
     * @param options Request options.
     * @deprecated
     */
    getCreateMetadata<T = GetCreateIssueMetadataResponseOK>(options?: GetCreateIssueMetadataRequest): Promise<GetCreateIssueMetadataResponseOK | T>;
}
declare class PriorityGroup {
    private implementation;
    private getGlobalErrorStrategy;
    Scheme: IssuePrioritySchemeGroup;
    constructor(implementation: PlatformImplementation, getGlobalErrorStrategy: GetGlobalErrorStrategy);
    /**
     * Returns a list of all issue priorities.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#priority-getPriorities
     * @param options Request options.
     */
    getPriorities<T = GetIssuePrioritiesResponseOK>(options?: GetIssuePrioritiesRequest): Promise<GetIssuePrioritiesResponseOK | T>;
    /**
     * Returns an issue priority.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#priority-getPriority
     * @param options Request options.
     */
    getPriority<T = GetIssuePriorityResponseOK>(options: GetIssuePriorityRequest): Promise<GetIssuePriorityResponseOK | T>;
}
declare class IssuePrioritySchemeGroup {
    private implementation;
    private getGlobalErrorStrategy;
    constructor(implementation: PlatformImplementation, getGlobalErrorStrategy: GetGlobalErrorStrategy);
    /**
     * Creates new priority scheme.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.2/#priorityschemes-createPriorityScheme
     * @param options Request options.
     */
    createScheme<T = CreateIssuePrioritySchemeResponseOK>(options: CreateIssuePrioritySchemeRequest): Promise<CreateIssuePrioritySchemeResponseOK | T>;
    /**
     * Returns all priority schemes.
     * All project keys associated with the priority scheme will only be returned if additional query parameter is provided expand=schemes.projectKeys.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.2/#priorityschemes-getPrioritySchemes
     * @param options Request options.
     */
    getSchemes<T = GetIssuePrioritySchemesResponseOK>(options?: GetIssuePrioritySchemesRequest): Promise<GetIssuePrioritySchemesResponseOK | T>;
    /**
     * Deletes a priority scheme.
     * All projects using deleted scheme will use default priority scheme afterwards. Default priority scheme can't be deleted.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.2/#priorityschemes-deletePriorityScheme
     * @param options Request options.
     */
    deleteScheme<T = DeleteIssuePrioritySchemeResponseOK>(options: DeleteIssuePrioritySchemeRequest): Promise<DeleteIssuePrioritySchemeResponseOK | T>;
    /**
     * Updates a priority scheme.
     * Update will be rejected if issue migration would be needed as a result of scheme update.
     * Priority scheme update with migration is possible from the UI.
     * All project keys associated with the priority scheme will only be returned if additional query parameter is provided expand=projectKeys.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.2/#priorityschemes-updatePriorityScheme
     * @param options Request options.
     */
    updateScheme<T = UpdateIssuePrioritySchemeResponseOK>(options: UpdateIssuePrioritySchemeRequest): Promise<UpdateIssuePrioritySchemeResponseOK | T>;
    /**
     * Gets a full representation of a priority scheme in JSON format.
     * All project keys associated with the priority scheme will only be returned if additional query parameter is provided expand=projectKeys.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.2/#priorityschemes-getPriorityScheme
     * @param options Request options.
     */
    getScheme<T = GetIssuePrioritySchemeResponseOK>(options: GetIssuePrioritySchemeRequest): Promise<GetIssuePrioritySchemeResponseOK | T>;
}
declare class IssuePropertyGroup {
    private implementation;
    private getGlobalErrorStrategy;
    constructor(implementation: PlatformImplementation, getGlobalErrorStrategy: GetGlobalErrorStrategy);
    /**
     * Returns the keys of all properties for the issue identified by the key or by the id.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.2/#issue/{issueIdOrKey}/properties-getPropertiesKeys
     * @param options Request options.
     */
    getPropertyKeys<T = GetIssuePropertyKeysResponseOK>(options: GetIssuePropertyKeysRequest): Promise<GetIssuePropertyKeysResponseOK | T>;
    /**
     * Removes the property from the issue identified by the key or by the id.
     * Ths user removing the property is required to have permissions to edit the issue.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.2/#issue/{issueIdOrKey}/properties-deleteProperty
     * @param options Request options.
     */
    deleteProperty<T = DeleteIssuePropertyResponseOK>(options: DeleteIssuePropertyRequest): Promise<DeleteIssuePropertyResponseOK | T>;
    /**
     * Sets the value of the specified issue's property.
     * You can use this resource to store a custom data against the issue identified by the key or by the id.
     * The user who stores the data is required to have permissions to edit the issue.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.2/#issue/{issueIdOrKey}/properties-setProperty
     * @param options Request options.
     */
    setProperty<T = SetIssuePropertyResponseOK>(options: SetIssuePropertyRequest): Promise<SetIssuePropertyResponseOK | T>;
    /**
     * Returns the value of the property with a given key from the issue identified by the key or by the id.
     * The user who retrieves the property is required to have permissions to read the issue.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.2/#issue/{issueIdOrKey}/properties-getProperty
     * @param options Request options.
     */
    getProperty<T = GetIssuePropertyResponseOK>(options: GetIssuePropertyRequest): Promise<GetIssuePropertyResponseOK | T>;
}
declare class ResolutionGroup {
    private implementation;
    private getGlobalErrorStrategy;
    constructor(implementation: PlatformImplementation, getGlobalErrorStrategy: GetGlobalErrorStrategy);
    /**
     * Returns a list of all resolutions.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#resolution-getResolutions
     * @param options Request options.
     */
    getResolutions<T = GetIssueResolutionsResponseOK>(options?: GetIssueResolutionsRequest): Promise<GetIssueResolutionsResponseOK | T>;
    /**
     * Returns a resolution.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#resolution-getResolution
     * @param options Request options.
     */
    getResolution<T = GetIssueResolutionResponseOK>(options: GetIssueResolutionRequest): Promise<GetIssueResolutionResponseOK | T>;
}
declare class SearchGroup {
    private implementation;
    private getGlobalErrorStrategy;
    constructor(implementation: PlatformImplementation, getGlobalErrorStrategy: GetGlobalErrorStrategy);
    /**
     * Returns a resolution.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#resolution-getResolution
     * @param options Request options.
     */
    searchByJql<T = SearchIssuesByJqlResponseOK>(options: SearchIssuesByJqlRequest): Promise<SearchIssuesByJqlResponseOK | T>;
}
declare class SubTaskGroup {
    private implementation;
    private getGlobalErrorStrategy;
    constructor(implementation: PlatformImplementation, getGlobalErrorStrategy: GetGlobalErrorStrategy);
    /**
     * Returns an issue's subtask list.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#issue/{issueIdOrKey}/subtask-getSubTasks
     * @param options Request options.
     */
    getSubTasks<T = GetIssueSubTasksResponseOK>(options: GetIssueSubTasksRequest): Promise<GetIssueSubTasksResponseOK | T>;
    /**
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#issue/{issueIdOrKey}/subtask-canMoveSubTask
     * @param options Request options.
     */
    canMoveSubTask<T = CanMoveIssueSubTaskResponseOK>(options: CanMoveIssueSubTaskRequest): Promise<CanMoveIssueSubTaskResponseOK | T>;
    /**
     * Reorders an issue's subtasks by moving the subtask at index "from" to index "to".
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#issue/{issueIdOrKey}/subtask-moveSubTasks
     * @param options Request options.
     */
    moveSubTasks<T = MoveIssueSubTasksResponseOK>(options: MoveIssueSubTasksRequest): Promise<MoveIssueSubTasksResponseOK | T>;
}
declare class TransitionGroup {
    private implementation;
    private getGlobalErrorStrategy;
    constructor(implementation: PlatformImplementation, getGlobalErrorStrategy: GetGlobalErrorStrategy);
    /**
     * Reorders an issue's subtasks by moving the subtask at index "from" to index "to".
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#issue/{issueIdOrKey}/subtask-moveSubTasks
     * @param options Request options.
     */
    getTransitions<T = GetIssueTransitionsResponseOK>(options: GetIssueTransitionsRequest): Promise<GetIssueTransitionsResponseOK | T>;
    /**
     * Perform a transition on an issue. When performing the transition you can update or set other issue fields.
     * The fields that can be set on transtion, in either the fields parameter or the update parameter can be determined using the /rest/api/2/issue/{issueIdOrKey}/transitions?expand=transitions.fields resource. If a field is not configured to appear on the transition screen, then it will not be in the transition metadata, and a field validation error will occur if it is submitted. The updateHistory param adds the issues retrieved by this method to the current user's issue history, if set to true (by default, the issue history does not include issues retrieved via the REST API). You can view the issue history in the JIRA application, via the Issues dropdown or by using the lastViewed JQL field in an issue search.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#issue-doTransition
     * @param options Request options.
     */
    performTransition<T = PerformIssueTransitionResponseOK>(options: PerformIssueTransitionRequest): Promise<PerformIssueTransitionResponseOK | T>;
}
declare class TypeGroup {
    private implementation;
    private getGlobalErrorStrategy;
    Scheme: IssueTypeSchemeGroup;
    constructor(implementation: PlatformImplementation, getGlobalErrorStrategy: GetGlobalErrorStrategy);
    /**
     * Returns a list of all issue types visible to the user.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#issuetype-getIssueAllTypes
     * @param options Request options.
     */
    getTypes<T = GetIssueTypesResponseOK>(options?: GetIssueTypesRequest): Promise<GetIssueTypesResponseOK | T>;
    /**
     * Creates an issue type from a JSON representation and adds the issue newly created issue type to the default issue type scheme.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#issuetype-createIssueType
     * @param options Request options.
     */
    createType<T = CreateIssueTypeResponseOK>(options: CreateIssueTypeRequest): Promise<CreateIssueTypeResponseOK | T>;
    /**
     * Returns a full representation of the issue type that has the given id.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#issuetype-getIssueType
     * @param options Request options.
     */
    getType<T = GetIssueTypeResponseOK>(options: GetIssueTypeRequest): Promise<GetIssueTypeResponseOK | T>;
    /**
     * Deletes the specified issue type. If the issue type has any associated issues, these issues will be migrated to the alternative issue type specified in the parameter.
     * You can determine the alternative issue types by calling the /rest/api/2/issuetype/{id}/alternatives resource.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#issuetype-deleteIssueType
     * @param options Request options.
     */
    deleteType<T = DeleteIssueTypeResponseOK>(options: DeleteIssueTypeRequest): Promise<DeleteIssueTypeResponseOK | T>;
    /**
     * Updates the specified issue type from a JSON representation.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#issuetype-updateIssueType
     * @param options Request options.
     */
    updateType<T = UpdateIssueTypeResponseOK>(options: UpdateIssueTypeRequest): Promise<UpdateIssueTypeResponseOK | T>;
    /**
     * Returns a list of all alternative issue types for the given issue type id. The list will contain these issues types, to which issues assigned to the given issue type can be migrated.
     * The suitable alternatives are issue types which are assigned to the same workflow, the same field configuration and the same screen scheme.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#issuetype-getAlternativeIssueTypes
     * @param options Request options.
     */
    getAlternativeTypes<T = GetAlternativeIssueTypesResponseOK>(options: GetAlternativeIssueTypesRequest): Promise<GetAlternativeIssueTypesResponseOK | T>;
}
declare class IssueTypeSchemeGroup {
    private implementation;
    private getGlobalErrorStrategy;
    Project: IssueTypeSchemeProjectGroup;
    constructor(implementation: PlatformImplementation, getGlobalErrorStrategy: GetGlobalErrorStrategy);
    /**
     * Creates an issue type scheme from a JSON representation. (Admin required)
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.2/#issuetypescheme-createIssueTypeScheme
     * @param options Request options.
     */
    createScheme<T = CreateIssueTypeSchemeResponseOK>(options: CreateIssueTypeSchemeRequest): Promise<CreateIssueTypeSchemeResponseOK | T>;
    /**
     * Returns a list of all issue type schemes visible to the user (must be admin).
     * All issue types associated with the scheme will only be returned if an additional query parameter is provided: expand=schemes.issueTypes.
     * Similarly, the default issue type associated with the scheme (if one exists) will only be returned if additional an query parameter is provided: expand=schemes.defaultIssueType.
     * Note that both query parameters can be used together: expand=schemes.issueTypes,schemes.defaultIssueType.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.2/#issuetypescheme-getAllIssueTypeSchemes
     * @param options Request options.
     */
    getSchemes<T = GetIssueTypeSchemesResponseOK>(options?: GetIssueTypeSchemesRequest): Promise<GetIssueTypeSchemesResponseOK | T>;
    /**
     * Returns a full representation of the issue type scheme that has the given id (must be admin).
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.2/#issuetypescheme-getIssueTypeScheme
     * @param options Request options.
     */
    getScheme<T = GetIssueTypeSchemeResponseOK>(options: GetIssueTypeSchemeRequest): Promise<GetIssueTypeSchemeResponseOK | T>;
    /**
     * Updates the specified issue type scheme from a JSON representation. (Admin required)
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.2/#issuetypescheme-updateIssueTypeScheme
     * @param options Request options.
     */
    updateScheme<T = UpdateIssueTypeSchemeResponseOK>(options: UpdateIssueTypeSchemeRequest): Promise<UpdateIssueTypeSchemeResponseOK | T>;
    /**
     * Deletes the specified issue type scheme.
     * Any projects associated with this IssueTypeScheme will be automatically associated with the global default IssueTypeScheme. (Admin required)
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.2/#issuetypescheme-deleteIssueTypeScheme
     * @param options Request options.
     */
    deleteScheme<T = DeleteIssueTypeSchemeResponseOK>(options: DeleteIssueTypeSchemeRequest): Promise<DeleteIssueTypeSchemeResponseOK | T>;
}
declare class IssueTypeSchemeProjectGroup {
    private implementation;
    private getGlobalErrorStrategy;
    constructor(implementation: PlatformImplementation, getGlobalErrorStrategy: GetGlobalErrorStrategy);
    /**
     * Perform a transition on an issue. When performing the transition you can update or set other issue fields.
     * The fields that can be set on transtion, in either the fields parameter or the update parameter can be determined using the /rest/api/2/issue/{issueIdOrKey}/transitions?expand=transitions.fields resource. If a field is not configured to appear on the transition screen, then it will not be in the transition metadata, and a field validation error will occur if it is submitted. The updateHistory param adds the issues retrieved by this method to the current user's issue history, if set to true (by default, the issue history does not include issues retrieved via the REST API). You can view the issue history in the JIRA application, via the Issues dropdown or by using the lastViewed JQL field in an issue search.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#issue-doTransition
     * @param options Request options.
     */
    addAssociations<T = AddProjectAssociationsToIssueTypeSchemeResponseOK>(options: AddProjectAssociationsToIssueTypeSchemeRequest): Promise<AddProjectAssociationsToIssueTypeSchemeResponseOK | T>;
    /**
     * For the specified issue type scheme, returns all of the associated projects. (Admin required)
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.2/#issuetypescheme-getAssociatedProjects
     * @param options Request options.
     */
    getAssociations<T = GetProjectAssociationsForIssueTypeSchemeResponseOK>(options: GetProjectAssociationsForIssueTypeSchemeRequest): Promise<GetProjectAssociationsForIssueTypeSchemeResponseOK | T>;
    /**
     * Associates the given projects with the specified issue type scheme.
     * Any existing project-associations the issue type scheme has will be overwritten. (Admin required)
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.2/#issuetypescheme-setProjectAssociationsForScheme
     * @param options Request options.
     */
    setAssociations<T = SetProjectAssociationsForIssueTypeSchemeResponseOK>(options: SetProjectAssociationsForIssueTypeSchemeRequest): Promise<SetProjectAssociationsForIssueTypeSchemeResponseOK | T>;
    /**
     * Removes all project associations for the specified issue type scheme.
     * These projects revert to an association with the default/global issue type scheme.(Admin required)
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.2/#issuetypescheme-removeAllProjectAssociations
     * @param options Request options.
     */
    removeAssociations<T = RemoveProjectAssociationsForIssueTypeSchemeResponseOK>(options: RemoveProjectAssociationsForIssueTypeSchemeRequest): Promise<RemoveProjectAssociationsForIssueTypeSchemeResponseOK | T>;
    /**
     * For the specified issue type scheme, removes the given project association.
     * This project reverts to an association with the default/global issue type scheme.(Admin required)
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.2/#issuetypescheme-removeProjectAssociation
     * @param options Request options.
     */
    removeAssociation<T = RemoveProjectAssociationForIssueTypeSchemeResponseOK>(options: RemoveProjectAssociationForIssueTypeSchemeRequest): Promise<RemoveProjectAssociationForIssueTypeSchemeResponseOK | T>;
}
declare class VoteGroup {
    private implementation;
    private getGlobalErrorStrategy;
    constructor(implementation: PlatformImplementation, getGlobalErrorStrategy: GetGlobalErrorStrategy);
    /**
     * Remove your vote from an issue. (i.e. "unvote").
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#issue-removeVote
     * @param options Request options.
     */
    removeVote<T = RemoveIssueVoteResponseOK>(options: RemoveIssueVoteRequest): Promise<RemoveIssueVoteResponseOK | T>;
    /**
     * Cast your vote in favour of an issue.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#issue-addVote
     * @param options Request options.
     */
    addVote<T = AddIssueVoteResponseOK>(options: AddIssueVoteRequest): Promise<AddIssueVoteResponseOK | T>;
    /**
    * A REST sub-resource representing the voters on the issue.
    * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#issue-getVotes
    * @param options Request options.
    */
    getVotes<T = GetIssueVotesResponseOK>(options: GetIssueVotesRequest): Promise<GetIssueVotesResponseOK | T>;
}
declare class WatcherGroup {
    private implementation;
    private getGlobalErrorStrategy;
    constructor(implementation: PlatformImplementation, getGlobalErrorStrategy: GetGlobalErrorStrategy);
    /**
     * Returns the list of watchers for the issue with the given key.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#issue-getIssueWatchers
     * @param options Request options.
     */
    getWatchers<T = GetIssueWatchersResponseOK>(options: GetIssueWatchersRequest): Promise<GetIssueWatchersResponseOK | T>;
    /**
     * Adds a user to an issue's watcher list.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#issue-addWatcher
     * @param options Request options.
     */
    addWatcher<T = AddIssueWatcherResponseOK>(options: AddIssueWatcherRequest): Promise<AddIssueWatcherResponseOK | T>;
    /**
     * Removes a user from an issue's watcher list.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#issue-removeWatcher
     * @param options Request options.
     */
    removeWatcher<T = RemoveIssueWatcherResponseOK>(options: RemoveIssueWatcherRequest): Promise<RemoveIssueWatcherResponseOK | T>;
}
declare class WorklogGroup {
    private implementation;
    private getGlobalErrorStrategy;
    constructor(implementation: PlatformImplementation, getGlobalErrorStrategy: GetGlobalErrorStrategy);
    /**
     * Returns all work logs for an issue. Work logs won't be returned if the Log work field is hidden for the project.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#issue-getIssueWorklog
     * @param options Request options.
     */
    getWorklogs<T = GetIssueWorklogsResponseOK>(options: GetIssueWorklogsRequest): Promise<GetIssueWorklogsResponseOK | T>;
    /**
     * Adds a new worklog entry to an issue.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#issue-addWorklog
     * @param options Request options.
     */
    addWorklog<T = AddIssueWorklogResponseOK>(options: AddIssueWorklogRequest): Promise<AddIssueWorklogResponseOK | T>;
    /**
     * Returns a specific worklog. The work log won't be returned if the Log work field is hidden for the project.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#issue-getWorklog
     * @param options Request options.
     */
    getWorklog<T = GetIssueWorklogResponseOK>(options: GetIssueWorklogRequest): Promise<GetIssueWorklogResponseOK | T>;
    /**
     * Updates an existing worklog entry. Fields possible for editing are: comment, visibility, started, timeSpent and timeSpentSeconds. Either timeSpent or timeSpentSeconds can be set. Fields which are not set will not be updated. For a request to be valid, it has to have at least one field change.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#issue-updateWorklog
     * @param options Request options.
     */
    updateWorklog<T = UpdateIssueWorklogResponseOK>(options: UpdateIssueWorklogRequest): Promise<UpdateIssueWorklogResponseOK | T>;
    /**
     * Deletes an existing worklog entry.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#issue-deleteWorklog
     * @param options Request options.
     */
    deleteWorklog<T = DeleteIssueWorklogResponseOK>(options: DeleteIssueWorklogRequest): Promise<DeleteIssueWorklogResponseOK | T>;
    /**
     * Returns worklogs id and delete time of worklogs that was deleted since given time. The returns set of worklogs is limited to 1000 elements. This API will not return worklogs deleted during last minute.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#worklog-getIdsOfWorklogsDeletedSince
     * @param options Request options.
     */
    getDeletedWorklogIds<T = GetDeletedIssueWorklogIdsResponseOK>(options?: GetDeletedIssueWorklogIdsRequest): Promise<GetDeletedIssueWorklogIdsResponseOK | T>;
    /**
     * Returns worklogs for given worklog ids. Only worklogs to which the calling user has permissions, will be included in the result. The returns set of worklogs is limited to 1000 elements.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#worklog-getWorklogsForIds
     * @param options Request options.
     */
    getWorklogsForIds<T = GetIssueWorklogsForIdsResponseOK>(options: GetIssueWorklogsForIdsRequest): Promise<GetIssueWorklogsForIdsResponseOK | T>;
    /**
     * Returns worklogs id and update time of worklogs that was updated since given time. The returns set of worklogs is limited to 1000 elements. This API will not return worklogs updated during last minute.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#worklog-getIdsOfWorklogsModifiedSince
     * @param options Request options.
     */
    getUpdatedWorklogIds<T = GetUpdatedIssueWorklogIdsResponseOK>(options?: GetUpdatedIssueWorklogIdsRequest): Promise<GetUpdatedIssueWorklogIdsResponseOK | T>;
}
declare class IssueSecurityGroup {
    private implementation;
    private getGlobalErrorStrategy;
    Scheme: IssueSecuritySchemeGroup;
    constructor(implementation: PlatformImplementation, getGlobalErrorStrategy: GetGlobalErrorStrategy);
}
declare class IssueSecuritySchemeGroup {
    private implementation;
    private getGlobalErrorStrategy;
    constructor(implementation: PlatformImplementation, getGlobalErrorStrategy: GetGlobalErrorStrategy);
    /**
     * Returns all issue security schemes that are defined.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.2/#issuesecurityschemes-getIssueSecuritySchemes
     * @param options Request options.
     */
    getSchemes<T = GetIssueSecuritySchemesResponseOK>(options?: GetIssueSecuritySchemesRequest): Promise<GetIssueSecuritySchemesResponseOK | T>;
    /**
     * Returns the issue security scheme along with that are defined.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.2/#issuesecurityschemes-getIssueSecurityScheme
     * @param options Request options.
     */
    getScheme<T = GetIssueSecuritySchemeResponseOK>(options: GetIssueSecuritySchemeRequest): Promise<GetIssueSecuritySchemeResponseOK | T>;
}
declare class IssueNotificationGroup {
    private implementation;
    private getGlobalErrorStrategy;
    Scheme: IssueNotificationSchemeGroup;
    constructor(implementation: PlatformImplementation, getGlobalErrorStrategy: GetGlobalErrorStrategy);
}
declare class IssueNotificationSchemeGroup {
    private implementation;
    private getGlobalErrorStrategy;
    constructor(implementation: PlatformImplementation, getGlobalErrorStrategy: GetGlobalErrorStrategy);
    /**
     * Returns a paginated list of notification schemes.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#notificationscheme-getNotificationSchemes
     * @param options Request options.
     */
    getSchemes<T = GetNotificationSchemesResponseOK>(options?: GetNotificationSchemesRequest): Promise<GetNotificationSchemesResponseOK | T>;
    /**
     * Returns a full representation of the notification scheme for the given id.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.2/#notificationscheme-getNotificationScheme
     * @param options Request options.
     */
    getScheme<T = GetNotificationSchemeResponseOK>(options: GetNotificationSchemeRequest): Promise<GetNotificationSchemeResponseOK | T>;
}
declare class ApplicationGroup {
    private implementation;
    private getGlobalErrorStrategy;
    Role: ApplicationRoleGroup;
    constructor(implementation: PlatformImplementation, getGlobalErrorStrategy: GetGlobalErrorStrategy);
}
declare class ApplicationRoleGroup {
    private implementation;
    private getGlobalErrorStrategy;
    constructor(implementation: PlatformImplementation, getGlobalErrorStrategy: GetGlobalErrorStrategy);
    /**
     * Returns all ApplicationRoles in the system.
     * Will also return an ETag header containing a version hash of the collection of ApplicationRoles.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.2/#applicationrole-getAll
     * @param options Request options.
     */
    getRoles<T = GetApplicationRolesResponseOK>(options?: GetApplicationRolesRequest): Promise<GetApplicationRolesResponseOK | T>;
    /**
     * Returns the ApplicationRole with passed key if it exists.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.2/#applicationrole-get
     * @param options Request options.
     */
    getRole<T = GetApplicationRoleResponseOK>(options: GetApplicationRoleRequest): Promise<GetApplicationRoleResponseOK | T>;
    /**
     * Updates the ApplicationRole with the passed data.
     * Only the groups and default groups setting of the role may be updated.
     * Requests to change the key or the name of the role will be silently ignored.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.2/#applicationrole-put
     * @param options Request options.
     */
    updateRole<T = UpdateApplicationRoleResponseOK>(options: UpdateApplicationRoleRequest): Promise<UpdateApplicationRoleResponseOK | T>;
}
declare class WorkflowGroup {
    private implementation;
    private getGlobalErrorStrategy;
    Status: WorkflowStatusGroup;
    Scheme: WorkflowSchemeGroup;
    constructor(implementation: PlatformImplementation, getGlobalErrorStrategy: GetGlobalErrorStrategy);
    /**
     * Returns all workflows.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#workflow-getAllWorkflows
     * @param options Request options.
     */
    getWorkflows<T = GetWorkflowsResponseOK>(options?: GetWorkflowsRequest): Promise<GetWorkflowsResponseOK | T>;
}
declare class WorkflowStatusGroup {
    private implementation;
    private getGlobalErrorStrategy;
    Category: StatusCategoryGroup;
    constructor(implementation: PlatformImplementation, getGlobalErrorStrategy: GetGlobalErrorStrategy);
    /**
     * Returns a list of all statuses.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#status-getStatuses
     * @param options Request options.
     */
    getStatuses<T = GetWorkflowStatusesResponseOK>(options?: GetWorkflowStatusesRequest): Promise<GetWorkflowStatusesResponseOK | T>;
    /**
     * Returns a full representation of the Status having the given id or name.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#status-getStatus
     * @param options Request options.
     */
    getStatus<T = GetWorkflowStatusResponseOK>(options: GetWorkflowStatusRequest): Promise<GetWorkflowStatusResponseOK | T>;
}
declare class StatusCategoryGroup {
    private implementation;
    private getGlobalErrorStrategy;
    constructor(implementation: PlatformImplementation, getGlobalErrorStrategy: GetGlobalErrorStrategy);
    /**
     * Returns a list of all status categories.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#statuscategory-getStatusCategories
     * @param options Request options.
     */
    getCategories<T = GetWorkflowStatusCategoriesResponseOK>(options?: GetWorkflowStatusCategoriesRequest): Promise<GetWorkflowStatusCategoriesResponseOK | T>;
    /**
     * Returns a list of all status categories.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#statuscategory-getStatusCategories
     * @param options Request options.
     */
    getCategory<T = GetWorkflowStatusCategoryResponseOK>(options: GetWorkflowStatusCategoryRequest): Promise<GetWorkflowStatusCategoryResponseOK | T>;
}
declare class WorkflowSchemeGroup {
    private implementation;
    private getGlobalErrorStrategy;
    constructor(implementation: PlatformImplementation, getGlobalErrorStrategy: GetGlobalErrorStrategy);
    /**
     * Create a new workflow scheme.
     * The body contains a representation of the new scheme. Values not passed are assumed to be set to their defaults.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.2/#workflowscheme-createScheme
     * @param options Request options.
     */
    createScheme<T = CreateWorkflowSchemeResponseOK>(options: CreateWorkflowSchemeRequest): Promise<CreateWorkflowSchemeResponseOK | T>;
    /**
     * Returns the requested workflow scheme to the caller.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.2/#workflowscheme-getById
     * @param options Request options.
     */
    getScheme<T = GetWorkflowSchemeResponseOK>(options: GetWorkflowSchemeRequest): Promise<GetWorkflowSchemeResponseOK | T>;
    /**
     * Returns the requested workflow scheme to the caller.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.2/#workflowscheme-getById
     * @param options Request options.
     */
    deleteScheme<T = DeleteWorkflowSchemeResponseOK>(options: DeleteWorkflowSchemeRequest): Promise<DeleteWorkflowSchemeResponseOK | T>;
    /**
     * Update the passed workflow scheme.
     * The body of the request is a representation of the workflow scheme.
     * Values not passed are assumed to indicate no change for that field.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.2/#workflowscheme-update
     * @param options Request options.
     */
    updateScheme<T = UpdateWorkflowSchemeResponseOK>(options: UpdateWorkflowSchemeRequest): Promise<UpdateWorkflowSchemeResponseOK | T>;
}
declare class DashboardGroup {
    private implementation;
    private getGlobalErrorStrategy;
    constructor(implementation: PlatformImplementation, getGlobalErrorStrategy: GetGlobalErrorStrategy);
    /**
     * Returns a list of all dashboards, optionally filtering them.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#dashboard-list
     * @param options Request options.
     */
    getDashboards<T = GetAllDashboardsResponseOK>(options?: GetAllDashboardsRequest): Promise<GetAllDashboardsResponseOK | T>;
    /**
     * Returns a single dashboard.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#dashboard-getDashboard
     * @param options Request options.
     */
    getDashboard<T = GetDashboardByIdResponseOK>(options: GetDashboardByIdRequest): Promise<GetDashboardByIdResponseOK | T>;
}
declare class FilterGroup {
    private implementation;
    private getGlobalErrorStrategy;
    Column: FilterColumnGroup;
    Share: FilterShareGroup;
    constructor(implementation: PlatformImplementation, getGlobalErrorStrategy: GetGlobalErrorStrategy);
    /**
     * Returns a filter given an id.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#filter-getFilter
     * @param options Request options.
     */
    getFilter<T = GetFilterResponseOK>(options: GetFilterRequest): Promise<GetFilterResponseOK | T>;
    /**
     * Returns the favourite filters of the logged-in user.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#filter-getFavouriteFilters
     * @param options Request options.
     */
    getMyFavouriteFilters<T = GetMyFavouriteFiltersResponseOK>(options?: GetMyFavouriteFiltersRequest): Promise<GetMyFavouriteFiltersResponseOK | T>;
    /**
     * Creates a new filter, and returns newly created filter. Currently sets permissions just using the users default sharing permissions.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#filter-createFilter
     * @param options Request options.
     */
    createFilter<T = CreateFilterResponseOK>(options: CreateFilterRequest): Promise<CreateFilterResponseOK | T>;
    /**
     * Updates an existing filter, and returns its new value.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#filter-editFilter
     * @param options Request options.
     */
    editFilter<T = EditFilterResponseOK>(options: EditFilterRequest): Promise<EditFilterResponseOK | T>;
    /**
     * Delete a filter.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#filter-deleteFilter
     * @param options Request options.
     */
    deleteFilter<T = DeleteFilterResponseOK>(options: DeleteFilterRequest): Promise<DeleteFilterResponseOK | T>;
}
declare class FilterColumnGroup {
    private implementation;
    private getGlobalErrorStrategy;
    constructor(implementation: PlatformImplementation, getGlobalErrorStrategy: GetGlobalErrorStrategy);
    /**
     * Returns the default columns for the given filter. Currently logged in user will be used as the user making such request.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#filter-defaultColumns
     * @param options Request options.
     */
    getDefaultColumns<T = GetFilterDefaultColumnsResponseOK>(options: GetFilterDefaultColumnsRequest): Promise<GetFilterDefaultColumnsResponseOK | T>;
    /**
     * Sets the default columns for the given filter.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#filter-setColumns
     * @param options Request options.
     */
    setDefaultColumns<T = SetFilterDefaultColumnsResponseOK>(options: SetFilterDefaultColumnsRequest): Promise<SetFilterDefaultColumnsResponseOK | T>;
    /**
     * Resets the columns for the given filter such that the filter no longer has its own column config.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#filter-resetColumns
     * @param options Request options.
     */
    resetColumns<T = ResetFilterColumnsResponseOK>(options: ResetFilterColumnsRequest): Promise<ResetFilterColumnsResponseOK | T>;
}
declare class FilterShareGroup {
    private implementation;
    private getGlobalErrorStrategy;
    Permission: SharePermissionGroup;
    constructor(implementation: PlatformImplementation, getGlobalErrorStrategy: GetGlobalErrorStrategy);
    /**
     * Returns the default share scope of the logged-in user.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#filter-getDefaultShareScope
     * @param options Request options.
     */
    getShareScope<T = GetDefaultShareScopeResponseOK>(options?: GetDefaultShareScopeRequest): Promise<GetDefaultShareScopeResponseOK | T>;
    /**
     * Sets the default share scope of the logged-in user. Available values are GLOBAL and PRIVATE.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#filter-setDefaultShareScope
     * @param options Request options.
     */
    setShareScope<T = SetDefaultShareScopeResponseOK>(options: SetDefaultShareScopeRequest): Promise<SetDefaultShareScopeResponseOK | T>;
}
declare class SharePermissionGroup {
    private implementation;
    private getGlobalErrorStrategy;
    constructor(implementation: PlatformImplementation, getGlobalErrorStrategy: GetGlobalErrorStrategy);
    /**
     * Returns all share permissions of the given filter.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#filter-getSharePermissions
     * @param options Request options.
     */
    getSharePermissions<T = GetFilterSharePermissionsResponseOK>(options: GetFilterSharePermissionsRequest): Promise<GetFilterSharePermissionsResponseOK | T>;
    /**
     * Adds a share permissions to the given filter. Adding a global permission removes all previous permissions from the filter.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#filter-addSharePermission
     * @param options Request options.
     */
    addSharePermission<T = AddFilterSharePermissionResponseOK>(options: AddFilterSharePermissionRequest): Promise<AddFilterSharePermissionResponseOK | T>;
    /**
     * Returns a single share permission of the given filter.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#filter-getSharePermission
     * @param options Request options.
     */
    getSharePermission<T = GetFilterSharePermissionResponseOK>(options: GetFilterSharePermissionRequest): Promise<GetFilterSharePermissionResponseOK | T>;
    /**
     * Removes a share permissions from the given filter.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#filter-getSharePermission
     * @param options Request options.
     */
    deleteSharePermission<T = DeleteFilterSharePermissionResponseOK>(options: DeleteFilterSharePermissionRequest): Promise<DeleteFilterSharePermissionResponseOK | T>;
}
declare class GroupGroup {
    private implementation;
    private getGlobalErrorStrategy;
    User: GroupUserGroup;
    constructor(implementation: PlatformImplementation, getGlobalErrorStrategy: GetGlobalErrorStrategy);
    /**
     * Creates a group by given group parameter.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#group-createGroup
     * @param options Request options.
     */
    createGroup<T = CreateGroupResponseOK>(options: CreateGroupRequest): Promise<CreateGroupResponseOK | T>;
    /**
     * Deletes a group by given group parameter.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#group-removeGroup
     * @param options Request options.
     */
    removeGroup<T = RemoveGroupResponseOK>(options?: RemoveGroupRequest): Promise<RemoveGroupResponseOK | T>;
}
declare class GroupUserGroup {
    private implementation;
    private getGlobalErrorStrategy;
    constructor(implementation: PlatformImplementation, getGlobalErrorStrategy: GetGlobalErrorStrategy);
    /**
     * This resource returns a paginated list of users who are members of the specified group and its subgroups. Users in the page are ordered by user names. User of this resource is required to have sysadmin or admin permissions.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#group-getUsersFromGroup
     * @param options Request options.
     */
    getUsers<T = GetUsersFromGroupResponseOK>(options: GetUsersFromGroupRequest): Promise<GetUsersFromGroupResponseOK | T>;
    /**
     * Adds given user to a group.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#group-addUserToGroup
     * @param options Request options.
     */
    addUsers<T = AddUsersToGroupResponseOK>(options: AddUsersToGroupRequest): Promise<AddUsersToGroupResponseOK | T>;
    /**
     * Removes given user from a group.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#group-removeUserFromGroup
     * @param options Request options.
     */
    removeUsers<T = RemoveUsersFromGroupResponseOK>(options?: RemoveUsersFromGroupRequest): Promise<RemoveUsersFromGroupResponseOK | T>;
}
declare class InstanceGroup {
    private implementation;
    private getGlobalErrorStrategy;
    constructor(implementation: PlatformImplementation, getGlobalErrorStrategy: GetGlobalErrorStrategy);
    /**
     * Returns an application property.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#application-properties-getProperty
     * @param options Request options.
     */
    getApplicationProperty<T = GetApplicationPropertyResponseOK>(options?: GetApplicationPropertyRequest): Promise<GetApplicationPropertyResponseOK | T>;
    /**
     * Modify an application property via PUT. The "value" field present in the PUT will override the existing value.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#application-properties-setPropertyViaRestfulTable
     * @param options Request options.
     */
    setApplicationProperty<T = SetApplicationPropertyResponseOK>(options: SetApplicationPropertyRequest): Promise<SetApplicationPropertyResponseOK | T>;
    /**
     * Returns the properties that are displayed on the "General Configuration > Advanced Settings" page.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#application-properties-getAdvancedSettings
     * @param options Request options.
     */
    getAdvancedSettings<T = GetAdvancedSettingsResponseOK>(options?: GetAdvancedSettingsRequest): Promise<GetAdvancedSettingsResponseOK | T>;
    /**
     * Returns the information if the optional features in JIRA are enabled or disabled. If the time tracking is enabled, it also returns the detailed information about time tracking configuration.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#configuration-getConfiguration
     * @param options Request options.
     */
    getConfiguration<T = GetInstanceConfigurationResponseOK>(options?: GetInstanceConfigurationRequest): Promise<GetInstanceConfigurationResponseOK | T>;
    /**
     * Returns general information about the current JIRA server.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#serverInfo-getServerInfo
     * @param options Request options.
     */
    getInfo<T = GetInstanceInfoResponseOK>(options?: GetInstanceInfoRequest): Promise<GetInstanceInfoResponseOK | T>;
}
declare class MyselfGroup {
    private implementation;
    private getGlobalErrorStrategy;
    constructor(implementation: PlatformImplementation, getGlobalErrorStrategy: GetGlobalErrorStrategy);
    /**
     * Sets preference of the currently logged in user.
     * Preference key must be provided as input parameters (key).
     * Value must be provided as post body. If key or value parameter is not provided - status code 404.
     * If preference is set - status code 204.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.2/#mypreferences-setPreference
     * @param options Request options.
     */
    setPreference<T = SetMyPreferenceResponseOK>(options: SetMyPreferenceRequest): Promise<SetMyPreferenceResponseOK | T>;
    /**
     * Removes preference of the currently logged in user. Preference key must be provided as input parameters (key).
     * If key parameter is not provided or wrong - status code 404.
     * If preference is unset - status code 204.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.2/#mypreferences-removePreference
     * @param options Request options.
     */
    removePreference<T = RemoveMyPreferenceResponseOK>(options: RemoveMyPreferenceRequest): Promise<RemoveMyPreferenceResponseOK | T>;
    /**
     * Returns preference of the currently logged in user.
     * Preference key must be provided as input parameter (key).
     * The value is returned exactly as it is. If key parameter is not provided or wrong - status code 404.
     * If value is found - status code 200.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.2/#mypreferences-getPreference
     * @param options Request options.
     */
    getPreference<T = GetMyPreferenceResponseOK>(options: GetMyPreferenceRequest): Promise<GetMyPreferenceResponseOK | T>;
    /**
     * Returns currently logged in user.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#myself-getUser
     * @param options Request options.
     */
    getCurrentUser<T = GetCurrentUserResponseOK>(options?: GetCurrentUserRequest): Promise<GetCurrentUserResponseOK | T>;
}
declare class PermissionGroup {
    private implementation;
    private getGlobalErrorStrategy;
    Scheme: PermissionSchemeGroup;
    constructor(implementation: PlatformImplementation, getGlobalErrorStrategy: GetGlobalErrorStrategy);
    /**
     * Returns all permissions in the system and whether the currently logged in user has them.
     * You can optionally provide a specific context to get permissions for (projectKey OR projectId OR issueKey OR issueId)
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#-getPermissions
     * @param options Request options.
     */
    getMyPermissions<T = GetMyPermissionsResponseOK>(options?: GetMyPermissionsRequest): Promise<GetMyPermissionsResponseOK | T>;
    /**
     * Returns all permissions that are present in the JIRA instance - Global, Project and the global ones added by plugins
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#-getAllPermissions
     * @param options Request options.
     */
    getPermissions<T = GetPermissionsResponseOK>(options?: GetPermissionsRequest): Promise<GetPermissionsResponseOK | T>;
}
declare class PermissionSchemeGroup {
    private implementation;
    private getGlobalErrorStrategy;
    Attribute: PermissionSchemeAttributeGroup;
    Grant: PermissionSchemeGrantGroup;
    constructor(implementation: PlatformImplementation, getGlobalErrorStrategy: GetGlobalErrorStrategy);
    /**
     * Returns a list of all permission schemes.
     * By default only shortened beans are returned.
     * If you want to include permissions of all the schemes, then specify the permissions expand parameter.
     * Permissions will be included also if you specify any other expand parameter.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.2/#permissionscheme-getPermissionSchemes
     * @param options Request options.
     */
    getSchemes<T = GetPermissionSchemesResponseOK>(options?: GetPermissionSchemesRequest): Promise<GetPermissionSchemesResponseOK | T>;
    /**
     * Returns a list of all permission schemes.
     * By default only shortened beans are returned.
     * If you want to include permissions of all the schemes, then specify the permissions expand parameter.
     * Permissions will be included also if you specify any other expand parameter.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.2/#permissionscheme-getPermissionSchemes
     * @param options Request options.
     */
    createScheme<T = CreatePermissionSchemeResponseOK>(options: CreatePermissionSchemeRequest): Promise<CreatePermissionSchemeResponseOK | T>;
    /**
     * Returns a permission scheme identified by the given id.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.2/#permissionscheme-getPermissionScheme
     * @param options Request options.
     */
    getScheme<T = GetPermissionSchemeResponseOK>(options: GetPermissionSchemeRequest): Promise<GetPermissionSchemeResponseOK | T>;
    /**
     * Deletes a permission scheme identified by the given id.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.2/#permissionscheme-deletePermissionScheme
     * @param options Request options.
     */
    deleteScheme<T = DeletePermissionSchemeResponseOK>(options: DeletePermissionSchemeRequest): Promise<DeletePermissionSchemeResponseOK | T>;
    /**
     * Updates a permission scheme.
     * If the permissions list is present then it will be set in the permission scheme, which basically means it will overwrite any permission grants that existed in the permission scheme.
     * Sending an empty list will remove all permission grants from the permission scheme.
     * To update just the name and description, do not send permissions list at all.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.2/#permissionscheme-updatePermissionScheme
     * @param options Request options.
     */
    updateScheme<T = UpdatePermissionSchemeResponseOK>(options: UpdatePermissionSchemeRequest): Promise<UpdatePermissionSchemeResponseOK | T>;
}
declare class PermissionSchemeAttributeGroup {
    private implementation;
    private getGlobalErrorStrategy;
    constructor(implementation: PlatformImplementation, getGlobalErrorStrategy: GetGlobalErrorStrategy);
    /**
     * Returns scheme attribute.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.2/#permissionscheme-getSchemeAttribute
     * @param options Request options.
     */
    getAttribute<T = GetPermissionSchemeAttributeResponseOK>(options: GetPermissionSchemeAttributeRequest): Promise<GetPermissionSchemeAttributeResponseOK | T>;
}
declare class PermissionSchemeGrantGroup {
    private implementation;
    private getGlobalErrorStrategy;
    constructor(implementation: PlatformImplementation, getGlobalErrorStrategy: GetGlobalErrorStrategy);
    /**
     * Returns all permission grants of the given permission scheme.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.2/#permissionscheme-getPermissionSchemeGrants
     * @param options Request options.
     */
    getGrants<T = GetPermissionSchemeGrantsResponseOK>(options: GetPermissionSchemeGrantsRequest): Promise<GetPermissionSchemeGrantsResponseOK | T>;
    /**
     * Creates a permission grant in a permission scheme.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.2/#permissionscheme-createPermissionGrant
     * @param options Request options.
     */
    createGrant<T = CreatePermissionSchemeGrantResponseOK>(options: CreatePermissionSchemeGrantRequest): Promise<CreatePermissionSchemeGrantResponseOK | T>;
    /**
     * Deletes a permission grant from a permission scheme.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.2/#permissionscheme-deletePermissionSchemeEntity
     * @param options Request options.
     */
    deleteGrant<T = DeletePermissionSchemeGrantResponseOK>(options: DeletePermissionSchemeGrantRequest): Promise<DeletePermissionSchemeGrantResponseOK | T>;
    /**
     * Returns a permission grant identified by the given id.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.2/#permissionscheme-getPermissionSchemeGrant
     * @param options Request options.
     */
    getGrant<T = GetPermissionSchemeGrantResponseOK>(options: GetPermissionSchemeGrantRequest): Promise<GetPermissionSchemeGrantResponseOK | T>;
}
declare class ProjectGroup {
    private implementation;
    private getGlobalErrorStrategy;
    Component: ComponentGroup;
    Role: ProjectRoleGroup;
    Type: ProjectTypeGroup;
    Validation: ProjectValidationGroup;
    Version: ProjectVersionGroup;
    Issue: ProjectIssueGroup;
    Notification: ProjectNotificationGroup;
    Permission: ProjectPermissionGroup;
    Priority: ProjectPriorityGroup;
    Security: ProjectSecurityGroup;
    constructor(implementation: PlatformImplementation, getGlobalErrorStrategy: GetGlobalErrorStrategy);
    /**
     * Returns all projects which are visible for the currently logged in user. If no user is logged in, it returns the list of projects that are visible when using anonymous access.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#project-getAllProjects
     * @param options Request options.
     */
    getProjects<T = GetProjectsResponseOK>(options?: GetProjectsRequest): Promise<GetProjectsResponseOK | T>;
    /**
     * Creates a new project.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#project-createProject
     * @param options Request options.
     */
    createProject<T = CreateProjectResponseOK>(options: CreateProjectRequest): Promise<CreateProjectResponseOK | T>;
    /**
     * Contains a full representation of a project in JSON format.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#project-getProject
     * @param options Request options.
     */
    getProject<T = GetProjectResponseOK>(options: GetProjectRequest): Promise<GetProjectResponseOK | T>;
    /**
     * Contains a full representation of a project in JSON format.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#project-getProject
     * @param options Request options.
     */
    updateProject<T = UpdateProjectResponseOK>(options: UpdateProjectRequest): Promise<UpdateProjectResponseOK | T>;
    /**
     * Deletes a project.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#project-deleteProject
     * @param options Request options.
     */
    deleteProject<T = DeleteProjectResponseOK>(options: DeleteProjectRequest): Promise<DeleteProjectResponseOK | T>;
    /**
     * Archives a project. Only for DC.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#project-archiveProject
     * @param options Request options.
     */
    archiveProject<T = ArchiveProjectResponseOK>(options: ArchiveProjectRequest): Promise<ArchiveProjectResponseOK | T>;
    /**
     * Contains a full representation of a the specified project's components.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#project-getProjectComponents
     * @param options Request options.
     */
    getComponents<T = GetProjectComponentsResponseOK>(options: GetProjectComponentsRequest): Promise<GetProjectComponentsResponseOK | T>;
    /**
     * Contains a full representation of a the specified project's components.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#project-getProjectComponents
     * @param options Request options.
     */
    restoreProject<T = RestoreProjectResponseOK>(options: RestoreProjectRequest): Promise<RestoreProjectResponseOK | T>;
    /**
     * Get all issue types with valid status values for a project.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#project-getAllStatuses
     * @param options Request options.
     */
    getStatuses<T = GetProjectStatusesResponseOK>(options: GetProjectStatusesRequest): Promise<GetProjectStatusesResponseOK | T>;
    /**
     * Updates the type of a project.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#project-updateProjectType
     * @param options Request options.
     */
    updateProjectType<T = UpdateProjectTypeResponseOK>(options: UpdateProjectTypeRequest): Promise<UpdateProjectTypeResponseOK | T>;
    /**
     * Returns all versions for the specified project. Results are paginated.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#project-getProjectVersionsPaginated
     * @param options Request options.
     */
    getVersionsPaginated<T = GetProjectVersionsPaginatedResponseOK>(options: GetProjectVersionsPaginatedRequest): Promise<GetProjectVersionsPaginatedResponseOK | T>;
    /**
     * Contains a full representation of a the specified project's versions.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#project-getProjectVersions
     * @param options Request options.
     */
    getVersions<T = GetProjectVersionsResponseOK>(options: GetProjectVersionsRequest): Promise<GetProjectVersionsResponseOK | T>;
}
declare class ComponentGroup {
    private implementation;
    private getGlobalErrorStrategy;
    constructor(implementation: PlatformImplementation, getGlobalErrorStrategy: GetGlobalErrorStrategy);
    /**
     * Create a component via POST.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#component-createComponent
     * @param options Request options.
     */
    createComponent<T = CreateProjectComponentResponseOK>(options: CreateProjectComponentRequest): Promise<CreateProjectComponentResponseOK | T>;
    /**
     * Returns a project component.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#component-getComponent
     * @param options Request options.
     */
    getComponent<T = GetProjectComponentResponseOK>(options: GetProjectComponentRequest): Promise<GetProjectComponentResponseOK | T>;
    /**
     * Modify a component via PUT. If leadUserName is an empty string ("") the component lead will be removed.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#component-updateComponent
     * @param options Request options.
     */
    updateComponent<T = UpdateProjectComponentResponseOK>(options: UpdateProjectComponentRequest): Promise<UpdateProjectComponentResponseOK | T>;
    /**
     * Delete a project component.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#component-delete
     * @param options Request options.
     */
    deleteComponent<T = DeleteProjectComponentResponseOK>(options: DeleteProjectComponentRequest): Promise<DeleteProjectComponentResponseOK | T>;
    /**
     * Returns counts of issues related to this component.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#component-getComponentRelatedIssues
     * @param options Request options.
     */
    getRelatedIssueCount<T = GetProjectComponentRelatedIssueCountResponseOK>(options: GetProjectComponentRelatedIssueCountRequest): Promise<GetProjectComponentRelatedIssueCountResponseOK | T>;
}
declare class ProjectRoleGroup {
    private implementation;
    private getGlobalErrorStrategy;
    Actor: RoleActorGroup;
    constructor(implementation: PlatformImplementation, getGlobalErrorStrategy: GetGlobalErrorStrategy);
    /**
     * Returns all roles in the given project Id or key, with links to full details on each role.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#project/{projectIdOrKey}/role-getProjectRoles
     * @param options Request options.
     */
    getRoles<T = GetProjectRolesResponseOK>(options: GetProjectRolesRequest): Promise<GetProjectRolesResponseOK | T>;
    /**
     * Returns the details for a given project role in a project.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#project/{projectIdOrKey}/role-getProjectRole
     * @param options Request options.
     */
    getRole<T = GetProjectRoleResponseOK>(options: GetProjectRoleRequest): Promise<GetProjectRolesResponseOK | T>;
}
declare class RoleActorGroup {
    private implementation;
    private getGlobalErrorStrategy;
    constructor(implementation: PlatformImplementation, getGlobalErrorStrategy: GetGlobalErrorStrategy);
    /**
     * Updates a project role to include the specified actors (users or groups).
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#project/{projectIdOrKey}/role-setActors
     * @param options Request options.
     */
    setActors<T = SetProjectRoleActorsResponseOK>(options: SetProjectRoleActorsRequest): Promise<SetProjectRoleActorsResponseOK | T>;
    /**
     * Adds an actor (user or group) to a project role.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#project/{projectIdOrKey}/role-addActorUsers
     * @param options Request options.
     */
    addUsers<T = AddProjectRoleActorUsersResponseOK>(options: AddProjectRoleActorUsersRequest): Promise<AddProjectRoleActorUsersResponseOK | T>;
    /**
     * Deletes actors (users or groups) from a project role.
     * Delete a user from the role: /rest/api/2/project/{projectIdOrKey}/role/{roleId}?user={username}
     * Delete a group from the role: /rest/api/2/project/{projectIdOrKey}/role/{roleId}?group={groupname}
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#project/{projectIdOrKey}/role-deleteActor
     * @param options Request options.
     */
    deleteActor<T = DeleteProjectRoleActorResponseOK>(options: DeleteProjectRoleActorRequest): Promise<DeleteProjectRoleActorResponseOK | T>;
}
declare class ProjectSecurityGroup {
    private implementation;
    private getGlobalErrorStrategy;
    constructor(implementation: PlatformImplementation, getGlobalErrorStrategy: GetGlobalErrorStrategy);
    /**
     * Returns all security levels for the project that the current logged in user has access to.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.2/#project/{projectKeyOrId}/securitylevel-getSecurityLevelsForProject
     * @param options Request options.
     */
    getLevels<T = GetProjectSecurityLevelsResponseOK>(options: GetProjectSecurityLevelsRequest): Promise<GetProjectSecurityLevelsResponseOK | T>;
}
declare class ProjectTypeGroup {
    private implementation;
    private getGlobalErrorStrategy;
    constructor(implementation: PlatformImplementation, getGlobalErrorStrategy: GetGlobalErrorStrategy);
    /**
     * Returns all the project types defined on the JIRA instance, not taking into account whether the license to use those project types is valid or not.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#project/type-getAllProjectTypes
     * @param options Request options.
     */
    getTypes<T = GetProjectTypesResponseOK>(options?: GetProjectTypesRequest): Promise<GetProjectTypesResponseOK | T>;
    /**
     * Returns the project type with the given key.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#project/type-getProjectTypeByKey
     * @param options Request options.
     */
    getType<T = GetProjectTypeResponseOK>(options: GetProjectTypeRequest): Promise<GetProjectTypeResponseOK | T>;
    /**
     * Returns the project type with the given key, if it is accessible to the logged in user. This takes into account whether the user is licensed on the Application that defines the project type.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#project/type-getAccessibleProjectTypeByKey
     * @param options Request options.
     */
    getAccessibleType<T = GetAccessibleProjectTypeResponseOK>(options: GetAccessibleProjectTypeRequest): Promise<GetAccessibleProjectTypeResponseOK | T>;
}
declare class ProjectValidationGroup {
    private implementation;
    private getGlobalErrorStrategy;
    constructor(implementation: PlatformImplementation, getGlobalErrorStrategy: GetGlobalErrorStrategy);
    /**
     * Validates a project key.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#projectvalidate-getProject
     * @param options Request options.
     */
    validateProjectKey<T = ValidateProjectKeyResponseOK>(options: ValidateProjectKeyRequest): Promise<ValidateProjectKeyResponseOK | T>;
}
declare class ProjectVersionGroup {
    private implementation;
    private getGlobalErrorStrategy;
    Count: VersionCountGroup;
    Remote: ProjectVersionRemoteGroup;
    constructor(implementation: PlatformImplementation, getGlobalErrorStrategy: GetGlobalErrorStrategy);
    /**
     * Create a version via POST.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#version-createVersion
     * @param options Request options.
     */
    createVersion<T = CreateProjectVersionResponseOK>(options: CreateProjectVersionRequest): Promise<CreateProjectVersionResponseOK | T>;
    /**
     * Modify a version's sequence within a project.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#version-moveVersion
     * @param options Request options.
     */
    moveVersion<T = MoveProjectVersionResponseOK>(options: MoveProjectVersionRequest): Promise<MoveProjectVersionResponseOK | T>;
    /**
     * Returns a project version.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#version-getVersion
     * @param options Request options.
     */
    getVersion<T = GetProjectVersionResponseOK>(options: GetProjectVersionRequest): Promise<GetProjectVersionResponseOK | T>;
    /**
     * Modify a version via PUT. Any fields present in the PUT will override existing values. As a convenience, if a field is not present, it is silently ignored.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#version-updateVersion
     * @param options Request options.
     */
    updateVersion<T = UpdateProjectVersionResponseOK>(options: UpdateProjectVersionRequest): Promise<UpdateProjectVersionResponseOK | T>;
    /**
     * Delete a project version.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#version-delete
     * @param options Request options.
     */
    deleteVersion<T = DeleteProjectVersionResponseOK>(options: DeleteProjectVersionRequest): Promise<DeleteProjectVersionResponseOK | T>;
    /**
     * Merge versions.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#version-merge
     * @param options Request options.
     */
    mergeVersion<T = MergeProjectVersionResponseOK>(options: MergeProjectVersionRequest): Promise<MergeProjectVersionResponseOK | T>;
    /**
     * Delete a project version.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#version-delete
     * @param options Request options.
     */
    removeAndReplaceVersion<T = RemoveAndReplaceProjectVersionResponseOK>(options: RemoveAndReplaceProjectVersionRequest): Promise<RemoveAndReplaceProjectVersionResponseOK | T>;
}
declare class VersionCountGroup {
    private implementation;
    private getGlobalErrorStrategy;
    constructor(implementation: PlatformImplementation, getGlobalErrorStrategy: GetGlobalErrorStrategy);
    /**
     * Returns a bean containing the number of fixed in and affected issues for the given version.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#version-getVersionRelatedIssues
     * @param options Request options.
     */
    getVersionRelatedIssueCount<T = GetProjectVersionRelatedIssueCountResponseOK>(options: GetProjectVersionRelatedIssueCountRequest): Promise<GetProjectVersionRelatedIssueCountResponseOK | T>;
    /**
     * Returns the number of unresolved issues for the given version
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#version-getVersionUnresolvedIssues
     * @param options Request options.
     */
    getVersionUnresolvedIssueCount<T = GetProjectVersionUnresolvedIssueCountResponseOK>(options: GetProjectVersionUnresolvedIssueCountRequest): Promise<GetProjectVersionUnresolvedIssueCountResponseOK | T>;
}
declare class ProjectVersionRemoteGroup {
    private implementation;
    private getGlobalErrorStrategy;
    constructor(implementation: PlatformImplementation, getGlobalErrorStrategy: GetGlobalErrorStrategy);
    /**
     * Returns the remote version links associated with the given version ID.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.2/#version-getRemoteVersionLinksByVersionId
     * @param options Request options.
     */
    getLinksById<T = GetRemoteVersionLinksByIdResponseOK>(options: GetRemoteVersionLinksByIdRequest): Promise<GetRemoteVersionLinksByIdResponseOK | T>;
    /**
     * Create a remote version link via POST.
     * The link's global ID will be taken from the JSON payload if provided; otherwise, it will be generated.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.2/#version-createOrUpdateRemoteVersionLink
     * @param options Request options.
     */
    createOrUpdateLinkById<T = CreateOrUpdateRemoteVersionLinkByIdResponseOK>(options: CreateOrUpdateRemoteVersionLinkByIdRequest): Promise<CreateOrUpdateRemoteVersionLinkByIdResponseOK | T>;
    /**
     * Delete all remote version links for a given version ID.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.2/#version-deleteRemoteVersionLinksByVersionId
     * @param options Request options.
     */
    deleteLinksById<T = DeleteRemoteVersionLinksByIdResponseOK>(options: DeleteRemoteVersionLinksByIdRequest): Promise<DeleteRemoteVersionLinksByIdResponseOK | T>;
    /**
     * A REST sub-resource representing a remote version link.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.2/#version-getRemoteVersionLink
     * @param options Request options.
     */
    getLink<T = GetRemoteVersionLinkResponseOK>(options: GetRemoteVersionLinkRequest): Promise<GetRemoteVersionLinkResponseOK | T>;
    /**
     * Create a remote version link via POST.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.2/#version-createOrUpdateRemoteVersionLink
     * @param options Request options.
     */
    createOrUpdateLink<T = CreateOrUpdateRemoteVersionLinkResponseOK>(options: CreateOrUpdateRemoteVersionLinkRequest): Promise<CreateOrUpdateRemoteVersionLinkResponseOK | T>;
    /**
     * Delete a specific remote version link with the given version ID and global ID.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.2/#version-deleteRemoteVersionLink
     * @param options Request options.
     */
    deleteLink<T = DeleteRemoteVersionLinkResponseOK>(options: DeleteRemoteVersionLinkRequest): Promise<DeleteRemoteVersionLinkResponseOK | T>;
    /**
     * Returns the remote version links for a given global ID.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.2/#version-getRemoteVersionLinks
     * @param options Request options.
     */
    getLinks<T = GetRemoteVersionLinksResponseOK>(options: GetRemoteVersionLinksRequest): Promise<GetRemoteVersionLinksResponseOK | T>;
}
declare class ProjectIssueGroup {
    private implementation;
    private getGlobalErrorStrategy;
    Security: ProjectIssueSecurityGroup;
    constructor(implementation: PlatformImplementation, getGlobalErrorStrategy: GetGlobalErrorStrategy);
}
declare class ProjectIssueSecurityGroup {
    private implementation;
    private getGlobalErrorStrategy;
    Scheme: ProjectIssueSecuritySchemeGroup;
    constructor(implementation: PlatformImplementation, getGlobalErrorStrategy: GetGlobalErrorStrategy);
}
declare class ProjectIssueSecuritySchemeGroup {
    private implementation;
    private getGlobalErrorStrategy;
    constructor(implementation: PlatformImplementation, getGlobalErrorStrategy: GetGlobalErrorStrategy);
    /**
     * Returns the issue security scheme for project.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.2/#project/{projectKeyOrId}/issuesecuritylevelscheme-getIssueSecurityScheme
     * @param options Request options.
     */
    getScheme<T = GetProjectIssueSecuritySchemeResponseOK>(options: GetProjectIssueSecuritySchemeRequest): Promise<GetProjectIssueSecuritySchemeResponseOK | T>;
}
declare class ProjectNotificationGroup {
    private implementation;
    private getGlobalErrorStrategy;
    Scheme: ProjectNotificationSchemeGroup;
    constructor(implementation: PlatformImplementation, getGlobalErrorStrategy: GetGlobalErrorStrategy);
}
declare class ProjectNotificationSchemeGroup {
    private implementation;
    private getGlobalErrorStrategy;
    constructor(implementation: PlatformImplementation, getGlobalErrorStrategy: GetGlobalErrorStrategy);
    /**
     * Gets a notification scheme associated with the project.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.2/#project/{projectKeyOrId}/notificationscheme-getNotificationScheme
     * @param options Request options.
     */
    getScheme<T = GetProjectNotificationSchemeResponseOK>(options: GetProjectNotificationSchemeRequest): Promise<GetProjectNotificationSchemeResponseOK | T>;
}
declare class ProjectPermissionGroup {
    private implementation;
    private getGlobalErrorStrategy;
    Scheme: ProjectPermissionSchemeGroup;
    constructor(implementation: PlatformImplementation, getGlobalErrorStrategy: GetGlobalErrorStrategy);
}
declare class ProjectPermissionSchemeGroup {
    private implementation;
    private getGlobalErrorStrategy;
    constructor(implementation: PlatformImplementation, getGlobalErrorStrategy: GetGlobalErrorStrategy);
    /**
     * Resource for associating permission schemes and projects.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.2/#project/{projectKeyOrId}/permissionscheme-getAssignedPermissionScheme
     * @param options Request options.
     */
    getScheme<T = GetProjectPermissionSchemeResponseOK>(options: GetProjectPermissionSchemeRequest): Promise<GetProjectPermissionSchemeResponseOK | T>;
}
declare class ProjectPriorityGroup {
    private implementation;
    private getGlobalErrorStrategy;
    Scheme: ProjectPrioritySchemeGroup;
    constructor(implementation: PlatformImplementation, getGlobalErrorStrategy: GetGlobalErrorStrategy);
}
declare class ProjectPrioritySchemeGroup {
    private implementation;
    private getGlobalErrorStrategy;
    constructor(implementation: PlatformImplementation, getGlobalErrorStrategy: GetGlobalErrorStrategy);
    /**
     * Gets a full representation of a priority scheme in JSON format used by specified project.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.2/#project/{projectKeyOrId}/priorityscheme-getAssignedPriorityScheme
     * @param options Request options.
     */
    getScheme<T = GetPrioritySchemeResponseOK>(options: GetPrioritySchemeRequest): Promise<GetPrioritySchemeResponseOK | T>;
}
declare class ScreenGroup {
    private implementation;
    private getGlobalErrorStrategy;
    Tab: ScreenTabGroup;
    Field: ScreenFieldGroup;
    constructor(implementation: PlatformImplementation, getGlobalErrorStrategy: GetGlobalErrorStrategy);
    /**
     * Gets available fields for screen. i.e ones that haven't already been added.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.2/#screens-getFieldsToAdd
     * @param options Request options.
     */
    getFieldsToAdd<T = GetScreenFieldsToAddResponseOK>(options: GetScreenFieldsToAddRequest): Promise<GetScreenFieldsToAddResponseOK | T>;
    /**
     * Gets available field screens.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.2/#screens-getAllScreens
     * @param options Request options.
     */
    getScreens<T = GetScreensResponseOK>(options?: GetScreensRequest): Promise<GetScreensResponseOK | T>;
}
declare class ScreenTabGroup {
    private implementation;
    private getGlobalErrorStrategy;
    constructor(implementation: PlatformImplementation, getGlobalErrorStrategy: GetGlobalErrorStrategy);
    /**
     * Creates tab for given screen.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.2/#screens-addTab
     * @param options Request options.
     */
    addTab<T = AddScreenTabResponseOK>(options: AddScreenTabRequest): Promise<AddScreenTabResponseOK | T>;
    /**
     * Returns a list of all tabs for the given screen.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.2/#screens-getAllTabs
     * @param options Request options.
     */
    getTabs<T = GetScreenTabsResponseOK>(options: GetScreenTabsRequest): Promise<GetScreenTabsResponseOK | T>;
    /**
     * Renames tab on given screen.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.2/#screens-renameTab
     * @param options Request options.
     */
    renameTab<T = RenameScreenTabResponseOK>(options: RenameScreenTabRequest): Promise<RenameScreenTabResponseOK | T>;
    /**
     * Deletes tab to give screen.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.2/#screens-deleteTab
     * @param options Request options.
     */
    deleteTab<T = DeleteScreenTabResponseOK>(options: DeleteScreenTabRequest): Promise<DeleteScreenTabResponseOK | T>;
    /**
     * Moves tab position.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.2/#screens-moveTab
     * @param options Request options.
     */
    moveTab<T = MoveScreenTabResponseOK>(options: MoveScreenTabRequest): Promise<MoveScreenTabResponseOK | T>;
}
declare class ScreenFieldGroup {
    private implementation;
    private getGlobalErrorStrategy;
    constructor(implementation: PlatformImplementation, getGlobalErrorStrategy: GetGlobalErrorStrategy);
    /**
     * Gets all fields for a given tab.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.2/#screens-getAllFields
     * @param options Request options.
     */
    getFields<T = GetScreenFieldsResponseOK>(options: GetScreenFieldsRequest): Promise<GetScreenFieldsResponseOK | T>;
    /**
    * Adds field to the given tab.
    * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.2/#screens-addField
    * @param options Request options.
    */
    addField<T = AddScreenFieldResponseOK>(options: AddScreenFieldRequest): Promise<AddScreenFieldResponseOK | T>;
    /**
     * Removes field from given tab.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.2/#screens-removeField
     * @param options Request options.
     */
    removeField<T = RemoveScreenFieldResponseOK>(options: RemoveScreenFieldRequest): Promise<RemoveScreenFieldResponseOK | T>;
    /**
     * Moves field on the given tab.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.2/#screens-moveField
     * @param options Request options.
     */
    moveField<T = MoveScreenFieldResponseOK>(options: MoveScreenFieldRequest): Promise<MoveScreenFieldResponseOK | T>;
    /**
     * Adds field or custom field to the default tab.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.2/#screens-addFieldToDefaultScreen
     * @param options Request options.
     */
    addToDefaultScreen<T = AddFieldToDefaultScreenResponseOK>(options: AddFieldToDefaultScreenRequest): Promise<AddFieldToDefaultScreenResponseOK | T>;
}
declare class UserGroup {
    private implementation;
    private getGlobalErrorStrategy;
    Search: UserSearchGroup;
    constructor(implementation: PlatformImplementation, getGlobalErrorStrategy: GetGlobalErrorStrategy);
    /**
     * Returns a user.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#user-getUser
     * @param options Request options.
     */
    getUser<T = GetUserResponseOK>(options?: GetUserRequest): Promise<GetUserResponseOK | T>;
    /**
     * Modify user. The "value" fields present will override the existing value. Fields skipped in request will not be changed.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#user-updateUser
     * @param options Request options.
     */
    updateUser<T = UpdateUserResponseOK>(options: UpdateUserRequest): Promise<UpdateUserResponseOK | T>;
    /**
     * Create user. By default created user will not be notified with email. If password field is not set then password will be randomly generated.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#user-createUser
     * @param options Request options.
     */
    createUser<T = CreateUserResponseOK>(options: CreateUserRequest): Promise<CreateUserResponseOK | T>;
    /**
     * Removes user and its references (like project roles associations, watches, history).
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#user-removeUser
     * @param options Request options.
     */
    removeUser<T = RemoveUserResponseOK>(options: RemoveUserRequest): Promise<RemoveUserResponseOK | T>;
    /**
     * Add user to given application. Admin permission will be required to perform this operation.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#user-addUserToApplication
     * @param options Request options.
     */
    addUserToApplication<T = AddUserToApplicationResponseOK>(options: AddUserToApplicationRequest): Promise<AddUserToApplicationResponseOK | T>;
    /**
     * Remove user from given application. Admin permission will be required to perform this operation.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#user-removeUserFromApplication
     * @param options Request options.
     */
    removeUserFromApplication<T = RemoveUserFromApplicationResponseOK>(options: RemoveUserFromApplicationRequest): Promise<RemoveUserFromApplicationResponseOK | T>;
    /**
     * Modify user password.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#user-changeUserPassword
     * @param options Request options.
     */
    changeUserPassword<T = ChangeUserPasswordResponseOK>(options: ChangeUserPasswordRequest): Promise<ChangeUserPasswordResponseOK | T>;
}
declare class UserSearchGroup {
    private implementation;
    private getGlobalErrorStrategy;
    constructor(implementation: PlatformImplementation, getGlobalErrorStrategy: GetGlobalErrorStrategy);
    /**
     * Returns a list of users that match the search string. This resource cannot be accessed anonymously. Please note that this resource should be called with an issue key when a list of assignable users is retrieved for editing. For create only a project key should be supplied. The list of assignable users may be incorrect if it's called with the project key for editing.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#user-findAssignableUsers
     * @param options Request options.
     */
    findAssignableUsers<T = FindAssignableUsersResponseOK>(options?: FindAssignableUsersRequest): Promise<FindAssignableUsersResponseOK | T>;
    /**
     * Returns a list of active users that match the search string and have all specified permissions for the project or issue.
     * This resource can be accessed by users with ADMINISTER_PROJECT permission for the project or global ADMIN or SYSADMIN rights.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#user-findUsersWithAllPermissions
     * @param options Request options.
     */
    findUsersWithAllPermissions<T = FindUsersWithAllPermissionsResponseOK>(options: FindUsersWithAllPermissionsRequest): Promise<FindUsersWithAllPermissionsResponseOK | T>;
    /**
     * Returns a list of users that match the search string. This resource cannot be accessed anonymously.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#user-findUsers
     * @param options Request options.
     */
    findUsers<T = FindUsersResponseOK>(options: FindUsersRequest): Promise<FindUsersResponseOK | T>;
    /**
     * Returns a list of active users that match the search string. This resource cannot be accessed anonymously and requires the Browse Users global permission. Given an issue key this resource will provide a list of users that match the search string and have the browse issue permission for the issue provided.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#user-findUsersWithBrowsePermission
     * @param options Request options.
     */
    findUsersWithBrowsePermission<T = FindUsersWithBrowsePermissionResponseOK>(options: FindUsersWithBrowsePermissionRequest): Promise<FindUsersWithBrowsePermissionResponseOK | T>;
}
declare class RoleGroup {
    private implementation;
    private getGlobalErrorStrategy;
    Project: RoleProjectGroup;
    constructor(implementation: PlatformImplementation, getGlobalErrorStrategy: GetGlobalErrorStrategy);
}
declare class RoleProjectGroup {
    private implementation;
    private getGlobalErrorStrategy;
    Actor: RoleProjectActorGroup;
    constructor(implementation: PlatformImplementation, getGlobalErrorStrategy: GetGlobalErrorStrategy);
    /**
     * Get all the ProjectRoles available in JIRA. Currently this list is global.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#role-getProjectRoles
     * @param options Request options.
     */
    getRoles<T = GetGlobalProjectRolesResponseOK>(options?: GetGlobalProjectRolesRequest): Promise<GetGlobalProjectRolesResponseOK | T>;
    /**
     * Creates a new ProjectRole to be available in Jira. The created role does not have any default actors assigned.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.2/#role-createProjectRole
     * @param options Request options.
     */
    createRole<T = CreateGlobalProjectRoleResponseOK>(options: CreateGlobalProjectRoleRequest): Promise<CreateGlobalProjectRoleResponseOK | T>;
    /**
     * Get a specific ProjectRole available in JIRA.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#role-getProjectRolesById
     * @param options Request options.
     */
    getRole<T = GetGlobalProjectRoleResponseOK>(options: GetGlobalProjectRoleRequest): Promise<GetGlobalProjectRoleResponseOK | T>;
    /**
     * Partially updates a roles name or description.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.2/#role-partialUpdateProjectRole
     * @param options Request options.
     */
    updateRolePartially<T = UpdateGlobalProjectRolePartiallyResponseOK>(options: UpdateGlobalProjectRolePartiallyRequest): Promise<UpdateGlobalProjectRolePartiallyResponseOK | T>;
    /**
     * Fully updates a roles. Both name and description must be given.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.0/#role-getProjectRolesById
     * @param options Request options.
     */
    updateRoleFully<T = UpdateGlobalProjectRoleFullyResponseOK>(options: UpdateGlobalProjectRoleFullyRequest): Promise<UpdateGlobalProjectRoleFullyResponseOK | T>;
    /**
     * Deletes a role. May return 403 in the future.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.2/#role-deleteProjectRole
     * @param options Request options.
     */
    deleteRole<T = DeleteGlobalProjectRoleResponseOK>(options: DeleteGlobalProjectRoleRequest): Promise<DeleteGlobalProjectRoleResponseOK | T>;
}
declare class RoleProjectActorGroup {
    private implementation;
    private getGlobalErrorStrategy;
    constructor(implementation: PlatformImplementation, getGlobalErrorStrategy: GetGlobalErrorStrategy);
    /**
     * Gets default actors for the given role.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.2/#role-getProjectRoleActorsForRole
     * @param options Request options.
     */
    getActors<T = GetGlobalProjectRoleActorsResponseOK>(options: GetGlobalProjectRoleActorsRequest): Promise<GetGlobalProjectRoleActorsResponseOK | T>;
    /**
     * Adds default actors to the given role. The request data should contain a list of usernames or a list of groups to add.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.2/#role-addProjectRoleActorsToRole
     * @param options Request options.
     */
    addActors<T = AddGlobalProjectRoleActorsResponseOK>(options: AddGlobalProjectRoleActorsRequest): Promise<AddGlobalProjectRoleActorsResponseOK | T>;
    /**
     * Removes default actor from the given role.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/8.20.2/#role-deleteProjectRoleActorsFromRole
     * @param options Request options.
     */
    deleteActors<T = DeleteGlobalProjectRoleActorsResponseOK>(options: DeleteGlobalProjectRoleActorsRequest): Promise<DeleteGlobalProjectRoleActorsResponseOK | T>;
}
export {};
//# sourceMappingURL=index.d.ts.map